""" Cisco_IOS_XR_ip_static_cfg 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ip\-static package configuration.

This module contains definitions
for the following management objects\:
  router\-static\: This class represents router static
    configuration

Copyright (c) 2013\-2016 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.entity_utils import get_relative_entity_path as _get_relative_entity_path
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error



class RouterStatic(Entity):
    """
    This class represents router static configuration
    
    .. attribute:: default_vrf
    
    	Default VRF configuration
    	**type**\:   :py:class:`DefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf>`
    
    .. attribute:: maximum_routes
    
    	The maximum number of static routes that can be configured
    	**type**\:   :py:class:`MaximumRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.MaximumRoutes>`
    
    .. attribute:: vrfs
    
    	VRF static configuration container
    	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs>`
    
    

    """

    _prefix = 'ip-static-cfg'
    _revision = '2015-09-10'

    def __init__(self):
        super(RouterStatic, self).__init__()
        self._top_entity = None

        self.yang_name = "router-static"
        self.yang_parent_name = "Cisco-IOS-XR-ip-static-cfg"

        self.default_vrf = RouterStatic.DefaultVrf()
        self.default_vrf.parent = self
        self._children_name_map["default_vrf"] = "default-vrf"
        self._children_yang_names.add("default-vrf")

        self.maximum_routes = RouterStatic.MaximumRoutes()
        self.maximum_routes.parent = self
        self._children_name_map["maximum_routes"] = "maximum-routes"
        self._children_yang_names.add("maximum-routes")

        self.vrfs = RouterStatic.Vrfs()
        self.vrfs.parent = self
        self._children_name_map["vrfs"] = "vrfs"
        self._children_yang_names.add("vrfs")


    class Vrfs(Entity):
        """
        VRF static configuration container
        
        .. attribute:: vrf
        
        	VRF static configuration
        	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf>`
        
        

        """

        _prefix = 'ip-static-cfg'
        _revision = '2015-09-10'

        def __init__(self):
            super(RouterStatic.Vrfs, self).__init__()

            self.yang_name = "vrfs"
            self.yang_parent_name = "router-static"

            self.vrf = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RouterStatic.Vrfs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RouterStatic.Vrfs, self).__setattr__(name, value)


        class Vrf(Entity):
            """
            VRF static configuration
            
            .. attribute:: vrf_name  <key>
            
            	VRF name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: address_family
            
            	Address family configuration
            	**type**\:   :py:class:`AddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily>`
            
            

            """

            _prefix = 'ip-static-cfg'
            _revision = '2015-09-10'

            def __init__(self):
                super(RouterStatic.Vrfs.Vrf, self).__init__()

                self.yang_name = "vrf"
                self.yang_parent_name = "vrfs"

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.address_family = RouterStatic.Vrfs.Vrf.AddressFamily()
                self.address_family.parent = self
                self._children_name_map["address_family"] = "address-family"
                self._children_yang_names.add("address-family")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("vrf_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RouterStatic.Vrfs.Vrf, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RouterStatic.Vrfs.Vrf, self).__setattr__(name, value)


            class AddressFamily(Entity):
                """
                Address family configuration
                
                .. attribute:: vrfipv4
                
                	IPv4 static configuration
                	**type**\:   :py:class:`Vrfipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4>`
                
                .. attribute:: vrfipv6
                
                	IPv6 static configuration
                	**type**\:   :py:class:`Vrfipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6>`
                
                

                """

                _prefix = 'ip-static-cfg'
                _revision = '2015-09-10'

                def __init__(self):
                    super(RouterStatic.Vrfs.Vrf.AddressFamily, self).__init__()

                    self.yang_name = "address-family"
                    self.yang_parent_name = "vrf"

                    self.vrfipv4 = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4()
                    self.vrfipv4.parent = self
                    self._children_name_map["vrfipv4"] = "vrfipv4"
                    self._children_yang_names.add("vrfipv4")

                    self.vrfipv6 = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6()
                    self.vrfipv6.parent = self
                    self._children_name_map["vrfipv6"] = "vrfipv6"
                    self._children_yang_names.add("vrfipv6")


                class Vrfipv4(Entity):
                    """
                    IPv4 static configuration
                    
                    .. attribute:: vrf_multicast
                    
                    	Multicast static configuration
                    	**type**\:   :py:class:`VrfMulticast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast>`
                    
                    .. attribute:: vrf_unicast
                    
                    	Unicast static configuration
                    	**type**\:   :py:class:`VrfUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast>`
                    
                    

                    """

                    _prefix = 'ip-static-cfg'
                    _revision = '2015-09-10'

                    def __init__(self):
                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4, self).__init__()

                        self.yang_name = "vrfipv4"
                        self.yang_parent_name = "address-family"

                        self.vrf_multicast = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast()
                        self.vrf_multicast.parent = self
                        self._children_name_map["vrf_multicast"] = "vrf-multicast"
                        self._children_yang_names.add("vrf-multicast")

                        self.vrf_unicast = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast()
                        self.vrf_unicast.parent = self
                        self._children_name_map["vrf_unicast"] = "vrf-unicast"
                        self._children_yang_names.add("vrf-unicast")


                    class VrfUnicast(Entity):
                        """
                        Unicast static configuration
                        
                        .. attribute:: default_topology
                        
                        	Default topology configuration
                        	**type**\:   :py:class:`DefaultTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology>`
                        
                        .. attribute:: topologies
                        
                        	Topology static configuration container
                        	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies>`
                        
                        .. attribute:: vrf_prefixes
                        
                        	The set of all Static Topologies for this AFI
                        	**type**\:   :py:class:`VrfPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2015-09-10'

                        def __init__(self):
                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast, self).__init__()

                            self.yang_name = "vrf-unicast"
                            self.yang_parent_name = "vrfipv4"

                            self.default_topology = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology()
                            self.default_topology.parent = self
                            self._children_name_map["default_topology"] = "default-topology"
                            self._children_yang_names.add("default-topology")

                            self.topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies()
                            self.topologies.parent = self
                            self._children_name_map["topologies"] = "topologies"
                            self._children_yang_names.add("topologies")

                            self.vrf_prefixes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes()
                            self.vrf_prefixes.parent = self
                            self._children_name_map["vrf_prefixes"] = "vrf-prefixes"
                            self._children_yang_names.add("vrf-prefixes")


                        class Topologies(Entity):
                            """
                            Topology static configuration container
                            
                            .. attribute:: topology
                            
                            	Topology static configuration
                            	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2015-09-10'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies, self).__init__()

                                self.yang_name = "topologies"
                                self.yang_parent_name = "vrf-unicast"

                                self.topology = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies, self).__setattr__(name, value)


                            class Topology(Entity):
                                """
                                Topology static configuration
                                
                                .. attribute:: topology_name  <key>
                                
                                	Topology name
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: vrf_prefix_topologies
                                
                                	The set of all Static Topologies for this AFI
                                	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology, self).__init__()

                                    self.yang_name = "topology"
                                    self.yang_parent_name = "topologies"

                                    self.topology_name = YLeaf(YType.str, "topology-name")

                                    self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies()
                                    self.vrf_prefix_topologies.parent = self
                                    self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                    self._children_yang_names.add("vrf-prefix-topologies")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("topology_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology, self).__setattr__(name, value)


                                class VrfPrefixTopologies(Entity):
                                    """
                                    The set of all Static Topologies for this AFI.
                                    
                                    .. attribute:: vrf_prefix_topology
                                    
                                    	A static route
                                    	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, self).__init__()

                                        self.yang_name = "vrf-prefix-topologies"
                                        self.yang_parent_name = "topology"

                                        self.vrf_prefix_topology = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, self).__setattr__(name, value)


                                    class VrfPrefixTopology(Entity):
                                        """
                                        A static route
                                        
                                        .. attribute:: prefix  <key>
                                        
                                        	Destination prefix
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: prefix_length  <key>
                                        
                                        	Destination prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..128
                                        
                                        .. attribute:: vrf_recurse_routes
                                        
                                        	A recursive next VRF static route
                                        	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                        
                                        .. attribute:: vrf_route
                                        
                                        	A connected or recursive  static route
                                        	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                        
                                        .. attribute:: vrf_seg_route
                                        
                                        	A static segment route
                                        	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                            self.yang_name = "vrf-prefix-topology"
                                            self.yang_parent_name = "vrf-prefix-topologies"

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                            self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                            self.vrf_recurse_routes.parent = self
                                            self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                            self._children_yang_names.add("vrf-recurse-routes")

                                            self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                            self.vrf_route.parent = self
                                            self._children_name_map["vrf_route"] = "vrf-route"
                                            self._children_yang_names.add("vrf-route")

                                            self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                            self.vrf_seg_route.parent = self
                                            self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                            self._children_yang_names.add("vrf-seg-route")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("prefix",
                                                            "prefix_length") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)


                                        class VrfRoute(Entity):
                                            """
                                            A connected or recursive  static route
                                            
                                            .. attribute:: vrf_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                                self.yang_name = "vrf-route"
                                                self.yang_parent_name = "vrf-prefix-topology"

                                                self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                self.vrf_next_hop_table.parent = self
                                                self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                                self._children_yang_names.add("vrf-next-hop-table")


                                            class VrfNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-next-hop-table"
                                                    self.yang_parent_name = "vrf-route"

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-table" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                        for c in self.vrf_next_hop_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_explicit_path_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name"):
                                                        for c in self.vrf_next_hop_interface_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                        for c in self.vrf_next_hop_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_data())

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-route" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-table"):
                                                    if (self.vrf_next_hop_table is None):
                                                        self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                        self.vrf_next_hop_table.parent = self
                                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                                    return self.vrf_next_hop_table

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-table"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class VrfRecurseRoutes(Entity):
                                            """
                                            A recursive next VRF static route
                                            
                                            .. attribute:: vrf_recurse_route
                                            
                                            	A recursive next vrf static route
                                            	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                                self.yang_name = "vrf-recurse-routes"
                                                self.yang_parent_name = "vrf-prefix-topology"

                                                self.vrf_recurse_route = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)


                                            class VrfRecurseRoute(Entity):
                                                """
                                                A recursive next vrf static route
                                                
                                                .. attribute:: vrf_name  <key>
                                                
                                                	Fallback or recusive VRF name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: vrf_recursive_next_hop_table
                                                
                                                	The set of nexthop information configured for this route
                                                	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                    self.yang_name = "vrf-recurse-route"
                                                    self.yang_parent_name = "vrf-recurse-routes"

                                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                    self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                    self.vrf_recursive_next_hop_table.parent = self
                                                    self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                    self._children_yang_names.add("vrf-recursive-next-hop-table")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("vrf_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)


                                                class VrfRecursiveNextHopTable(Entity):
                                                    """
                                                    The set of nexthop information configured for
                                                    this route
                                                    
                                                    .. attribute:: vrf_next_hop_explicit_path_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                    
                                                    .. attribute:: vrf_next_hop_interface_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                    
                                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                    
                                                    .. attribute:: vrf_next_hop_next_hop_address
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                    
                                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                        self.yang_name = "vrf-recursive-next-hop-table"
                                                        self.yang_parent_name = "vrf-recurse-route"

                                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                                        self.vrf_next_hop_interface_name = YList(self)
                                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                        self.vrf_next_hop_next_hop_address = YList(self)
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)


                                                    class VrfNextHopInterfaceName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: interface_name  <key>
                                                        
                                                        	Forwarding interface
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2015-09-10'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-interface-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("interface_name",
                                                                            "bfd_fast_detect",
                                                                            "description",
                                                                            "detect_multiplier",
                                                                            "index",
                                                                            "load_metric",
                                                                            "metric",
                                                                            "minimum_interval",
                                                                            "object_name",
                                                                            "permanent",
                                                                            "tag",
                                                                            "tunnel_id",
                                                                            "vrf_lable") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.interface_name.is_set or
                                                                self.bfd_fast_detect.is_set or
                                                                self.description.is_set or
                                                                self.detect_multiplier.is_set or
                                                                self.index.is_set or
                                                                self.load_metric.is_set or
                                                                self.metric.is_set or
                                                                self.minimum_interval.is_set or
                                                                self.object_name.is_set or
                                                                self.permanent.is_set or
                                                                self.tag.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.vrf_lable.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.interface_name.yfilter != YFilter.not_set or
                                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                                self.description.yfilter != YFilter.not_set or
                                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                                self.index.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                                self.object_name.yfilter != YFilter.not_set or
                                                                self.permanent.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.vrf_lable.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.description.get_name_leafdata())
                                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.index.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "interface-name"):
                                                                self.interface_name = value
                                                                self.interface_name.value_namespace = name_space
                                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "bfd-fast-detect"):
                                                                self.bfd_fast_detect = value
                                                                self.bfd_fast_detect.value_namespace = name_space
                                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "description"):
                                                                self.description = value
                                                                self.description.value_namespace = name_space
                                                                self.description.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "detect-multiplier"):
                                                                self.detect_multiplier = value
                                                                self.detect_multiplier.value_namespace = name_space
                                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "index"):
                                                                self.index = value
                                                                self.index.value_namespace = name_space
                                                                self.index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "minimum-interval"):
                                                                self.minimum_interval = value
                                                                self.minimum_interval.value_namespace = name_space
                                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "object-name"):
                                                                self.object_name = value
                                                                self.object_name.value_namespace = name_space
                                                                self.object_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "permanent"):
                                                                self.permanent = value
                                                                self.permanent.value_namespace = name_space
                                                                self.permanent.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-lable"):
                                                                self.vrf_lable = value
                                                                self.vrf_lable.value_namespace = name_space
                                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: interface_name  <key>
                                                        
                                                        	Forwarding interface
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                        
                                                        .. attribute:: next_hop_address  <key>
                                                        
                                                        	Next hop address
                                                        	**type**\: one of the below types:
                                                        
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2015-09-10'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("interface_name",
                                                                            "next_hop_address",
                                                                            "bfd_fast_detect",
                                                                            "description",
                                                                            "detect_multiplier",
                                                                            "index",
                                                                            "load_metric",
                                                                            "metric",
                                                                            "minimum_interval",
                                                                            "object_name",
                                                                            "permanent",
                                                                            "tag",
                                                                            "tunnel_id",
                                                                            "vrf_lable") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.interface_name.is_set or
                                                                self.next_hop_address.is_set or
                                                                self.bfd_fast_detect.is_set or
                                                                self.description.is_set or
                                                                self.detect_multiplier.is_set or
                                                                self.index.is_set or
                                                                self.load_metric.is_set or
                                                                self.metric.is_set or
                                                                self.minimum_interval.is_set or
                                                                self.object_name.is_set or
                                                                self.permanent.is_set or
                                                                self.tag.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.vrf_lable.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.interface_name.yfilter != YFilter.not_set or
                                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                                self.description.yfilter != YFilter.not_set or
                                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                                self.index.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                                self.object_name.yfilter != YFilter.not_set or
                                                                self.permanent.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.vrf_lable.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.description.get_name_leafdata())
                                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.index.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "interface-name"):
                                                                self.interface_name = value
                                                                self.interface_name.value_namespace = name_space
                                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-address"):
                                                                self.next_hop_address = value
                                                                self.next_hop_address.value_namespace = name_space
                                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "bfd-fast-detect"):
                                                                self.bfd_fast_detect = value
                                                                self.bfd_fast_detect.value_namespace = name_space
                                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "description"):
                                                                self.description = value
                                                                self.description.value_namespace = name_space
                                                                self.description.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "detect-multiplier"):
                                                                self.detect_multiplier = value
                                                                self.detect_multiplier.value_namespace = name_space
                                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "index"):
                                                                self.index = value
                                                                self.index.value_namespace = name_space
                                                                self.index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "minimum-interval"):
                                                                self.minimum_interval = value
                                                                self.minimum_interval.value_namespace = name_space
                                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "object-name"):
                                                                self.object_name = value
                                                                self.object_name.value_namespace = name_space
                                                                self.object_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "permanent"):
                                                                self.permanent = value
                                                                self.permanent.value_namespace = name_space
                                                                self.permanent.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-lable"):
                                                                self.vrf_lable = value
                                                                self.vrf_lable.value_namespace = name_space
                                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                    class VrfNextHopNextHopAddress(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: next_hop_address  <key>
                                                        
                                                        	Next hop address
                                                        	**type**\: one of the below types:
                                                        
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2015-09-10'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("next_hop_address",
                                                                            "bfd_fast_detect",
                                                                            "description",
                                                                            "detect_multiplier",
                                                                            "index",
                                                                            "load_metric",
                                                                            "metric",
                                                                            "minimum_interval",
                                                                            "object_name",
                                                                            "permanent",
                                                                            "tag",
                                                                            "tunnel_id",
                                                                            "vrf_lable") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.next_hop_address.is_set or
                                                                self.bfd_fast_detect.is_set or
                                                                self.description.is_set or
                                                                self.detect_multiplier.is_set or
                                                                self.index.is_set or
                                                                self.load_metric.is_set or
                                                                self.metric.is_set or
                                                                self.minimum_interval.is_set or
                                                                self.object_name.is_set or
                                                                self.permanent.is_set or
                                                                self.tag.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.vrf_lable.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                                self.description.yfilter != YFilter.not_set or
                                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                                self.index.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                                self.object_name.yfilter != YFilter.not_set or
                                                                self.permanent.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.vrf_lable.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.description.get_name_leafdata())
                                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.index.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "next-hop-address"):
                                                                self.next_hop_address = value
                                                                self.next_hop_address.value_namespace = name_space
                                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "bfd-fast-detect"):
                                                                self.bfd_fast_detect = value
                                                                self.bfd_fast_detect.value_namespace = name_space
                                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "description"):
                                                                self.description = value
                                                                self.description.value_namespace = name_space
                                                                self.description.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "detect-multiplier"):
                                                                self.detect_multiplier = value
                                                                self.detect_multiplier.value_namespace = name_space
                                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "index"):
                                                                self.index = value
                                                                self.index.value_namespace = name_space
                                                                self.index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "minimum-interval"):
                                                                self.minimum_interval = value
                                                                self.minimum_interval.value_namespace = name_space
                                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "object-name"):
                                                                self.object_name = value
                                                                self.object_name.value_namespace = name_space
                                                                self.object_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "permanent"):
                                                                self.permanent = value
                                                                self.permanent.value_namespace = name_space
                                                                self.permanent.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-lable"):
                                                                self.vrf_lable = value
                                                                self.vrf_lable.value_namespace = name_space
                                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: next_hop_address  <key>
                                                        
                                                        	Next hop address
                                                        	**type**\: one of the below types:
                                                        
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        .. attribute:: explicit_path_name  <key>
                                                        
                                                        	Segment Routing mpls path name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2015-09-10'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("next_hop_address",
                                                                            "explicit_path_name",
                                                                            "bfd_fast_detect",
                                                                            "description",
                                                                            "detect_multiplier",
                                                                            "index",
                                                                            "load_metric",
                                                                            "metric",
                                                                            "minimum_interval",
                                                                            "object_name",
                                                                            "permanent",
                                                                            "tag",
                                                                            "tunnel_id",
                                                                            "vrf_lable") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.next_hop_address.is_set or
                                                                self.explicit_path_name.is_set or
                                                                self.bfd_fast_detect.is_set or
                                                                self.description.is_set or
                                                                self.detect_multiplier.is_set or
                                                                self.index.is_set or
                                                                self.load_metric.is_set or
                                                                self.metric.is_set or
                                                                self.minimum_interval.is_set or
                                                                self.object_name.is_set or
                                                                self.permanent.is_set or
                                                                self.tag.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.vrf_lable.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                                self.explicit_path_name.yfilter != YFilter.not_set or
                                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                                self.description.yfilter != YFilter.not_set or
                                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                                self.index.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                                self.object_name.yfilter != YFilter.not_set or
                                                                self.permanent.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.vrf_lable.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                            if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.description.get_name_leafdata())
                                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.index.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "next-hop-address"):
                                                                self.next_hop_address = value
                                                                self.next_hop_address.value_namespace = name_space
                                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "explicit-path-name"):
                                                                self.explicit_path_name = value
                                                                self.explicit_path_name.value_namespace = name_space
                                                                self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "bfd-fast-detect"):
                                                                self.bfd_fast_detect = value
                                                                self.bfd_fast_detect.value_namespace = name_space
                                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "description"):
                                                                self.description = value
                                                                self.description.value_namespace = name_space
                                                                self.description.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "detect-multiplier"):
                                                                self.detect_multiplier = value
                                                                self.detect_multiplier.value_namespace = name_space
                                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "index"):
                                                                self.index = value
                                                                self.index.value_namespace = name_space
                                                                self.index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "minimum-interval"):
                                                                self.minimum_interval = value
                                                                self.minimum_interval.value_namespace = name_space
                                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "object-name"):
                                                                self.object_name = value
                                                                self.object_name.value_namespace = name_space
                                                                self.object_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "permanent"):
                                                                self.permanent = value
                                                                self.permanent.value_namespace = name_space
                                                                self.permanent.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-lable"):
                                                                self.vrf_lable = value
                                                                self.vrf_lable.value_namespace = name_space
                                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                    class VrfNextHopExplicitPathName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: explicit_path_name  <key>
                                                        
                                                        	Segment Routing mpls path name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2015-09-10'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("explicit_path_name",
                                                                            "bfd_fast_detect",
                                                                            "description",
                                                                            "detect_multiplier",
                                                                            "index",
                                                                            "load_metric",
                                                                            "metric",
                                                                            "minimum_interval",
                                                                            "object_name",
                                                                            "permanent",
                                                                            "tag",
                                                                            "tunnel_id",
                                                                            "vrf_lable") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.explicit_path_name.is_set or
                                                                self.bfd_fast_detect.is_set or
                                                                self.description.is_set or
                                                                self.detect_multiplier.is_set or
                                                                self.index.is_set or
                                                                self.load_metric.is_set or
                                                                self.metric.is_set or
                                                                self.minimum_interval.is_set or
                                                                self.object_name.is_set or
                                                                self.permanent.is_set or
                                                                self.tag.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.vrf_lable.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.explicit_path_name.yfilter != YFilter.not_set or
                                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                                self.description.yfilter != YFilter.not_set or
                                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                                self.index.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                                self.object_name.yfilter != YFilter.not_set or
                                                                self.permanent.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.vrf_lable.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.description.get_name_leafdata())
                                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.index.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "explicit-path-name"):
                                                                self.explicit_path_name = value
                                                                self.explicit_path_name.value_namespace = name_space
                                                                self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "bfd-fast-detect"):
                                                                self.bfd_fast_detect = value
                                                                self.bfd_fast_detect.value_namespace = name_space
                                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "description"):
                                                                self.description = value
                                                                self.description.value_namespace = name_space
                                                                self.description.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "detect-multiplier"):
                                                                self.detect_multiplier = value
                                                                self.detect_multiplier.value_namespace = name_space
                                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "index"):
                                                                self.index = value
                                                                self.index.value_namespace = name_space
                                                                self.index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "minimum-interval"):
                                                                self.minimum_interval = value
                                                                self.minimum_interval.value_namespace = name_space
                                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "object-name"):
                                                                self.object_name = value
                                                                self.object_name.value_namespace = name_space
                                                                self.object_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "permanent"):
                                                                self.permanent = value
                                                                self.permanent.value_namespace = name_space
                                                                self.permanent.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-lable"):
                                                                self.vrf_lable = value
                                                                self.vrf_lable.value_namespace = name_space
                                                                self.vrf_lable.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.vrf_next_hop_explicit_path_name:
                                                            if (c.has_data()):
                                                                return True
                                                        for c in self.vrf_next_hop_interface_name:
                                                            if (c.has_data()):
                                                                return True
                                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                            if (c.has_data()):
                                                                return True
                                                        for c in self.vrf_next_hop_next_hop_address:
                                                            if (c.has_data()):
                                                                return True
                                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.vrf_next_hop_explicit_path_name:
                                                            if (c.has_operation()):
                                                                return True
                                                        for c in self.vrf_next_hop_interface_name:
                                                            if (c.has_operation()):
                                                                return True
                                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                            if (c.has_operation()):
                                                                return True
                                                        for c in self.vrf_next_hop_next_hop_address:
                                                            if (c.has_operation()):
                                                                return True
                                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-recursive-next-hop-table" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                            for c in self.vrf_next_hop_explicit_path_name:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.vrf_next_hop_explicit_path_name.append(c)
                                                            return c

                                                        if (child_yang_name == "vrf-next-hop-interface-name"):
                                                            for c in self.vrf_next_hop_interface_name:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.vrf_next_hop_interface_name.append(c)
                                                            return c

                                                        if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                            return c

                                                        if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                            for c in self.vrf_next_hop_next_hop_address:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.vrf_next_hop_next_hop_address.append(c)
                                                            return c

                                                        if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        self.vrf_name.is_set or
                                                        (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.vrf_name.yfilter != YFilter.not_set or
                                                        (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "vrf-recursive-next-hop-table"):
                                                        if (self.vrf_recursive_next_hop_table is None):
                                                            self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                            self.vrf_recursive_next_hop_table.parent = self
                                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                        return self.vrf_recursive_next_hop_table

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "vrf-recursive-next-hop-table" or name == "vrf-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "vrf-name"):
                                                        self.vrf_name = value
                                                        self.vrf_name.value_namespace = name_space
                                                        self.vrf_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_recurse_route:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_recurse_route:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-recurse-routes" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-recurse-route"):
                                                    for c in self.vrf_recurse_route:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_recurse_route.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-recurse-route"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class VrfSegRoute(Entity):
                                            """
                                            A static segment route
                                            
                                            .. attribute:: segment_route_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                                self.yang_name = "vrf-seg-route"
                                                self.yang_parent_name = "vrf-prefix-topology"

                                                self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                self.segment_route_next_hop_table.parent = self
                                                self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                                self._children_yang_names.add("segment-route-next-hop-table")


                                            class SegmentRouteNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                    self.yang_name = "segment-route-next-hop-table"
                                                    self.yang_parent_name = "vrf-seg-route"

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "segment-route-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "segment-route-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "segment-route-next-hop-table" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                        for c in self.vrf_next_hop_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_explicit_path_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name"):
                                                        for c in self.vrf_next_hop_interface_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                        for c in self.vrf_next_hop_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_data())

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-seg-route" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "segment-route-next-hop-table"):
                                                    if (self.segment_route_next_hop_table is None):
                                                        self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                        self.segment_route_next_hop_table.parent = self
                                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                                    return self.segment_route_next_hop_table

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "segment-route-next-hop-table"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.prefix.is_set or
                                                self.prefix_length.is_set or
                                                (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_data()) or
                                                (self.vrf_route is not None and self.vrf_route.has_data()) or
                                                (self.vrf_seg_route is not None and self.vrf_seg_route.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.prefix.yfilter != YFilter.not_set or
                                                self.prefix_length.yfilter != YFilter.not_set or
                                                (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_operation()) or
                                                (self.vrf_route is not None and self.vrf_route.has_operation()) or
                                                (self.vrf_seg_route is not None and self.vrf_seg_route.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-recurse-routes"):
                                                if (self.vrf_recurse_routes is None):
                                                    self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                                    self.vrf_recurse_routes.parent = self
                                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                                return self.vrf_recurse_routes

                                            if (child_yang_name == "vrf-route"):
                                                if (self.vrf_route is None):
                                                    self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                                    self.vrf_route.parent = self
                                                    self._children_name_map["vrf_route"] = "vrf-route"
                                                return self.vrf_route

                                            if (child_yang_name == "vrf-seg-route"):
                                                if (self.vrf_seg_route is None):
                                                    self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                                    self.vrf_seg_route.parent = self
                                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                                return self.vrf_seg_route

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-recurse-routes" or name == "vrf-route" or name == "vrf-seg-route" or name == "prefix" or name == "prefix-length"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "prefix"):
                                                self.prefix = value
                                                self.prefix.value_namespace = name_space
                                                self.prefix.value_namespace_prefix = name_space_prefix
                                            if(value_path == "prefix-length"):
                                                self.prefix_length = value
                                                self.prefix_length.value_namespace = name_space
                                                self.prefix_length.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vrf_prefix_topology:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.vrf_prefix_topology:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-prefix-topologies" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-prefix-topology"):
                                            for c in self.vrf_prefix_topology:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_prefix_topology.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-prefix-topology"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.topology_name.is_set or
                                        (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.topology_name.yfilter != YFilter.not_set or
                                        (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "topology" + "[topology-name='" + self.topology_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.topology_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-prefix-topologies"):
                                        if (self.vrf_prefix_topologies is None):
                                            self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies()
                                            self.vrf_prefix_topologies.parent = self
                                            self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                        return self.vrf_prefix_topologies

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-prefix-topologies" or name == "topology-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "topology-name"):
                                        self.topology_name = value
                                        self.topology_name.value_namespace = name_space
                                        self.topology_name.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.topology:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.topology:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "topologies" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "topology"):
                                    for c in self.topology:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.topology.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "topology"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class VrfPrefixes(Entity):
                            """
                            The set of all Static Topologies for this AFI.
                            
                            .. attribute:: vrf_prefix
                            
                            	A static route
                            	**type**\: list of    :py:class:`VrfPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2015-09-10'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes, self).__init__()

                                self.yang_name = "vrf-prefixes"
                                self.yang_parent_name = "vrf-unicast"

                                self.vrf_prefix = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes, self).__setattr__(name, value)


                            class VrfPrefix(Entity):
                                """
                                A static route
                                
                                .. attribute:: prefix  <key>
                                
                                	Destination prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: prefix_length  <key>
                                
                                	Destination prefix length
                                	**type**\:  int
                                
                                	**range:** 0..128
                                
                                .. attribute:: vrf_recurse_routes
                                
                                	A recursive next VRF static route
                                	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes>`
                                
                                .. attribute:: vrf_route
                                
                                	A connected or recursive  static route
                                	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute>`
                                
                                .. attribute:: vrf_seg_route
                                
                                	A static segment route
                                	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix, self).__init__()

                                    self.yang_name = "vrf-prefix"
                                    self.yang_parent_name = "vrf-prefixes"

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                    self.vrf_recurse_routes.parent = self
                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                    self._children_yang_names.add("vrf-recurse-routes")

                                    self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute()
                                    self.vrf_route.parent = self
                                    self._children_name_map["vrf_route"] = "vrf-route"
                                    self._children_yang_names.add("vrf-route")

                                    self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                    self.vrf_seg_route.parent = self
                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    self._children_yang_names.add("vrf-seg-route")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("prefix",
                                                    "prefix_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix, self).__setattr__(name, value)


                                class VrfRoute(Entity):
                                    """
                                    A connected or recursive  static route
                                    
                                    .. attribute:: vrf_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute, self).__init__()

                                        self.yang_name = "vrf-route"
                                        self.yang_parent_name = "vrf-prefix"

                                        self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                        self.vrf_next_hop_table.parent = self
                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        self._children_yang_names.add("vrf-next-hop-table")


                                    class VrfNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__init__()

                                            self.yang_name = "vrf-next-hop-table"
                                            self.yang_parent_name = "vrf-route"

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-table" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_explicit_path_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name"):
                                                for c in self.vrf_next_hop_interface_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_data())

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-route" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-next-hop-table"):
                                            if (self.vrf_next_hop_table is None):
                                                self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                                self.vrf_next_hop_table.parent = self
                                                self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            return self.vrf_next_hop_table

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-next-hop-table"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class VrfRecurseRoutes(Entity):
                                    """
                                    A recursive next VRF static route
                                    
                                    .. attribute:: vrf_recurse_route
                                    
                                    	A recursive next vrf static route
                                    	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__init__()

                                        self.yang_name = "vrf-recurse-routes"
                                        self.yang_parent_name = "vrf-prefix"

                                        self.vrf_recurse_route = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__setattr__(name, value)


                                    class VrfRecurseRoute(Entity):
                                        """
                                        A recursive next vrf static route
                                        
                                        .. attribute:: vrf_name  <key>
                                        
                                        	Fallback or recusive VRF name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: vrf_recursive_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                            self.yang_name = "vrf-recurse-route"
                                            self.yang_parent_name = "vrf-recurse-routes"

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                            self.vrf_recursive_next_hop_table.parent = self
                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            self._children_yang_names.add("vrf-recursive-next-hop-table")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vrf_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)


                                        class VrfRecursiveNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                self.yang_name = "vrf-recursive-next-hop-table"
                                                self.yang_parent_name = "vrf-recurse-route"

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-recursive-next-hop-table" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_explicit_path_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name"):
                                                    for c in self.vrf_next_hop_interface_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.vrf_name.is_set or
                                                (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vrf_name.yfilter != YFilter.not_set or
                                                (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-recursive-next-hop-table"):
                                                if (self.vrf_recursive_next_hop_table is None):
                                                    self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                    self.vrf_recursive_next_hop_table.parent = self
                                                    self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                return self.vrf_recursive_next_hop_table

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-recursive-next-hop-table" or name == "vrf-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vrf-name"):
                                                self.vrf_name = value
                                                self.vrf_name.value_namespace = name_space
                                                self.vrf_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vrf_recurse_route:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.vrf_recurse_route:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-recurse-routes" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-recurse-route"):
                                            for c in self.vrf_recurse_route:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_recurse_route.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-recurse-route"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class VrfSegRoute(Entity):
                                    """
                                    A static segment route
                                    
                                    .. attribute:: segment_route_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute, self).__init__()

                                        self.yang_name = "vrf-seg-route"
                                        self.yang_parent_name = "vrf-prefix"

                                        self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                        self.segment_route_next_hop_table.parent = self
                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        self._children_yang_names.add("segment-route-next-hop-table")


                                    class SegmentRouteNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                            self.yang_name = "segment-route-next-hop-table"
                                            self.yang_parent_name = "vrf-seg-route"

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "segment-route-next-hop-table" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_explicit_path_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name"):
                                                for c in self.vrf_next_hop_interface_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_data())

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-seg-route" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "segment-route-next-hop-table"):
                                            if (self.segment_route_next_hop_table is None):
                                                self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                                self.segment_route_next_hop_table.parent = self
                                                self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            return self.segment_route_next_hop_table

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "segment-route-next-hop-table"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.prefix.is_set or
                                        self.prefix_length.is_set or
                                        (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_data()) or
                                        (self.vrf_route is not None and self.vrf_route.has_data()) or
                                        (self.vrf_seg_route is not None and self.vrf_seg_route.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.prefix.yfilter != YFilter.not_set or
                                        self.prefix_length.yfilter != YFilter.not_set or
                                        (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_operation()) or
                                        (self.vrf_route is not None and self.vrf_route.has_operation()) or
                                        (self.vrf_seg_route is not None and self.vrf_seg_route.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-prefix" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-recurse-routes"):
                                        if (self.vrf_recurse_routes is None):
                                            self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                            self.vrf_recurse_routes.parent = self
                                            self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                        return self.vrf_recurse_routes

                                    if (child_yang_name == "vrf-route"):
                                        if (self.vrf_route is None):
                                            self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute()
                                            self.vrf_route.parent = self
                                            self._children_name_map["vrf_route"] = "vrf-route"
                                        return self.vrf_route

                                    if (child_yang_name == "vrf-seg-route"):
                                        if (self.vrf_seg_route is None):
                                            self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                            self.vrf_seg_route.parent = self
                                            self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        return self.vrf_seg_route

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-recurse-routes" or name == "vrf-route" or name == "vrf-seg-route" or name == "prefix" or name == "prefix-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "prefix"):
                                        self.prefix = value
                                        self.prefix.value_namespace = name_space
                                        self.prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-length"):
                                        self.prefix_length = value
                                        self.prefix_length.value_namespace = name_space
                                        self.prefix_length.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.vrf_prefix:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.vrf_prefix:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vrf-prefixes" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "vrf-prefix"):
                                    for c in self.vrf_prefix:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.vrf_prefix.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "vrf-prefix"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class DefaultTopology(Entity):
                            """
                            Default topology configuration
                            
                            .. attribute:: vrf_prefix_topologies
                            
                            	The set of all Static Topologies for this AFI
                            	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2015-09-10'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology, self).__init__()

                                self.yang_name = "default-topology"
                                self.yang_parent_name = "vrf-unicast"

                                self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies()
                                self.vrf_prefix_topologies.parent = self
                                self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                self._children_yang_names.add("vrf-prefix-topologies")


                            class VrfPrefixTopologies(Entity):
                                """
                                The set of all Static Topologies for this AFI.
                                
                                .. attribute:: vrf_prefix_topology
                                
                                	A static route
                                	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies, self).__init__()

                                    self.yang_name = "vrf-prefix-topologies"
                                    self.yang_parent_name = "default-topology"

                                    self.vrf_prefix_topology = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies, self).__setattr__(name, value)


                                class VrfPrefixTopology(Entity):
                                    """
                                    A static route
                                    
                                    .. attribute:: prefix  <key>
                                    
                                    	Destination prefix
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: prefix_length  <key>
                                    
                                    	Destination prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: vrf_recurse_routes
                                    
                                    	A recursive next VRF static route
                                    	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                    
                                    .. attribute:: vrf_route
                                    
                                    	A connected or recursive  static route
                                    	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                    
                                    .. attribute:: vrf_seg_route
                                    
                                    	A static segment route
                                    	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                        self.yang_name = "vrf-prefix-topology"
                                        self.yang_parent_name = "vrf-prefix-topologies"

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                        self._children_yang_names.add("vrf-recurse-routes")

                                        self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"
                                        self._children_yang_names.add("vrf-route")

                                        self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        self._children_yang_names.add("vrf-seg-route")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("prefix",
                                                        "prefix_length") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)


                                    class VrfRoute(Entity):
                                        """
                                        A connected or recursive  static route
                                        
                                        .. attribute:: vrf_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                            self.yang_name = "vrf-route"
                                            self.yang_parent_name = "vrf-prefix-topology"

                                            self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            self._children_yang_names.add("vrf-next-hop-table")


                                        class VrfNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                self.yang_name = "vrf-next-hop-table"
                                                self.yang_parent_name = "vrf-route"

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-table" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_explicit_path_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name"):
                                                    for c in self.vrf_next_hop_interface_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_data())

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-route" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-table"):
                                                if (self.vrf_next_hop_table is None):
                                                    self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                    self.vrf_next_hop_table.parent = self
                                                    self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                                return self.vrf_next_hop_table

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-table"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class VrfRecurseRoutes(Entity):
                                        """
                                        A recursive next VRF static route
                                        
                                        .. attribute:: vrf_recurse_route
                                        
                                        	A recursive next vrf static route
                                        	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                            self.yang_name = "vrf-recurse-routes"
                                            self.yang_parent_name = "vrf-prefix-topology"

                                            self.vrf_recurse_route = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)


                                        class VrfRecurseRoute(Entity):
                                            """
                                            A recursive next vrf static route
                                            
                                            .. attribute:: vrf_name  <key>
                                            
                                            	Fallback or recusive VRF name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: vrf_recursive_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                self.yang_name = "vrf-recurse-route"
                                                self.yang_parent_name = "vrf-recurse-routes"

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                self._children_yang_names.add("vrf-recursive-next-hop-table")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("vrf_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)


                                            class VrfRecursiveNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-recursive-next-hop-table"
                                                    self.yang_parent_name = "vrf-recurse-route"

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-recursive-next-hop-table" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                        for c in self.vrf_next_hop_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_explicit_path_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name"):
                                                        for c in self.vrf_next_hop_interface_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                        for c in self.vrf_next_hop_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.vrf_name.is_set or
                                                    (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.vrf_name.yfilter != YFilter.not_set or
                                                    (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-recursive-next-hop-table"):
                                                    if (self.vrf_recursive_next_hop_table is None):
                                                        self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                        self.vrf_recursive_next_hop_table.parent = self
                                                        self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                    return self.vrf_recursive_next_hop_table

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-recursive-next-hop-table" or name == "vrf-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "vrf-name"):
                                                    self.vrf_name = value
                                                    self.vrf_name.value_namespace = name_space
                                                    self.vrf_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_recurse_route:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_recurse_route:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-recurse-routes" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-recurse-route"):
                                                for c in self.vrf_recurse_route:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_recurse_route.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-recurse-route"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class VrfSegRoute(Entity):
                                        """
                                        A static segment route
                                        
                                        .. attribute:: segment_route_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                            self.yang_name = "vrf-seg-route"
                                            self.yang_parent_name = "vrf-prefix-topology"

                                            self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            self._children_yang_names.add("segment-route-next-hop-table")


                                        class SegmentRouteNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                self.yang_name = "segment-route-next-hop-table"
                                                self.yang_parent_name = "vrf-seg-route"

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "segment-route-next-hop-table" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_explicit_path_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name"):
                                                    for c in self.vrf_next_hop_interface_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_data())

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-seg-route" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "segment-route-next-hop-table"):
                                                if (self.segment_route_next_hop_table is None):
                                                    self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                    self.segment_route_next_hop_table.parent = self
                                                    self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                                return self.segment_route_next_hop_table

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "segment-route-next-hop-table"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.prefix.is_set or
                                            self.prefix_length.is_set or
                                            (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_data()) or
                                            (self.vrf_route is not None and self.vrf_route.has_data()) or
                                            (self.vrf_seg_route is not None and self.vrf_seg_route.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.prefix.yfilter != YFilter.not_set or
                                            self.prefix_length.yfilter != YFilter.not_set or
                                            (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_operation()) or
                                            (self.vrf_route is not None and self.vrf_route.has_operation()) or
                                            (self.vrf_seg_route is not None and self.vrf_seg_route.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix.get_name_leafdata())
                                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-recurse-routes"):
                                            if (self.vrf_recurse_routes is None):
                                                self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                                self.vrf_recurse_routes.parent = self
                                                self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                            return self.vrf_recurse_routes

                                        if (child_yang_name == "vrf-route"):
                                            if (self.vrf_route is None):
                                                self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                                self.vrf_route.parent = self
                                                self._children_name_map["vrf_route"] = "vrf-route"
                                            return self.vrf_route

                                        if (child_yang_name == "vrf-seg-route"):
                                            if (self.vrf_seg_route is None):
                                                self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                                self.vrf_seg_route.parent = self
                                                self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                            return self.vrf_seg_route

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-recurse-routes" or name == "vrf-route" or name == "vrf-seg-route" or name == "prefix" or name == "prefix-length"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "prefix"):
                                            self.prefix = value
                                            self.prefix.value_namespace = name_space
                                            self.prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "prefix-length"):
                                            self.prefix_length = value
                                            self.prefix_length.value_namespace = name_space
                                            self.prefix_length.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vrf_prefix_topology:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.vrf_prefix_topology:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-prefix-topologies" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-prefix-topology"):
                                        for c in self.vrf_prefix_topology:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vrf_prefix_topology.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-prefix-topology"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_data())

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "default-topology" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "vrf-prefix-topologies"):
                                    if (self.vrf_prefix_topologies is None):
                                        self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies()
                                        self.vrf_prefix_topologies.parent = self
                                        self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                    return self.vrf_prefix_topologies

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "vrf-prefix-topologies"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.default_topology is not None and self.default_topology.has_data()) or
                                (self.topologies is not None and self.topologies.has_data()) or
                                (self.vrf_prefixes is not None and self.vrf_prefixes.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.default_topology is not None and self.default_topology.has_operation()) or
                                (self.topologies is not None and self.topologies.has_operation()) or
                                (self.vrf_prefixes is not None and self.vrf_prefixes.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "vrf-unicast" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "default-topology"):
                                if (self.default_topology is None):
                                    self.default_topology = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology()
                                    self.default_topology.parent = self
                                    self._children_name_map["default_topology"] = "default-topology"
                                return self.default_topology

                            if (child_yang_name == "topologies"):
                                if (self.topologies is None):
                                    self.topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies()
                                    self.topologies.parent = self
                                    self._children_name_map["topologies"] = "topologies"
                                return self.topologies

                            if (child_yang_name == "vrf-prefixes"):
                                if (self.vrf_prefixes is None):
                                    self.vrf_prefixes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes()
                                    self.vrf_prefixes.parent = self
                                    self._children_name_map["vrf_prefixes"] = "vrf-prefixes"
                                return self.vrf_prefixes

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "default-topology" or name == "topologies" or name == "vrf-prefixes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class VrfMulticast(Entity):
                        """
                        Multicast static configuration
                        
                        .. attribute:: default_topology
                        
                        	Default topology configuration
                        	**type**\:   :py:class:`DefaultTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology>`
                        
                        .. attribute:: topologies
                        
                        	Topology static configuration container
                        	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies>`
                        
                        .. attribute:: vrf_prefixes
                        
                        	The set of all Static Topologies for this AFI
                        	**type**\:   :py:class:`VrfPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2015-09-10'

                        def __init__(self):
                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast, self).__init__()

                            self.yang_name = "vrf-multicast"
                            self.yang_parent_name = "vrfipv4"

                            self.default_topology = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology()
                            self.default_topology.parent = self
                            self._children_name_map["default_topology"] = "default-topology"
                            self._children_yang_names.add("default-topology")

                            self.topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies()
                            self.topologies.parent = self
                            self._children_name_map["topologies"] = "topologies"
                            self._children_yang_names.add("topologies")

                            self.vrf_prefixes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes()
                            self.vrf_prefixes.parent = self
                            self._children_name_map["vrf_prefixes"] = "vrf-prefixes"
                            self._children_yang_names.add("vrf-prefixes")


                        class Topologies(Entity):
                            """
                            Topology static configuration container
                            
                            .. attribute:: topology
                            
                            	Topology static configuration
                            	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2015-09-10'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies, self).__init__()

                                self.yang_name = "topologies"
                                self.yang_parent_name = "vrf-multicast"

                                self.topology = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies, self).__setattr__(name, value)


                            class Topology(Entity):
                                """
                                Topology static configuration
                                
                                .. attribute:: topology_name  <key>
                                
                                	Topology name
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: vrf_prefix_topologies
                                
                                	The set of all Static Topologies for this AFI
                                	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology, self).__init__()

                                    self.yang_name = "topology"
                                    self.yang_parent_name = "topologies"

                                    self.topology_name = YLeaf(YType.str, "topology-name")

                                    self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies()
                                    self.vrf_prefix_topologies.parent = self
                                    self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                    self._children_yang_names.add("vrf-prefix-topologies")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("topology_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology, self).__setattr__(name, value)


                                class VrfPrefixTopologies(Entity):
                                    """
                                    The set of all Static Topologies for this AFI.
                                    
                                    .. attribute:: vrf_prefix_topology
                                    
                                    	A static route
                                    	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, self).__init__()

                                        self.yang_name = "vrf-prefix-topologies"
                                        self.yang_parent_name = "topology"

                                        self.vrf_prefix_topology = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, self).__setattr__(name, value)


                                    class VrfPrefixTopology(Entity):
                                        """
                                        A static route
                                        
                                        .. attribute:: prefix  <key>
                                        
                                        	Destination prefix
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: prefix_length  <key>
                                        
                                        	Destination prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..128
                                        
                                        .. attribute:: vrf_recurse_routes
                                        
                                        	A recursive next VRF static route
                                        	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                        
                                        .. attribute:: vrf_route
                                        
                                        	A connected or recursive  static route
                                        	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                        
                                        .. attribute:: vrf_seg_route
                                        
                                        	A static segment route
                                        	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                            self.yang_name = "vrf-prefix-topology"
                                            self.yang_parent_name = "vrf-prefix-topologies"

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                            self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                            self.vrf_recurse_routes.parent = self
                                            self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                            self._children_yang_names.add("vrf-recurse-routes")

                                            self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                            self.vrf_route.parent = self
                                            self._children_name_map["vrf_route"] = "vrf-route"
                                            self._children_yang_names.add("vrf-route")

                                            self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                            self.vrf_seg_route.parent = self
                                            self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                            self._children_yang_names.add("vrf-seg-route")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("prefix",
                                                            "prefix_length") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)


                                        class VrfRoute(Entity):
                                            """
                                            A connected or recursive  static route
                                            
                                            .. attribute:: vrf_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                                self.yang_name = "vrf-route"
                                                self.yang_parent_name = "vrf-prefix-topology"

                                                self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                self.vrf_next_hop_table.parent = self
                                                self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                                self._children_yang_names.add("vrf-next-hop-table")


                                            class VrfNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-next-hop-table"
                                                    self.yang_parent_name = "vrf-route"

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-table" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                        for c in self.vrf_next_hop_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_explicit_path_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name"):
                                                        for c in self.vrf_next_hop_interface_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                        for c in self.vrf_next_hop_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_data())

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-route" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-table"):
                                                    if (self.vrf_next_hop_table is None):
                                                        self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                        self.vrf_next_hop_table.parent = self
                                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                                    return self.vrf_next_hop_table

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-table"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class VrfRecurseRoutes(Entity):
                                            """
                                            A recursive next VRF static route
                                            
                                            .. attribute:: vrf_recurse_route
                                            
                                            	A recursive next vrf static route
                                            	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                                self.yang_name = "vrf-recurse-routes"
                                                self.yang_parent_name = "vrf-prefix-topology"

                                                self.vrf_recurse_route = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)


                                            class VrfRecurseRoute(Entity):
                                                """
                                                A recursive next vrf static route
                                                
                                                .. attribute:: vrf_name  <key>
                                                
                                                	Fallback or recusive VRF name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: vrf_recursive_next_hop_table
                                                
                                                	The set of nexthop information configured for this route
                                                	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                    self.yang_name = "vrf-recurse-route"
                                                    self.yang_parent_name = "vrf-recurse-routes"

                                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                    self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                    self.vrf_recursive_next_hop_table.parent = self
                                                    self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                    self._children_yang_names.add("vrf-recursive-next-hop-table")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("vrf_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)


                                                class VrfRecursiveNextHopTable(Entity):
                                                    """
                                                    The set of nexthop information configured for
                                                    this route
                                                    
                                                    .. attribute:: vrf_next_hop_explicit_path_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                    
                                                    .. attribute:: vrf_next_hop_interface_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                    
                                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                    
                                                    .. attribute:: vrf_next_hop_next_hop_address
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                    
                                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                        self.yang_name = "vrf-recursive-next-hop-table"
                                                        self.yang_parent_name = "vrf-recurse-route"

                                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                                        self.vrf_next_hop_interface_name = YList(self)
                                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                        self.vrf_next_hop_next_hop_address = YList(self)
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)


                                                    class VrfNextHopInterfaceName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: interface_name  <key>
                                                        
                                                        	Forwarding interface
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2015-09-10'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-interface-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("interface_name",
                                                                            "bfd_fast_detect",
                                                                            "description",
                                                                            "detect_multiplier",
                                                                            "index",
                                                                            "load_metric",
                                                                            "metric",
                                                                            "minimum_interval",
                                                                            "object_name",
                                                                            "permanent",
                                                                            "tag",
                                                                            "tunnel_id",
                                                                            "vrf_lable") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.interface_name.is_set or
                                                                self.bfd_fast_detect.is_set or
                                                                self.description.is_set or
                                                                self.detect_multiplier.is_set or
                                                                self.index.is_set or
                                                                self.load_metric.is_set or
                                                                self.metric.is_set or
                                                                self.minimum_interval.is_set or
                                                                self.object_name.is_set or
                                                                self.permanent.is_set or
                                                                self.tag.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.vrf_lable.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.interface_name.yfilter != YFilter.not_set or
                                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                                self.description.yfilter != YFilter.not_set or
                                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                                self.index.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                                self.object_name.yfilter != YFilter.not_set or
                                                                self.permanent.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.vrf_lable.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.description.get_name_leafdata())
                                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.index.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "interface-name"):
                                                                self.interface_name = value
                                                                self.interface_name.value_namespace = name_space
                                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "bfd-fast-detect"):
                                                                self.bfd_fast_detect = value
                                                                self.bfd_fast_detect.value_namespace = name_space
                                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "description"):
                                                                self.description = value
                                                                self.description.value_namespace = name_space
                                                                self.description.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "detect-multiplier"):
                                                                self.detect_multiplier = value
                                                                self.detect_multiplier.value_namespace = name_space
                                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "index"):
                                                                self.index = value
                                                                self.index.value_namespace = name_space
                                                                self.index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "minimum-interval"):
                                                                self.minimum_interval = value
                                                                self.minimum_interval.value_namespace = name_space
                                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "object-name"):
                                                                self.object_name = value
                                                                self.object_name.value_namespace = name_space
                                                                self.object_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "permanent"):
                                                                self.permanent = value
                                                                self.permanent.value_namespace = name_space
                                                                self.permanent.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-lable"):
                                                                self.vrf_lable = value
                                                                self.vrf_lable.value_namespace = name_space
                                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: interface_name  <key>
                                                        
                                                        	Forwarding interface
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                        
                                                        .. attribute:: next_hop_address  <key>
                                                        
                                                        	Next hop address
                                                        	**type**\: one of the below types:
                                                        
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2015-09-10'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("interface_name",
                                                                            "next_hop_address",
                                                                            "bfd_fast_detect",
                                                                            "description",
                                                                            "detect_multiplier",
                                                                            "index",
                                                                            "load_metric",
                                                                            "metric",
                                                                            "minimum_interval",
                                                                            "object_name",
                                                                            "permanent",
                                                                            "tag",
                                                                            "tunnel_id",
                                                                            "vrf_lable") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.interface_name.is_set or
                                                                self.next_hop_address.is_set or
                                                                self.bfd_fast_detect.is_set or
                                                                self.description.is_set or
                                                                self.detect_multiplier.is_set or
                                                                self.index.is_set or
                                                                self.load_metric.is_set or
                                                                self.metric.is_set or
                                                                self.minimum_interval.is_set or
                                                                self.object_name.is_set or
                                                                self.permanent.is_set or
                                                                self.tag.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.vrf_lable.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.interface_name.yfilter != YFilter.not_set or
                                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                                self.description.yfilter != YFilter.not_set or
                                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                                self.index.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                                self.object_name.yfilter != YFilter.not_set or
                                                                self.permanent.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.vrf_lable.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.description.get_name_leafdata())
                                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.index.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "interface-name"):
                                                                self.interface_name = value
                                                                self.interface_name.value_namespace = name_space
                                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-address"):
                                                                self.next_hop_address = value
                                                                self.next_hop_address.value_namespace = name_space
                                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "bfd-fast-detect"):
                                                                self.bfd_fast_detect = value
                                                                self.bfd_fast_detect.value_namespace = name_space
                                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "description"):
                                                                self.description = value
                                                                self.description.value_namespace = name_space
                                                                self.description.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "detect-multiplier"):
                                                                self.detect_multiplier = value
                                                                self.detect_multiplier.value_namespace = name_space
                                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "index"):
                                                                self.index = value
                                                                self.index.value_namespace = name_space
                                                                self.index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "minimum-interval"):
                                                                self.minimum_interval = value
                                                                self.minimum_interval.value_namespace = name_space
                                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "object-name"):
                                                                self.object_name = value
                                                                self.object_name.value_namespace = name_space
                                                                self.object_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "permanent"):
                                                                self.permanent = value
                                                                self.permanent.value_namespace = name_space
                                                                self.permanent.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-lable"):
                                                                self.vrf_lable = value
                                                                self.vrf_lable.value_namespace = name_space
                                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                    class VrfNextHopNextHopAddress(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: next_hop_address  <key>
                                                        
                                                        	Next hop address
                                                        	**type**\: one of the below types:
                                                        
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2015-09-10'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("next_hop_address",
                                                                            "bfd_fast_detect",
                                                                            "description",
                                                                            "detect_multiplier",
                                                                            "index",
                                                                            "load_metric",
                                                                            "metric",
                                                                            "minimum_interval",
                                                                            "object_name",
                                                                            "permanent",
                                                                            "tag",
                                                                            "tunnel_id",
                                                                            "vrf_lable") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.next_hop_address.is_set or
                                                                self.bfd_fast_detect.is_set or
                                                                self.description.is_set or
                                                                self.detect_multiplier.is_set or
                                                                self.index.is_set or
                                                                self.load_metric.is_set or
                                                                self.metric.is_set or
                                                                self.minimum_interval.is_set or
                                                                self.object_name.is_set or
                                                                self.permanent.is_set or
                                                                self.tag.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.vrf_lable.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                                self.description.yfilter != YFilter.not_set or
                                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                                self.index.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                                self.object_name.yfilter != YFilter.not_set or
                                                                self.permanent.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.vrf_lable.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.description.get_name_leafdata())
                                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.index.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "next-hop-address"):
                                                                self.next_hop_address = value
                                                                self.next_hop_address.value_namespace = name_space
                                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "bfd-fast-detect"):
                                                                self.bfd_fast_detect = value
                                                                self.bfd_fast_detect.value_namespace = name_space
                                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "description"):
                                                                self.description = value
                                                                self.description.value_namespace = name_space
                                                                self.description.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "detect-multiplier"):
                                                                self.detect_multiplier = value
                                                                self.detect_multiplier.value_namespace = name_space
                                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "index"):
                                                                self.index = value
                                                                self.index.value_namespace = name_space
                                                                self.index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "minimum-interval"):
                                                                self.minimum_interval = value
                                                                self.minimum_interval.value_namespace = name_space
                                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "object-name"):
                                                                self.object_name = value
                                                                self.object_name.value_namespace = name_space
                                                                self.object_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "permanent"):
                                                                self.permanent = value
                                                                self.permanent.value_namespace = name_space
                                                                self.permanent.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-lable"):
                                                                self.vrf_lable = value
                                                                self.vrf_lable.value_namespace = name_space
                                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: next_hop_address  <key>
                                                        
                                                        	Next hop address
                                                        	**type**\: one of the below types:
                                                        
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        .. attribute:: explicit_path_name  <key>
                                                        
                                                        	Segment Routing mpls path name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2015-09-10'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("next_hop_address",
                                                                            "explicit_path_name",
                                                                            "bfd_fast_detect",
                                                                            "description",
                                                                            "detect_multiplier",
                                                                            "index",
                                                                            "load_metric",
                                                                            "metric",
                                                                            "minimum_interval",
                                                                            "object_name",
                                                                            "permanent",
                                                                            "tag",
                                                                            "tunnel_id",
                                                                            "vrf_lable") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.next_hop_address.is_set or
                                                                self.explicit_path_name.is_set or
                                                                self.bfd_fast_detect.is_set or
                                                                self.description.is_set or
                                                                self.detect_multiplier.is_set or
                                                                self.index.is_set or
                                                                self.load_metric.is_set or
                                                                self.metric.is_set or
                                                                self.minimum_interval.is_set or
                                                                self.object_name.is_set or
                                                                self.permanent.is_set or
                                                                self.tag.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.vrf_lable.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                                self.explicit_path_name.yfilter != YFilter.not_set or
                                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                                self.description.yfilter != YFilter.not_set or
                                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                                self.index.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                                self.object_name.yfilter != YFilter.not_set or
                                                                self.permanent.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.vrf_lable.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                            if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.description.get_name_leafdata())
                                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.index.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "next-hop-address"):
                                                                self.next_hop_address = value
                                                                self.next_hop_address.value_namespace = name_space
                                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "explicit-path-name"):
                                                                self.explicit_path_name = value
                                                                self.explicit_path_name.value_namespace = name_space
                                                                self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "bfd-fast-detect"):
                                                                self.bfd_fast_detect = value
                                                                self.bfd_fast_detect.value_namespace = name_space
                                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "description"):
                                                                self.description = value
                                                                self.description.value_namespace = name_space
                                                                self.description.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "detect-multiplier"):
                                                                self.detect_multiplier = value
                                                                self.detect_multiplier.value_namespace = name_space
                                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "index"):
                                                                self.index = value
                                                                self.index.value_namespace = name_space
                                                                self.index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "minimum-interval"):
                                                                self.minimum_interval = value
                                                                self.minimum_interval.value_namespace = name_space
                                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "object-name"):
                                                                self.object_name = value
                                                                self.object_name.value_namespace = name_space
                                                                self.object_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "permanent"):
                                                                self.permanent = value
                                                                self.permanent.value_namespace = name_space
                                                                self.permanent.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-lable"):
                                                                self.vrf_lable = value
                                                                self.vrf_lable.value_namespace = name_space
                                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                    class VrfNextHopExplicitPathName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: explicit_path_name  <key>
                                                        
                                                        	Segment Routing mpls path name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2015-09-10'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("explicit_path_name",
                                                                            "bfd_fast_detect",
                                                                            "description",
                                                                            "detect_multiplier",
                                                                            "index",
                                                                            "load_metric",
                                                                            "metric",
                                                                            "minimum_interval",
                                                                            "object_name",
                                                                            "permanent",
                                                                            "tag",
                                                                            "tunnel_id",
                                                                            "vrf_lable") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.explicit_path_name.is_set or
                                                                self.bfd_fast_detect.is_set or
                                                                self.description.is_set or
                                                                self.detect_multiplier.is_set or
                                                                self.index.is_set or
                                                                self.load_metric.is_set or
                                                                self.metric.is_set or
                                                                self.minimum_interval.is_set or
                                                                self.object_name.is_set or
                                                                self.permanent.is_set or
                                                                self.tag.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.vrf_lable.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.explicit_path_name.yfilter != YFilter.not_set or
                                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                                self.description.yfilter != YFilter.not_set or
                                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                                self.index.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                                self.object_name.yfilter != YFilter.not_set or
                                                                self.permanent.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.vrf_lable.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.description.get_name_leafdata())
                                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.index.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "explicit-path-name"):
                                                                self.explicit_path_name = value
                                                                self.explicit_path_name.value_namespace = name_space
                                                                self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "bfd-fast-detect"):
                                                                self.bfd_fast_detect = value
                                                                self.bfd_fast_detect.value_namespace = name_space
                                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "description"):
                                                                self.description = value
                                                                self.description.value_namespace = name_space
                                                                self.description.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "detect-multiplier"):
                                                                self.detect_multiplier = value
                                                                self.detect_multiplier.value_namespace = name_space
                                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "index"):
                                                                self.index = value
                                                                self.index.value_namespace = name_space
                                                                self.index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "minimum-interval"):
                                                                self.minimum_interval = value
                                                                self.minimum_interval.value_namespace = name_space
                                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "object-name"):
                                                                self.object_name = value
                                                                self.object_name.value_namespace = name_space
                                                                self.object_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "permanent"):
                                                                self.permanent = value
                                                                self.permanent.value_namespace = name_space
                                                                self.permanent.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-lable"):
                                                                self.vrf_lable = value
                                                                self.vrf_lable.value_namespace = name_space
                                                                self.vrf_lable.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.vrf_next_hop_explicit_path_name:
                                                            if (c.has_data()):
                                                                return True
                                                        for c in self.vrf_next_hop_interface_name:
                                                            if (c.has_data()):
                                                                return True
                                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                            if (c.has_data()):
                                                                return True
                                                        for c in self.vrf_next_hop_next_hop_address:
                                                            if (c.has_data()):
                                                                return True
                                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.vrf_next_hop_explicit_path_name:
                                                            if (c.has_operation()):
                                                                return True
                                                        for c in self.vrf_next_hop_interface_name:
                                                            if (c.has_operation()):
                                                                return True
                                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                            if (c.has_operation()):
                                                                return True
                                                        for c in self.vrf_next_hop_next_hop_address:
                                                            if (c.has_operation()):
                                                                return True
                                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-recursive-next-hop-table" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                            for c in self.vrf_next_hop_explicit_path_name:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.vrf_next_hop_explicit_path_name.append(c)
                                                            return c

                                                        if (child_yang_name == "vrf-next-hop-interface-name"):
                                                            for c in self.vrf_next_hop_interface_name:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.vrf_next_hop_interface_name.append(c)
                                                            return c

                                                        if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                            return c

                                                        if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                            for c in self.vrf_next_hop_next_hop_address:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.vrf_next_hop_next_hop_address.append(c)
                                                            return c

                                                        if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        self.vrf_name.is_set or
                                                        (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.vrf_name.yfilter != YFilter.not_set or
                                                        (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "vrf-recursive-next-hop-table"):
                                                        if (self.vrf_recursive_next_hop_table is None):
                                                            self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                            self.vrf_recursive_next_hop_table.parent = self
                                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                        return self.vrf_recursive_next_hop_table

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "vrf-recursive-next-hop-table" or name == "vrf-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "vrf-name"):
                                                        self.vrf_name = value
                                                        self.vrf_name.value_namespace = name_space
                                                        self.vrf_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_recurse_route:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_recurse_route:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-recurse-routes" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-recurse-route"):
                                                    for c in self.vrf_recurse_route:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_recurse_route.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-recurse-route"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class VrfSegRoute(Entity):
                                            """
                                            A static segment route
                                            
                                            .. attribute:: segment_route_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                                self.yang_name = "vrf-seg-route"
                                                self.yang_parent_name = "vrf-prefix-topology"

                                                self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                self.segment_route_next_hop_table.parent = self
                                                self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                                self._children_yang_names.add("segment-route-next-hop-table")


                                            class SegmentRouteNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                    self.yang_name = "segment-route-next-hop-table"
                                                    self.yang_parent_name = "vrf-seg-route"

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "segment-route-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "segment-route-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "segment-route-next-hop-table" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                        for c in self.vrf_next_hop_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_explicit_path_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name"):
                                                        for c in self.vrf_next_hop_interface_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                        for c in self.vrf_next_hop_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_data())

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-seg-route" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "segment-route-next-hop-table"):
                                                    if (self.segment_route_next_hop_table is None):
                                                        self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                        self.segment_route_next_hop_table.parent = self
                                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                                    return self.segment_route_next_hop_table

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "segment-route-next-hop-table"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.prefix.is_set or
                                                self.prefix_length.is_set or
                                                (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_data()) or
                                                (self.vrf_route is not None and self.vrf_route.has_data()) or
                                                (self.vrf_seg_route is not None and self.vrf_seg_route.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.prefix.yfilter != YFilter.not_set or
                                                self.prefix_length.yfilter != YFilter.not_set or
                                                (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_operation()) or
                                                (self.vrf_route is not None and self.vrf_route.has_operation()) or
                                                (self.vrf_seg_route is not None and self.vrf_seg_route.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-recurse-routes"):
                                                if (self.vrf_recurse_routes is None):
                                                    self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                                    self.vrf_recurse_routes.parent = self
                                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                                return self.vrf_recurse_routes

                                            if (child_yang_name == "vrf-route"):
                                                if (self.vrf_route is None):
                                                    self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                                    self.vrf_route.parent = self
                                                    self._children_name_map["vrf_route"] = "vrf-route"
                                                return self.vrf_route

                                            if (child_yang_name == "vrf-seg-route"):
                                                if (self.vrf_seg_route is None):
                                                    self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                                    self.vrf_seg_route.parent = self
                                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                                return self.vrf_seg_route

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-recurse-routes" or name == "vrf-route" or name == "vrf-seg-route" or name == "prefix" or name == "prefix-length"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "prefix"):
                                                self.prefix = value
                                                self.prefix.value_namespace = name_space
                                                self.prefix.value_namespace_prefix = name_space_prefix
                                            if(value_path == "prefix-length"):
                                                self.prefix_length = value
                                                self.prefix_length.value_namespace = name_space
                                                self.prefix_length.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vrf_prefix_topology:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.vrf_prefix_topology:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-prefix-topologies" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-prefix-topology"):
                                            for c in self.vrf_prefix_topology:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_prefix_topology.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-prefix-topology"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.topology_name.is_set or
                                        (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.topology_name.yfilter != YFilter.not_set or
                                        (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "topology" + "[topology-name='" + self.topology_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.topology_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-prefix-topologies"):
                                        if (self.vrf_prefix_topologies is None):
                                            self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies()
                                            self.vrf_prefix_topologies.parent = self
                                            self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                        return self.vrf_prefix_topologies

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-prefix-topologies" or name == "topology-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "topology-name"):
                                        self.topology_name = value
                                        self.topology_name.value_namespace = name_space
                                        self.topology_name.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.topology:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.topology:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "topologies" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "topology"):
                                    for c in self.topology:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.topology.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "topology"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class VrfPrefixes(Entity):
                            """
                            The set of all Static Topologies for this AFI.
                            
                            .. attribute:: vrf_prefix
                            
                            	A static route
                            	**type**\: list of    :py:class:`VrfPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2015-09-10'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes, self).__init__()

                                self.yang_name = "vrf-prefixes"
                                self.yang_parent_name = "vrf-multicast"

                                self.vrf_prefix = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes, self).__setattr__(name, value)


                            class VrfPrefix(Entity):
                                """
                                A static route
                                
                                .. attribute:: prefix  <key>
                                
                                	Destination prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: prefix_length  <key>
                                
                                	Destination prefix length
                                	**type**\:  int
                                
                                	**range:** 0..128
                                
                                .. attribute:: vrf_recurse_routes
                                
                                	A recursive next VRF static route
                                	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes>`
                                
                                .. attribute:: vrf_route
                                
                                	A connected or recursive  static route
                                	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute>`
                                
                                .. attribute:: vrf_seg_route
                                
                                	A static segment route
                                	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix, self).__init__()

                                    self.yang_name = "vrf-prefix"
                                    self.yang_parent_name = "vrf-prefixes"

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                    self.vrf_recurse_routes.parent = self
                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                    self._children_yang_names.add("vrf-recurse-routes")

                                    self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute()
                                    self.vrf_route.parent = self
                                    self._children_name_map["vrf_route"] = "vrf-route"
                                    self._children_yang_names.add("vrf-route")

                                    self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                    self.vrf_seg_route.parent = self
                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    self._children_yang_names.add("vrf-seg-route")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("prefix",
                                                    "prefix_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix, self).__setattr__(name, value)


                                class VrfRoute(Entity):
                                    """
                                    A connected or recursive  static route
                                    
                                    .. attribute:: vrf_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute, self).__init__()

                                        self.yang_name = "vrf-route"
                                        self.yang_parent_name = "vrf-prefix"

                                        self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                        self.vrf_next_hop_table.parent = self
                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        self._children_yang_names.add("vrf-next-hop-table")


                                    class VrfNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__init__()

                                            self.yang_name = "vrf-next-hop-table"
                                            self.yang_parent_name = "vrf-route"

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-table" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_explicit_path_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name"):
                                                for c in self.vrf_next_hop_interface_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_data())

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-route" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-next-hop-table"):
                                            if (self.vrf_next_hop_table is None):
                                                self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                                self.vrf_next_hop_table.parent = self
                                                self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            return self.vrf_next_hop_table

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-next-hop-table"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class VrfRecurseRoutes(Entity):
                                    """
                                    A recursive next VRF static route
                                    
                                    .. attribute:: vrf_recurse_route
                                    
                                    	A recursive next vrf static route
                                    	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__init__()

                                        self.yang_name = "vrf-recurse-routes"
                                        self.yang_parent_name = "vrf-prefix"

                                        self.vrf_recurse_route = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__setattr__(name, value)


                                    class VrfRecurseRoute(Entity):
                                        """
                                        A recursive next vrf static route
                                        
                                        .. attribute:: vrf_name  <key>
                                        
                                        	Fallback or recusive VRF name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: vrf_recursive_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                            self.yang_name = "vrf-recurse-route"
                                            self.yang_parent_name = "vrf-recurse-routes"

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                            self.vrf_recursive_next_hop_table.parent = self
                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            self._children_yang_names.add("vrf-recursive-next-hop-table")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vrf_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)


                                        class VrfRecursiveNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                self.yang_name = "vrf-recursive-next-hop-table"
                                                self.yang_parent_name = "vrf-recurse-route"

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-recursive-next-hop-table" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_explicit_path_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name"):
                                                    for c in self.vrf_next_hop_interface_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.vrf_name.is_set or
                                                (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vrf_name.yfilter != YFilter.not_set or
                                                (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-recursive-next-hop-table"):
                                                if (self.vrf_recursive_next_hop_table is None):
                                                    self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                    self.vrf_recursive_next_hop_table.parent = self
                                                    self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                return self.vrf_recursive_next_hop_table

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-recursive-next-hop-table" or name == "vrf-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vrf-name"):
                                                self.vrf_name = value
                                                self.vrf_name.value_namespace = name_space
                                                self.vrf_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vrf_recurse_route:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.vrf_recurse_route:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-recurse-routes" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-recurse-route"):
                                            for c in self.vrf_recurse_route:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_recurse_route.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-recurse-route"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class VrfSegRoute(Entity):
                                    """
                                    A static segment route
                                    
                                    .. attribute:: segment_route_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute, self).__init__()

                                        self.yang_name = "vrf-seg-route"
                                        self.yang_parent_name = "vrf-prefix"

                                        self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                        self.segment_route_next_hop_table.parent = self
                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        self._children_yang_names.add("segment-route-next-hop-table")


                                    class SegmentRouteNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                            self.yang_name = "segment-route-next-hop-table"
                                            self.yang_parent_name = "vrf-seg-route"

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "segment-route-next-hop-table" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_explicit_path_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name"):
                                                for c in self.vrf_next_hop_interface_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_data())

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-seg-route" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "segment-route-next-hop-table"):
                                            if (self.segment_route_next_hop_table is None):
                                                self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                                self.segment_route_next_hop_table.parent = self
                                                self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            return self.segment_route_next_hop_table

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "segment-route-next-hop-table"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.prefix.is_set or
                                        self.prefix_length.is_set or
                                        (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_data()) or
                                        (self.vrf_route is not None and self.vrf_route.has_data()) or
                                        (self.vrf_seg_route is not None and self.vrf_seg_route.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.prefix.yfilter != YFilter.not_set or
                                        self.prefix_length.yfilter != YFilter.not_set or
                                        (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_operation()) or
                                        (self.vrf_route is not None and self.vrf_route.has_operation()) or
                                        (self.vrf_seg_route is not None and self.vrf_seg_route.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-prefix" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-recurse-routes"):
                                        if (self.vrf_recurse_routes is None):
                                            self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                            self.vrf_recurse_routes.parent = self
                                            self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                        return self.vrf_recurse_routes

                                    if (child_yang_name == "vrf-route"):
                                        if (self.vrf_route is None):
                                            self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute()
                                            self.vrf_route.parent = self
                                            self._children_name_map["vrf_route"] = "vrf-route"
                                        return self.vrf_route

                                    if (child_yang_name == "vrf-seg-route"):
                                        if (self.vrf_seg_route is None):
                                            self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                            self.vrf_seg_route.parent = self
                                            self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        return self.vrf_seg_route

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-recurse-routes" or name == "vrf-route" or name == "vrf-seg-route" or name == "prefix" or name == "prefix-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "prefix"):
                                        self.prefix = value
                                        self.prefix.value_namespace = name_space
                                        self.prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-length"):
                                        self.prefix_length = value
                                        self.prefix_length.value_namespace = name_space
                                        self.prefix_length.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.vrf_prefix:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.vrf_prefix:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vrf-prefixes" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "vrf-prefix"):
                                    for c in self.vrf_prefix:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.vrf_prefix.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "vrf-prefix"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class DefaultTopology(Entity):
                            """
                            Default topology configuration
                            
                            .. attribute:: vrf_prefix_topologies
                            
                            	The set of all Static Topologies for this AFI
                            	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2015-09-10'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology, self).__init__()

                                self.yang_name = "default-topology"
                                self.yang_parent_name = "vrf-multicast"

                                self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies()
                                self.vrf_prefix_topologies.parent = self
                                self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                self._children_yang_names.add("vrf-prefix-topologies")


                            class VrfPrefixTopologies(Entity):
                                """
                                The set of all Static Topologies for this AFI.
                                
                                .. attribute:: vrf_prefix_topology
                                
                                	A static route
                                	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies, self).__init__()

                                    self.yang_name = "vrf-prefix-topologies"
                                    self.yang_parent_name = "default-topology"

                                    self.vrf_prefix_topology = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies, self).__setattr__(name, value)


                                class VrfPrefixTopology(Entity):
                                    """
                                    A static route
                                    
                                    .. attribute:: prefix  <key>
                                    
                                    	Destination prefix
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: prefix_length  <key>
                                    
                                    	Destination prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: vrf_recurse_routes
                                    
                                    	A recursive next VRF static route
                                    	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                    
                                    .. attribute:: vrf_route
                                    
                                    	A connected or recursive  static route
                                    	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                    
                                    .. attribute:: vrf_seg_route
                                    
                                    	A static segment route
                                    	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                        self.yang_name = "vrf-prefix-topology"
                                        self.yang_parent_name = "vrf-prefix-topologies"

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                        self._children_yang_names.add("vrf-recurse-routes")

                                        self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"
                                        self._children_yang_names.add("vrf-route")

                                        self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        self._children_yang_names.add("vrf-seg-route")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("prefix",
                                                        "prefix_length") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)


                                    class VrfRoute(Entity):
                                        """
                                        A connected or recursive  static route
                                        
                                        .. attribute:: vrf_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                            self.yang_name = "vrf-route"
                                            self.yang_parent_name = "vrf-prefix-topology"

                                            self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            self._children_yang_names.add("vrf-next-hop-table")


                                        class VrfNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                self.yang_name = "vrf-next-hop-table"
                                                self.yang_parent_name = "vrf-route"

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-table" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_explicit_path_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name"):
                                                    for c in self.vrf_next_hop_interface_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_data())

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-route" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-table"):
                                                if (self.vrf_next_hop_table is None):
                                                    self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                    self.vrf_next_hop_table.parent = self
                                                    self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                                return self.vrf_next_hop_table

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-table"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class VrfRecurseRoutes(Entity):
                                        """
                                        A recursive next VRF static route
                                        
                                        .. attribute:: vrf_recurse_route
                                        
                                        	A recursive next vrf static route
                                        	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                            self.yang_name = "vrf-recurse-routes"
                                            self.yang_parent_name = "vrf-prefix-topology"

                                            self.vrf_recurse_route = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)


                                        class VrfRecurseRoute(Entity):
                                            """
                                            A recursive next vrf static route
                                            
                                            .. attribute:: vrf_name  <key>
                                            
                                            	Fallback or recusive VRF name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: vrf_recursive_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                self.yang_name = "vrf-recurse-route"
                                                self.yang_parent_name = "vrf-recurse-routes"

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                self._children_yang_names.add("vrf-recursive-next-hop-table")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("vrf_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)


                                            class VrfRecursiveNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-recursive-next-hop-table"
                                                    self.yang_parent_name = "vrf-recurse-route"

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-recursive-next-hop-table" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                        for c in self.vrf_next_hop_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_explicit_path_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name"):
                                                        for c in self.vrf_next_hop_interface_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                        for c in self.vrf_next_hop_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.vrf_name.is_set or
                                                    (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.vrf_name.yfilter != YFilter.not_set or
                                                    (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-recursive-next-hop-table"):
                                                    if (self.vrf_recursive_next_hop_table is None):
                                                        self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                        self.vrf_recursive_next_hop_table.parent = self
                                                        self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                    return self.vrf_recursive_next_hop_table

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-recursive-next-hop-table" or name == "vrf-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "vrf-name"):
                                                    self.vrf_name = value
                                                    self.vrf_name.value_namespace = name_space
                                                    self.vrf_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_recurse_route:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_recurse_route:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-recurse-routes" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-recurse-route"):
                                                for c in self.vrf_recurse_route:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_recurse_route.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-recurse-route"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class VrfSegRoute(Entity):
                                        """
                                        A static segment route
                                        
                                        .. attribute:: segment_route_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                            self.yang_name = "vrf-seg-route"
                                            self.yang_parent_name = "vrf-prefix-topology"

                                            self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            self._children_yang_names.add("segment-route-next-hop-table")


                                        class SegmentRouteNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                self.yang_name = "segment-route-next-hop-table"
                                                self.yang_parent_name = "vrf-seg-route"

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "segment-route-next-hop-table" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_explicit_path_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name"):
                                                    for c in self.vrf_next_hop_interface_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_data())

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-seg-route" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "segment-route-next-hop-table"):
                                                if (self.segment_route_next_hop_table is None):
                                                    self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                    self.segment_route_next_hop_table.parent = self
                                                    self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                                return self.segment_route_next_hop_table

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "segment-route-next-hop-table"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.prefix.is_set or
                                            self.prefix_length.is_set or
                                            (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_data()) or
                                            (self.vrf_route is not None and self.vrf_route.has_data()) or
                                            (self.vrf_seg_route is not None and self.vrf_seg_route.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.prefix.yfilter != YFilter.not_set or
                                            self.prefix_length.yfilter != YFilter.not_set or
                                            (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_operation()) or
                                            (self.vrf_route is not None and self.vrf_route.has_operation()) or
                                            (self.vrf_seg_route is not None and self.vrf_seg_route.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix.get_name_leafdata())
                                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-recurse-routes"):
                                            if (self.vrf_recurse_routes is None):
                                                self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                                self.vrf_recurse_routes.parent = self
                                                self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                            return self.vrf_recurse_routes

                                        if (child_yang_name == "vrf-route"):
                                            if (self.vrf_route is None):
                                                self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                                self.vrf_route.parent = self
                                                self._children_name_map["vrf_route"] = "vrf-route"
                                            return self.vrf_route

                                        if (child_yang_name == "vrf-seg-route"):
                                            if (self.vrf_seg_route is None):
                                                self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                                self.vrf_seg_route.parent = self
                                                self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                            return self.vrf_seg_route

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-recurse-routes" or name == "vrf-route" or name == "vrf-seg-route" or name == "prefix" or name == "prefix-length"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "prefix"):
                                            self.prefix = value
                                            self.prefix.value_namespace = name_space
                                            self.prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "prefix-length"):
                                            self.prefix_length = value
                                            self.prefix_length.value_namespace = name_space
                                            self.prefix_length.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vrf_prefix_topology:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.vrf_prefix_topology:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-prefix-topologies" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-prefix-topology"):
                                        for c in self.vrf_prefix_topology:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vrf_prefix_topology.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-prefix-topology"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_data())

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "default-topology" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "vrf-prefix-topologies"):
                                    if (self.vrf_prefix_topologies is None):
                                        self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies()
                                        self.vrf_prefix_topologies.parent = self
                                        self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                    return self.vrf_prefix_topologies

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "vrf-prefix-topologies"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.default_topology is not None and self.default_topology.has_data()) or
                                (self.topologies is not None and self.topologies.has_data()) or
                                (self.vrf_prefixes is not None and self.vrf_prefixes.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.default_topology is not None and self.default_topology.has_operation()) or
                                (self.topologies is not None and self.topologies.has_operation()) or
                                (self.vrf_prefixes is not None and self.vrf_prefixes.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "vrf-multicast" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "default-topology"):
                                if (self.default_topology is None):
                                    self.default_topology = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology()
                                    self.default_topology.parent = self
                                    self._children_name_map["default_topology"] = "default-topology"
                                return self.default_topology

                            if (child_yang_name == "topologies"):
                                if (self.topologies is None):
                                    self.topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies()
                                    self.topologies.parent = self
                                    self._children_name_map["topologies"] = "topologies"
                                return self.topologies

                            if (child_yang_name == "vrf-prefixes"):
                                if (self.vrf_prefixes is None):
                                    self.vrf_prefixes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes()
                                    self.vrf_prefixes.parent = self
                                    self._children_name_map["vrf_prefixes"] = "vrf-prefixes"
                                return self.vrf_prefixes

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "default-topology" or name == "topologies" or name == "vrf-prefixes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.vrf_multicast is not None and self.vrf_multicast.has_data()) or
                            (self.vrf_unicast is not None and self.vrf_unicast.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.vrf_multicast is not None and self.vrf_multicast.has_operation()) or
                            (self.vrf_unicast is not None and self.vrf_unicast.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "vrfipv4" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "vrf-multicast"):
                            if (self.vrf_multicast is None):
                                self.vrf_multicast = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast()
                                self.vrf_multicast.parent = self
                                self._children_name_map["vrf_multicast"] = "vrf-multicast"
                            return self.vrf_multicast

                        if (child_yang_name == "vrf-unicast"):
                            if (self.vrf_unicast is None):
                                self.vrf_unicast = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast()
                                self.vrf_unicast.parent = self
                                self._children_name_map["vrf_unicast"] = "vrf-unicast"
                            return self.vrf_unicast

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "vrf-multicast" or name == "vrf-unicast"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Vrfipv6(Entity):
                    """
                    IPv6 static configuration
                    
                    .. attribute:: vrf_multicast
                    
                    	Multicast static configuration
                    	**type**\:   :py:class:`VrfMulticast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast>`
                    
                    .. attribute:: vrf_unicast
                    
                    	Unicast static configuration
                    	**type**\:   :py:class:`VrfUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast>`
                    
                    

                    """

                    _prefix = 'ip-static-cfg'
                    _revision = '2015-09-10'

                    def __init__(self):
                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6, self).__init__()

                        self.yang_name = "vrfipv6"
                        self.yang_parent_name = "address-family"

                        self.vrf_multicast = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast()
                        self.vrf_multicast.parent = self
                        self._children_name_map["vrf_multicast"] = "vrf-multicast"
                        self._children_yang_names.add("vrf-multicast")

                        self.vrf_unicast = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast()
                        self.vrf_unicast.parent = self
                        self._children_name_map["vrf_unicast"] = "vrf-unicast"
                        self._children_yang_names.add("vrf-unicast")


                    class VrfUnicast(Entity):
                        """
                        Unicast static configuration
                        
                        .. attribute:: default_topology
                        
                        	Default topology configuration
                        	**type**\:   :py:class:`DefaultTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology>`
                        
                        .. attribute:: topologies
                        
                        	Topology static configuration container
                        	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies>`
                        
                        .. attribute:: vrf_prefixes
                        
                        	The set of all Static Topologies for this AFI
                        	**type**\:   :py:class:`VrfPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2015-09-10'

                        def __init__(self):
                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast, self).__init__()

                            self.yang_name = "vrf-unicast"
                            self.yang_parent_name = "vrfipv6"

                            self.default_topology = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology()
                            self.default_topology.parent = self
                            self._children_name_map["default_topology"] = "default-topology"
                            self._children_yang_names.add("default-topology")

                            self.topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies()
                            self.topologies.parent = self
                            self._children_name_map["topologies"] = "topologies"
                            self._children_yang_names.add("topologies")

                            self.vrf_prefixes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes()
                            self.vrf_prefixes.parent = self
                            self._children_name_map["vrf_prefixes"] = "vrf-prefixes"
                            self._children_yang_names.add("vrf-prefixes")


                        class Topologies(Entity):
                            """
                            Topology static configuration container
                            
                            .. attribute:: topology
                            
                            	Topology static configuration
                            	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2015-09-10'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies, self).__init__()

                                self.yang_name = "topologies"
                                self.yang_parent_name = "vrf-unicast"

                                self.topology = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies, self).__setattr__(name, value)


                            class Topology(Entity):
                                """
                                Topology static configuration
                                
                                .. attribute:: topology_name  <key>
                                
                                	Topology name
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: vrf_prefix_topologies
                                
                                	The set of all Static Topologies for this AFI
                                	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology, self).__init__()

                                    self.yang_name = "topology"
                                    self.yang_parent_name = "topologies"

                                    self.topology_name = YLeaf(YType.str, "topology-name")

                                    self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies()
                                    self.vrf_prefix_topologies.parent = self
                                    self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                    self._children_yang_names.add("vrf-prefix-topologies")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("topology_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology, self).__setattr__(name, value)


                                class VrfPrefixTopologies(Entity):
                                    """
                                    The set of all Static Topologies for this AFI.
                                    
                                    .. attribute:: vrf_prefix_topology
                                    
                                    	A static route
                                    	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, self).__init__()

                                        self.yang_name = "vrf-prefix-topologies"
                                        self.yang_parent_name = "topology"

                                        self.vrf_prefix_topology = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, self).__setattr__(name, value)


                                    class VrfPrefixTopology(Entity):
                                        """
                                        A static route
                                        
                                        .. attribute:: prefix  <key>
                                        
                                        	Destination prefix
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: prefix_length  <key>
                                        
                                        	Destination prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..128
                                        
                                        .. attribute:: vrf_recurse_routes
                                        
                                        	A recursive next VRF static route
                                        	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                        
                                        .. attribute:: vrf_route
                                        
                                        	A connected or recursive  static route
                                        	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                        
                                        .. attribute:: vrf_seg_route
                                        
                                        	A static segment route
                                        	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                            self.yang_name = "vrf-prefix-topology"
                                            self.yang_parent_name = "vrf-prefix-topologies"

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                            self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                            self.vrf_recurse_routes.parent = self
                                            self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                            self._children_yang_names.add("vrf-recurse-routes")

                                            self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                            self.vrf_route.parent = self
                                            self._children_name_map["vrf_route"] = "vrf-route"
                                            self._children_yang_names.add("vrf-route")

                                            self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                            self.vrf_seg_route.parent = self
                                            self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                            self._children_yang_names.add("vrf-seg-route")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("prefix",
                                                            "prefix_length") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)


                                        class VrfRoute(Entity):
                                            """
                                            A connected or recursive  static route
                                            
                                            .. attribute:: vrf_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                                self.yang_name = "vrf-route"
                                                self.yang_parent_name = "vrf-prefix-topology"

                                                self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                self.vrf_next_hop_table.parent = self
                                                self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                                self._children_yang_names.add("vrf-next-hop-table")


                                            class VrfNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-next-hop-table"
                                                    self.yang_parent_name = "vrf-route"

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-table" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                        for c in self.vrf_next_hop_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_explicit_path_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name"):
                                                        for c in self.vrf_next_hop_interface_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                        for c in self.vrf_next_hop_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_data())

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-route" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-table"):
                                                    if (self.vrf_next_hop_table is None):
                                                        self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                        self.vrf_next_hop_table.parent = self
                                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                                    return self.vrf_next_hop_table

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-table"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class VrfRecurseRoutes(Entity):
                                            """
                                            A recursive next VRF static route
                                            
                                            .. attribute:: vrf_recurse_route
                                            
                                            	A recursive next vrf static route
                                            	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                                self.yang_name = "vrf-recurse-routes"
                                                self.yang_parent_name = "vrf-prefix-topology"

                                                self.vrf_recurse_route = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)


                                            class VrfRecurseRoute(Entity):
                                                """
                                                A recursive next vrf static route
                                                
                                                .. attribute:: vrf_name  <key>
                                                
                                                	Fallback or recusive VRF name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: vrf_recursive_next_hop_table
                                                
                                                	The set of nexthop information configured for this route
                                                	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                    self.yang_name = "vrf-recurse-route"
                                                    self.yang_parent_name = "vrf-recurse-routes"

                                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                    self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                    self.vrf_recursive_next_hop_table.parent = self
                                                    self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                    self._children_yang_names.add("vrf-recursive-next-hop-table")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("vrf_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)


                                                class VrfRecursiveNextHopTable(Entity):
                                                    """
                                                    The set of nexthop information configured for
                                                    this route
                                                    
                                                    .. attribute:: vrf_next_hop_explicit_path_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                    
                                                    .. attribute:: vrf_next_hop_interface_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                    
                                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                    
                                                    .. attribute:: vrf_next_hop_next_hop_address
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                    
                                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                        self.yang_name = "vrf-recursive-next-hop-table"
                                                        self.yang_parent_name = "vrf-recurse-route"

                                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                                        self.vrf_next_hop_interface_name = YList(self)
                                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                        self.vrf_next_hop_next_hop_address = YList(self)
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)


                                                    class VrfNextHopInterfaceName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: interface_name  <key>
                                                        
                                                        	Forwarding interface
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2015-09-10'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-interface-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("interface_name",
                                                                            "bfd_fast_detect",
                                                                            "description",
                                                                            "detect_multiplier",
                                                                            "index",
                                                                            "load_metric",
                                                                            "metric",
                                                                            "minimum_interval",
                                                                            "object_name",
                                                                            "permanent",
                                                                            "tag",
                                                                            "tunnel_id",
                                                                            "vrf_lable") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.interface_name.is_set or
                                                                self.bfd_fast_detect.is_set or
                                                                self.description.is_set or
                                                                self.detect_multiplier.is_set or
                                                                self.index.is_set or
                                                                self.load_metric.is_set or
                                                                self.metric.is_set or
                                                                self.minimum_interval.is_set or
                                                                self.object_name.is_set or
                                                                self.permanent.is_set or
                                                                self.tag.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.vrf_lable.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.interface_name.yfilter != YFilter.not_set or
                                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                                self.description.yfilter != YFilter.not_set or
                                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                                self.index.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                                self.object_name.yfilter != YFilter.not_set or
                                                                self.permanent.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.vrf_lable.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.description.get_name_leafdata())
                                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.index.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "interface-name"):
                                                                self.interface_name = value
                                                                self.interface_name.value_namespace = name_space
                                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "bfd-fast-detect"):
                                                                self.bfd_fast_detect = value
                                                                self.bfd_fast_detect.value_namespace = name_space
                                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "description"):
                                                                self.description = value
                                                                self.description.value_namespace = name_space
                                                                self.description.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "detect-multiplier"):
                                                                self.detect_multiplier = value
                                                                self.detect_multiplier.value_namespace = name_space
                                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "index"):
                                                                self.index = value
                                                                self.index.value_namespace = name_space
                                                                self.index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "minimum-interval"):
                                                                self.minimum_interval = value
                                                                self.minimum_interval.value_namespace = name_space
                                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "object-name"):
                                                                self.object_name = value
                                                                self.object_name.value_namespace = name_space
                                                                self.object_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "permanent"):
                                                                self.permanent = value
                                                                self.permanent.value_namespace = name_space
                                                                self.permanent.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-lable"):
                                                                self.vrf_lable = value
                                                                self.vrf_lable.value_namespace = name_space
                                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: interface_name  <key>
                                                        
                                                        	Forwarding interface
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                        
                                                        .. attribute:: next_hop_address  <key>
                                                        
                                                        	Next hop address
                                                        	**type**\: one of the below types:
                                                        
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2015-09-10'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("interface_name",
                                                                            "next_hop_address",
                                                                            "bfd_fast_detect",
                                                                            "description",
                                                                            "detect_multiplier",
                                                                            "index",
                                                                            "load_metric",
                                                                            "metric",
                                                                            "minimum_interval",
                                                                            "object_name",
                                                                            "permanent",
                                                                            "tag",
                                                                            "tunnel_id",
                                                                            "vrf_lable") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.interface_name.is_set or
                                                                self.next_hop_address.is_set or
                                                                self.bfd_fast_detect.is_set or
                                                                self.description.is_set or
                                                                self.detect_multiplier.is_set or
                                                                self.index.is_set or
                                                                self.load_metric.is_set or
                                                                self.metric.is_set or
                                                                self.minimum_interval.is_set or
                                                                self.object_name.is_set or
                                                                self.permanent.is_set or
                                                                self.tag.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.vrf_lable.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.interface_name.yfilter != YFilter.not_set or
                                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                                self.description.yfilter != YFilter.not_set or
                                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                                self.index.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                                self.object_name.yfilter != YFilter.not_set or
                                                                self.permanent.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.vrf_lable.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.description.get_name_leafdata())
                                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.index.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "interface-name"):
                                                                self.interface_name = value
                                                                self.interface_name.value_namespace = name_space
                                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-address"):
                                                                self.next_hop_address = value
                                                                self.next_hop_address.value_namespace = name_space
                                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "bfd-fast-detect"):
                                                                self.bfd_fast_detect = value
                                                                self.bfd_fast_detect.value_namespace = name_space
                                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "description"):
                                                                self.description = value
                                                                self.description.value_namespace = name_space
                                                                self.description.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "detect-multiplier"):
                                                                self.detect_multiplier = value
                                                                self.detect_multiplier.value_namespace = name_space
                                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "index"):
                                                                self.index = value
                                                                self.index.value_namespace = name_space
                                                                self.index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "minimum-interval"):
                                                                self.minimum_interval = value
                                                                self.minimum_interval.value_namespace = name_space
                                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "object-name"):
                                                                self.object_name = value
                                                                self.object_name.value_namespace = name_space
                                                                self.object_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "permanent"):
                                                                self.permanent = value
                                                                self.permanent.value_namespace = name_space
                                                                self.permanent.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-lable"):
                                                                self.vrf_lable = value
                                                                self.vrf_lable.value_namespace = name_space
                                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                    class VrfNextHopNextHopAddress(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: next_hop_address  <key>
                                                        
                                                        	Next hop address
                                                        	**type**\: one of the below types:
                                                        
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2015-09-10'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("next_hop_address",
                                                                            "bfd_fast_detect",
                                                                            "description",
                                                                            "detect_multiplier",
                                                                            "index",
                                                                            "load_metric",
                                                                            "metric",
                                                                            "minimum_interval",
                                                                            "object_name",
                                                                            "permanent",
                                                                            "tag",
                                                                            "tunnel_id",
                                                                            "vrf_lable") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.next_hop_address.is_set or
                                                                self.bfd_fast_detect.is_set or
                                                                self.description.is_set or
                                                                self.detect_multiplier.is_set or
                                                                self.index.is_set or
                                                                self.load_metric.is_set or
                                                                self.metric.is_set or
                                                                self.minimum_interval.is_set or
                                                                self.object_name.is_set or
                                                                self.permanent.is_set or
                                                                self.tag.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.vrf_lable.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                                self.description.yfilter != YFilter.not_set or
                                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                                self.index.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                                self.object_name.yfilter != YFilter.not_set or
                                                                self.permanent.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.vrf_lable.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.description.get_name_leafdata())
                                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.index.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "next-hop-address"):
                                                                self.next_hop_address = value
                                                                self.next_hop_address.value_namespace = name_space
                                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "bfd-fast-detect"):
                                                                self.bfd_fast_detect = value
                                                                self.bfd_fast_detect.value_namespace = name_space
                                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "description"):
                                                                self.description = value
                                                                self.description.value_namespace = name_space
                                                                self.description.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "detect-multiplier"):
                                                                self.detect_multiplier = value
                                                                self.detect_multiplier.value_namespace = name_space
                                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "index"):
                                                                self.index = value
                                                                self.index.value_namespace = name_space
                                                                self.index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "minimum-interval"):
                                                                self.minimum_interval = value
                                                                self.minimum_interval.value_namespace = name_space
                                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "object-name"):
                                                                self.object_name = value
                                                                self.object_name.value_namespace = name_space
                                                                self.object_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "permanent"):
                                                                self.permanent = value
                                                                self.permanent.value_namespace = name_space
                                                                self.permanent.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-lable"):
                                                                self.vrf_lable = value
                                                                self.vrf_lable.value_namespace = name_space
                                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: next_hop_address  <key>
                                                        
                                                        	Next hop address
                                                        	**type**\: one of the below types:
                                                        
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        .. attribute:: explicit_path_name  <key>
                                                        
                                                        	Segment Routing mpls path name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2015-09-10'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("next_hop_address",
                                                                            "explicit_path_name",
                                                                            "bfd_fast_detect",
                                                                            "description",
                                                                            "detect_multiplier",
                                                                            "index",
                                                                            "load_metric",
                                                                            "metric",
                                                                            "minimum_interval",
                                                                            "object_name",
                                                                            "permanent",
                                                                            "tag",
                                                                            "tunnel_id",
                                                                            "vrf_lable") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.next_hop_address.is_set or
                                                                self.explicit_path_name.is_set or
                                                                self.bfd_fast_detect.is_set or
                                                                self.description.is_set or
                                                                self.detect_multiplier.is_set or
                                                                self.index.is_set or
                                                                self.load_metric.is_set or
                                                                self.metric.is_set or
                                                                self.minimum_interval.is_set or
                                                                self.object_name.is_set or
                                                                self.permanent.is_set or
                                                                self.tag.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.vrf_lable.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                                self.explicit_path_name.yfilter != YFilter.not_set or
                                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                                self.description.yfilter != YFilter.not_set or
                                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                                self.index.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                                self.object_name.yfilter != YFilter.not_set or
                                                                self.permanent.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.vrf_lable.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                            if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.description.get_name_leafdata())
                                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.index.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "next-hop-address"):
                                                                self.next_hop_address = value
                                                                self.next_hop_address.value_namespace = name_space
                                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "explicit-path-name"):
                                                                self.explicit_path_name = value
                                                                self.explicit_path_name.value_namespace = name_space
                                                                self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "bfd-fast-detect"):
                                                                self.bfd_fast_detect = value
                                                                self.bfd_fast_detect.value_namespace = name_space
                                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "description"):
                                                                self.description = value
                                                                self.description.value_namespace = name_space
                                                                self.description.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "detect-multiplier"):
                                                                self.detect_multiplier = value
                                                                self.detect_multiplier.value_namespace = name_space
                                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "index"):
                                                                self.index = value
                                                                self.index.value_namespace = name_space
                                                                self.index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "minimum-interval"):
                                                                self.minimum_interval = value
                                                                self.minimum_interval.value_namespace = name_space
                                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "object-name"):
                                                                self.object_name = value
                                                                self.object_name.value_namespace = name_space
                                                                self.object_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "permanent"):
                                                                self.permanent = value
                                                                self.permanent.value_namespace = name_space
                                                                self.permanent.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-lable"):
                                                                self.vrf_lable = value
                                                                self.vrf_lable.value_namespace = name_space
                                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                    class VrfNextHopExplicitPathName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: explicit_path_name  <key>
                                                        
                                                        	Segment Routing mpls path name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2015-09-10'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("explicit_path_name",
                                                                            "bfd_fast_detect",
                                                                            "description",
                                                                            "detect_multiplier",
                                                                            "index",
                                                                            "load_metric",
                                                                            "metric",
                                                                            "minimum_interval",
                                                                            "object_name",
                                                                            "permanent",
                                                                            "tag",
                                                                            "tunnel_id",
                                                                            "vrf_lable") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.explicit_path_name.is_set or
                                                                self.bfd_fast_detect.is_set or
                                                                self.description.is_set or
                                                                self.detect_multiplier.is_set or
                                                                self.index.is_set or
                                                                self.load_metric.is_set or
                                                                self.metric.is_set or
                                                                self.minimum_interval.is_set or
                                                                self.object_name.is_set or
                                                                self.permanent.is_set or
                                                                self.tag.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.vrf_lable.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.explicit_path_name.yfilter != YFilter.not_set or
                                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                                self.description.yfilter != YFilter.not_set or
                                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                                self.index.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                                self.object_name.yfilter != YFilter.not_set or
                                                                self.permanent.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.vrf_lable.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.description.get_name_leafdata())
                                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.index.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "explicit-path-name"):
                                                                self.explicit_path_name = value
                                                                self.explicit_path_name.value_namespace = name_space
                                                                self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "bfd-fast-detect"):
                                                                self.bfd_fast_detect = value
                                                                self.bfd_fast_detect.value_namespace = name_space
                                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "description"):
                                                                self.description = value
                                                                self.description.value_namespace = name_space
                                                                self.description.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "detect-multiplier"):
                                                                self.detect_multiplier = value
                                                                self.detect_multiplier.value_namespace = name_space
                                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "index"):
                                                                self.index = value
                                                                self.index.value_namespace = name_space
                                                                self.index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "minimum-interval"):
                                                                self.minimum_interval = value
                                                                self.minimum_interval.value_namespace = name_space
                                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "object-name"):
                                                                self.object_name = value
                                                                self.object_name.value_namespace = name_space
                                                                self.object_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "permanent"):
                                                                self.permanent = value
                                                                self.permanent.value_namespace = name_space
                                                                self.permanent.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-lable"):
                                                                self.vrf_lable = value
                                                                self.vrf_lable.value_namespace = name_space
                                                                self.vrf_lable.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.vrf_next_hop_explicit_path_name:
                                                            if (c.has_data()):
                                                                return True
                                                        for c in self.vrf_next_hop_interface_name:
                                                            if (c.has_data()):
                                                                return True
                                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                            if (c.has_data()):
                                                                return True
                                                        for c in self.vrf_next_hop_next_hop_address:
                                                            if (c.has_data()):
                                                                return True
                                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.vrf_next_hop_explicit_path_name:
                                                            if (c.has_operation()):
                                                                return True
                                                        for c in self.vrf_next_hop_interface_name:
                                                            if (c.has_operation()):
                                                                return True
                                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                            if (c.has_operation()):
                                                                return True
                                                        for c in self.vrf_next_hop_next_hop_address:
                                                            if (c.has_operation()):
                                                                return True
                                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-recursive-next-hop-table" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                            for c in self.vrf_next_hop_explicit_path_name:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.vrf_next_hop_explicit_path_name.append(c)
                                                            return c

                                                        if (child_yang_name == "vrf-next-hop-interface-name"):
                                                            for c in self.vrf_next_hop_interface_name:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.vrf_next_hop_interface_name.append(c)
                                                            return c

                                                        if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                            return c

                                                        if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                            for c in self.vrf_next_hop_next_hop_address:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.vrf_next_hop_next_hop_address.append(c)
                                                            return c

                                                        if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        self.vrf_name.is_set or
                                                        (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.vrf_name.yfilter != YFilter.not_set or
                                                        (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "vrf-recursive-next-hop-table"):
                                                        if (self.vrf_recursive_next_hop_table is None):
                                                            self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                            self.vrf_recursive_next_hop_table.parent = self
                                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                        return self.vrf_recursive_next_hop_table

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "vrf-recursive-next-hop-table" or name == "vrf-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "vrf-name"):
                                                        self.vrf_name = value
                                                        self.vrf_name.value_namespace = name_space
                                                        self.vrf_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_recurse_route:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_recurse_route:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-recurse-routes" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-recurse-route"):
                                                    for c in self.vrf_recurse_route:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_recurse_route.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-recurse-route"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class VrfSegRoute(Entity):
                                            """
                                            A static segment route
                                            
                                            .. attribute:: segment_route_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                                self.yang_name = "vrf-seg-route"
                                                self.yang_parent_name = "vrf-prefix-topology"

                                                self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                self.segment_route_next_hop_table.parent = self
                                                self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                                self._children_yang_names.add("segment-route-next-hop-table")


                                            class SegmentRouteNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                    self.yang_name = "segment-route-next-hop-table"
                                                    self.yang_parent_name = "vrf-seg-route"

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "segment-route-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "segment-route-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "segment-route-next-hop-table" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                        for c in self.vrf_next_hop_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_explicit_path_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name"):
                                                        for c in self.vrf_next_hop_interface_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                        for c in self.vrf_next_hop_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_data())

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-seg-route" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "segment-route-next-hop-table"):
                                                    if (self.segment_route_next_hop_table is None):
                                                        self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                        self.segment_route_next_hop_table.parent = self
                                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                                    return self.segment_route_next_hop_table

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "segment-route-next-hop-table"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.prefix.is_set or
                                                self.prefix_length.is_set or
                                                (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_data()) or
                                                (self.vrf_route is not None and self.vrf_route.has_data()) or
                                                (self.vrf_seg_route is not None and self.vrf_seg_route.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.prefix.yfilter != YFilter.not_set or
                                                self.prefix_length.yfilter != YFilter.not_set or
                                                (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_operation()) or
                                                (self.vrf_route is not None and self.vrf_route.has_operation()) or
                                                (self.vrf_seg_route is not None and self.vrf_seg_route.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-recurse-routes"):
                                                if (self.vrf_recurse_routes is None):
                                                    self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                                    self.vrf_recurse_routes.parent = self
                                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                                return self.vrf_recurse_routes

                                            if (child_yang_name == "vrf-route"):
                                                if (self.vrf_route is None):
                                                    self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                                    self.vrf_route.parent = self
                                                    self._children_name_map["vrf_route"] = "vrf-route"
                                                return self.vrf_route

                                            if (child_yang_name == "vrf-seg-route"):
                                                if (self.vrf_seg_route is None):
                                                    self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                                    self.vrf_seg_route.parent = self
                                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                                return self.vrf_seg_route

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-recurse-routes" or name == "vrf-route" or name == "vrf-seg-route" or name == "prefix" or name == "prefix-length"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "prefix"):
                                                self.prefix = value
                                                self.prefix.value_namespace = name_space
                                                self.prefix.value_namespace_prefix = name_space_prefix
                                            if(value_path == "prefix-length"):
                                                self.prefix_length = value
                                                self.prefix_length.value_namespace = name_space
                                                self.prefix_length.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vrf_prefix_topology:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.vrf_prefix_topology:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-prefix-topologies" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-prefix-topology"):
                                            for c in self.vrf_prefix_topology:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_prefix_topology.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-prefix-topology"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.topology_name.is_set or
                                        (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.topology_name.yfilter != YFilter.not_set or
                                        (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "topology" + "[topology-name='" + self.topology_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.topology_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-prefix-topologies"):
                                        if (self.vrf_prefix_topologies is None):
                                            self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies()
                                            self.vrf_prefix_topologies.parent = self
                                            self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                        return self.vrf_prefix_topologies

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-prefix-topologies" or name == "topology-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "topology-name"):
                                        self.topology_name = value
                                        self.topology_name.value_namespace = name_space
                                        self.topology_name.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.topology:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.topology:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "topologies" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "topology"):
                                    for c in self.topology:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.topology.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "topology"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class VrfPrefixes(Entity):
                            """
                            The set of all Static Topologies for this AFI.
                            
                            .. attribute:: vrf_prefix
                            
                            	A static route
                            	**type**\: list of    :py:class:`VrfPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2015-09-10'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes, self).__init__()

                                self.yang_name = "vrf-prefixes"
                                self.yang_parent_name = "vrf-unicast"

                                self.vrf_prefix = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes, self).__setattr__(name, value)


                            class VrfPrefix(Entity):
                                """
                                A static route
                                
                                .. attribute:: prefix  <key>
                                
                                	Destination prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: prefix_length  <key>
                                
                                	Destination prefix length
                                	**type**\:  int
                                
                                	**range:** 0..128
                                
                                .. attribute:: vrf_recurse_routes
                                
                                	A recursive next VRF static route
                                	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes>`
                                
                                .. attribute:: vrf_route
                                
                                	A connected or recursive  static route
                                	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute>`
                                
                                .. attribute:: vrf_seg_route
                                
                                	A static segment route
                                	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix, self).__init__()

                                    self.yang_name = "vrf-prefix"
                                    self.yang_parent_name = "vrf-prefixes"

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                    self.vrf_recurse_routes.parent = self
                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                    self._children_yang_names.add("vrf-recurse-routes")

                                    self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute()
                                    self.vrf_route.parent = self
                                    self._children_name_map["vrf_route"] = "vrf-route"
                                    self._children_yang_names.add("vrf-route")

                                    self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                    self.vrf_seg_route.parent = self
                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    self._children_yang_names.add("vrf-seg-route")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("prefix",
                                                    "prefix_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix, self).__setattr__(name, value)


                                class VrfRoute(Entity):
                                    """
                                    A connected or recursive  static route
                                    
                                    .. attribute:: vrf_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute, self).__init__()

                                        self.yang_name = "vrf-route"
                                        self.yang_parent_name = "vrf-prefix"

                                        self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                        self.vrf_next_hop_table.parent = self
                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        self._children_yang_names.add("vrf-next-hop-table")


                                    class VrfNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__init__()

                                            self.yang_name = "vrf-next-hop-table"
                                            self.yang_parent_name = "vrf-route"

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-table" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_explicit_path_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name"):
                                                for c in self.vrf_next_hop_interface_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_data())

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-route" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-next-hop-table"):
                                            if (self.vrf_next_hop_table is None):
                                                self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                                self.vrf_next_hop_table.parent = self
                                                self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            return self.vrf_next_hop_table

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-next-hop-table"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class VrfRecurseRoutes(Entity):
                                    """
                                    A recursive next VRF static route
                                    
                                    .. attribute:: vrf_recurse_route
                                    
                                    	A recursive next vrf static route
                                    	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__init__()

                                        self.yang_name = "vrf-recurse-routes"
                                        self.yang_parent_name = "vrf-prefix"

                                        self.vrf_recurse_route = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__setattr__(name, value)


                                    class VrfRecurseRoute(Entity):
                                        """
                                        A recursive next vrf static route
                                        
                                        .. attribute:: vrf_name  <key>
                                        
                                        	Fallback or recusive VRF name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: vrf_recursive_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                            self.yang_name = "vrf-recurse-route"
                                            self.yang_parent_name = "vrf-recurse-routes"

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                            self.vrf_recursive_next_hop_table.parent = self
                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            self._children_yang_names.add("vrf-recursive-next-hop-table")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vrf_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)


                                        class VrfRecursiveNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                self.yang_name = "vrf-recursive-next-hop-table"
                                                self.yang_parent_name = "vrf-recurse-route"

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-recursive-next-hop-table" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_explicit_path_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name"):
                                                    for c in self.vrf_next_hop_interface_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.vrf_name.is_set or
                                                (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vrf_name.yfilter != YFilter.not_set or
                                                (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-recursive-next-hop-table"):
                                                if (self.vrf_recursive_next_hop_table is None):
                                                    self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                    self.vrf_recursive_next_hop_table.parent = self
                                                    self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                return self.vrf_recursive_next_hop_table

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-recursive-next-hop-table" or name == "vrf-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vrf-name"):
                                                self.vrf_name = value
                                                self.vrf_name.value_namespace = name_space
                                                self.vrf_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vrf_recurse_route:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.vrf_recurse_route:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-recurse-routes" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-recurse-route"):
                                            for c in self.vrf_recurse_route:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_recurse_route.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-recurse-route"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class VrfSegRoute(Entity):
                                    """
                                    A static segment route
                                    
                                    .. attribute:: segment_route_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute, self).__init__()

                                        self.yang_name = "vrf-seg-route"
                                        self.yang_parent_name = "vrf-prefix"

                                        self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                        self.segment_route_next_hop_table.parent = self
                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        self._children_yang_names.add("segment-route-next-hop-table")


                                    class SegmentRouteNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                            self.yang_name = "segment-route-next-hop-table"
                                            self.yang_parent_name = "vrf-seg-route"

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "segment-route-next-hop-table" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_explicit_path_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name"):
                                                for c in self.vrf_next_hop_interface_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_data())

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-seg-route" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "segment-route-next-hop-table"):
                                            if (self.segment_route_next_hop_table is None):
                                                self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                                self.segment_route_next_hop_table.parent = self
                                                self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            return self.segment_route_next_hop_table

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "segment-route-next-hop-table"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.prefix.is_set or
                                        self.prefix_length.is_set or
                                        (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_data()) or
                                        (self.vrf_route is not None and self.vrf_route.has_data()) or
                                        (self.vrf_seg_route is not None and self.vrf_seg_route.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.prefix.yfilter != YFilter.not_set or
                                        self.prefix_length.yfilter != YFilter.not_set or
                                        (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_operation()) or
                                        (self.vrf_route is not None and self.vrf_route.has_operation()) or
                                        (self.vrf_seg_route is not None and self.vrf_seg_route.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-prefix" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-recurse-routes"):
                                        if (self.vrf_recurse_routes is None):
                                            self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                            self.vrf_recurse_routes.parent = self
                                            self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                        return self.vrf_recurse_routes

                                    if (child_yang_name == "vrf-route"):
                                        if (self.vrf_route is None):
                                            self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute()
                                            self.vrf_route.parent = self
                                            self._children_name_map["vrf_route"] = "vrf-route"
                                        return self.vrf_route

                                    if (child_yang_name == "vrf-seg-route"):
                                        if (self.vrf_seg_route is None):
                                            self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                            self.vrf_seg_route.parent = self
                                            self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        return self.vrf_seg_route

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-recurse-routes" or name == "vrf-route" or name == "vrf-seg-route" or name == "prefix" or name == "prefix-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "prefix"):
                                        self.prefix = value
                                        self.prefix.value_namespace = name_space
                                        self.prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-length"):
                                        self.prefix_length = value
                                        self.prefix_length.value_namespace = name_space
                                        self.prefix_length.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.vrf_prefix:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.vrf_prefix:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vrf-prefixes" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "vrf-prefix"):
                                    for c in self.vrf_prefix:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.vrf_prefix.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "vrf-prefix"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class DefaultTopology(Entity):
                            """
                            Default topology configuration
                            
                            .. attribute:: vrf_prefix_topologies
                            
                            	The set of all Static Topologies for this AFI
                            	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2015-09-10'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology, self).__init__()

                                self.yang_name = "default-topology"
                                self.yang_parent_name = "vrf-unicast"

                                self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies()
                                self.vrf_prefix_topologies.parent = self
                                self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                self._children_yang_names.add("vrf-prefix-topologies")


                            class VrfPrefixTopologies(Entity):
                                """
                                The set of all Static Topologies for this AFI.
                                
                                .. attribute:: vrf_prefix_topology
                                
                                	A static route
                                	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies, self).__init__()

                                    self.yang_name = "vrf-prefix-topologies"
                                    self.yang_parent_name = "default-topology"

                                    self.vrf_prefix_topology = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies, self).__setattr__(name, value)


                                class VrfPrefixTopology(Entity):
                                    """
                                    A static route
                                    
                                    .. attribute:: prefix  <key>
                                    
                                    	Destination prefix
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: prefix_length  <key>
                                    
                                    	Destination prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: vrf_recurse_routes
                                    
                                    	A recursive next VRF static route
                                    	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                    
                                    .. attribute:: vrf_route
                                    
                                    	A connected or recursive  static route
                                    	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                    
                                    .. attribute:: vrf_seg_route
                                    
                                    	A static segment route
                                    	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                        self.yang_name = "vrf-prefix-topology"
                                        self.yang_parent_name = "vrf-prefix-topologies"

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                        self._children_yang_names.add("vrf-recurse-routes")

                                        self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"
                                        self._children_yang_names.add("vrf-route")

                                        self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        self._children_yang_names.add("vrf-seg-route")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("prefix",
                                                        "prefix_length") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)


                                    class VrfRoute(Entity):
                                        """
                                        A connected or recursive  static route
                                        
                                        .. attribute:: vrf_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                            self.yang_name = "vrf-route"
                                            self.yang_parent_name = "vrf-prefix-topology"

                                            self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            self._children_yang_names.add("vrf-next-hop-table")


                                        class VrfNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                self.yang_name = "vrf-next-hop-table"
                                                self.yang_parent_name = "vrf-route"

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-table" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_explicit_path_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name"):
                                                    for c in self.vrf_next_hop_interface_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_data())

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-route" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-table"):
                                                if (self.vrf_next_hop_table is None):
                                                    self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                    self.vrf_next_hop_table.parent = self
                                                    self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                                return self.vrf_next_hop_table

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-table"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class VrfRecurseRoutes(Entity):
                                        """
                                        A recursive next VRF static route
                                        
                                        .. attribute:: vrf_recurse_route
                                        
                                        	A recursive next vrf static route
                                        	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                            self.yang_name = "vrf-recurse-routes"
                                            self.yang_parent_name = "vrf-prefix-topology"

                                            self.vrf_recurse_route = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)


                                        class VrfRecurseRoute(Entity):
                                            """
                                            A recursive next vrf static route
                                            
                                            .. attribute:: vrf_name  <key>
                                            
                                            	Fallback or recusive VRF name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: vrf_recursive_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                self.yang_name = "vrf-recurse-route"
                                                self.yang_parent_name = "vrf-recurse-routes"

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                self._children_yang_names.add("vrf-recursive-next-hop-table")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("vrf_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)


                                            class VrfRecursiveNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-recursive-next-hop-table"
                                                    self.yang_parent_name = "vrf-recurse-route"

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-recursive-next-hop-table" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                        for c in self.vrf_next_hop_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_explicit_path_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name"):
                                                        for c in self.vrf_next_hop_interface_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                        for c in self.vrf_next_hop_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.vrf_name.is_set or
                                                    (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.vrf_name.yfilter != YFilter.not_set or
                                                    (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-recursive-next-hop-table"):
                                                    if (self.vrf_recursive_next_hop_table is None):
                                                        self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                        self.vrf_recursive_next_hop_table.parent = self
                                                        self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                    return self.vrf_recursive_next_hop_table

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-recursive-next-hop-table" or name == "vrf-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "vrf-name"):
                                                    self.vrf_name = value
                                                    self.vrf_name.value_namespace = name_space
                                                    self.vrf_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_recurse_route:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_recurse_route:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-recurse-routes" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-recurse-route"):
                                                for c in self.vrf_recurse_route:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_recurse_route.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-recurse-route"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class VrfSegRoute(Entity):
                                        """
                                        A static segment route
                                        
                                        .. attribute:: segment_route_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                            self.yang_name = "vrf-seg-route"
                                            self.yang_parent_name = "vrf-prefix-topology"

                                            self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            self._children_yang_names.add("segment-route-next-hop-table")


                                        class SegmentRouteNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                self.yang_name = "segment-route-next-hop-table"
                                                self.yang_parent_name = "vrf-seg-route"

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "segment-route-next-hop-table" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_explicit_path_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name"):
                                                    for c in self.vrf_next_hop_interface_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_data())

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-seg-route" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "segment-route-next-hop-table"):
                                                if (self.segment_route_next_hop_table is None):
                                                    self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                    self.segment_route_next_hop_table.parent = self
                                                    self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                                return self.segment_route_next_hop_table

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "segment-route-next-hop-table"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.prefix.is_set or
                                            self.prefix_length.is_set or
                                            (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_data()) or
                                            (self.vrf_route is not None and self.vrf_route.has_data()) or
                                            (self.vrf_seg_route is not None and self.vrf_seg_route.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.prefix.yfilter != YFilter.not_set or
                                            self.prefix_length.yfilter != YFilter.not_set or
                                            (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_operation()) or
                                            (self.vrf_route is not None and self.vrf_route.has_operation()) or
                                            (self.vrf_seg_route is not None and self.vrf_seg_route.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix.get_name_leafdata())
                                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-recurse-routes"):
                                            if (self.vrf_recurse_routes is None):
                                                self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                                self.vrf_recurse_routes.parent = self
                                                self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                            return self.vrf_recurse_routes

                                        if (child_yang_name == "vrf-route"):
                                            if (self.vrf_route is None):
                                                self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                                self.vrf_route.parent = self
                                                self._children_name_map["vrf_route"] = "vrf-route"
                                            return self.vrf_route

                                        if (child_yang_name == "vrf-seg-route"):
                                            if (self.vrf_seg_route is None):
                                                self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                                self.vrf_seg_route.parent = self
                                                self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                            return self.vrf_seg_route

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-recurse-routes" or name == "vrf-route" or name == "vrf-seg-route" or name == "prefix" or name == "prefix-length"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "prefix"):
                                            self.prefix = value
                                            self.prefix.value_namespace = name_space
                                            self.prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "prefix-length"):
                                            self.prefix_length = value
                                            self.prefix_length.value_namespace = name_space
                                            self.prefix_length.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vrf_prefix_topology:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.vrf_prefix_topology:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-prefix-topologies" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-prefix-topology"):
                                        for c in self.vrf_prefix_topology:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vrf_prefix_topology.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-prefix-topology"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_data())

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "default-topology" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "vrf-prefix-topologies"):
                                    if (self.vrf_prefix_topologies is None):
                                        self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies()
                                        self.vrf_prefix_topologies.parent = self
                                        self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                    return self.vrf_prefix_topologies

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "vrf-prefix-topologies"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.default_topology is not None and self.default_topology.has_data()) or
                                (self.topologies is not None and self.topologies.has_data()) or
                                (self.vrf_prefixes is not None and self.vrf_prefixes.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.default_topology is not None and self.default_topology.has_operation()) or
                                (self.topologies is not None and self.topologies.has_operation()) or
                                (self.vrf_prefixes is not None and self.vrf_prefixes.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "vrf-unicast" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "default-topology"):
                                if (self.default_topology is None):
                                    self.default_topology = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology()
                                    self.default_topology.parent = self
                                    self._children_name_map["default_topology"] = "default-topology"
                                return self.default_topology

                            if (child_yang_name == "topologies"):
                                if (self.topologies is None):
                                    self.topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies()
                                    self.topologies.parent = self
                                    self._children_name_map["topologies"] = "topologies"
                                return self.topologies

                            if (child_yang_name == "vrf-prefixes"):
                                if (self.vrf_prefixes is None):
                                    self.vrf_prefixes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes()
                                    self.vrf_prefixes.parent = self
                                    self._children_name_map["vrf_prefixes"] = "vrf-prefixes"
                                return self.vrf_prefixes

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "default-topology" or name == "topologies" or name == "vrf-prefixes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class VrfMulticast(Entity):
                        """
                        Multicast static configuration
                        
                        .. attribute:: default_topology
                        
                        	Default topology configuration
                        	**type**\:   :py:class:`DefaultTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology>`
                        
                        .. attribute:: topologies
                        
                        	Topology static configuration container
                        	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies>`
                        
                        .. attribute:: vrf_prefixes
                        
                        	The set of all Static Topologies for this AFI
                        	**type**\:   :py:class:`VrfPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2015-09-10'

                        def __init__(self):
                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast, self).__init__()

                            self.yang_name = "vrf-multicast"
                            self.yang_parent_name = "vrfipv6"

                            self.default_topology = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology()
                            self.default_topology.parent = self
                            self._children_name_map["default_topology"] = "default-topology"
                            self._children_yang_names.add("default-topology")

                            self.topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies()
                            self.topologies.parent = self
                            self._children_name_map["topologies"] = "topologies"
                            self._children_yang_names.add("topologies")

                            self.vrf_prefixes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes()
                            self.vrf_prefixes.parent = self
                            self._children_name_map["vrf_prefixes"] = "vrf-prefixes"
                            self._children_yang_names.add("vrf-prefixes")


                        class Topologies(Entity):
                            """
                            Topology static configuration container
                            
                            .. attribute:: topology
                            
                            	Topology static configuration
                            	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2015-09-10'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies, self).__init__()

                                self.yang_name = "topologies"
                                self.yang_parent_name = "vrf-multicast"

                                self.topology = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies, self).__setattr__(name, value)


                            class Topology(Entity):
                                """
                                Topology static configuration
                                
                                .. attribute:: topology_name  <key>
                                
                                	Topology name
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: vrf_prefix_topologies
                                
                                	The set of all Static Topologies for this AFI
                                	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology, self).__init__()

                                    self.yang_name = "topology"
                                    self.yang_parent_name = "topologies"

                                    self.topology_name = YLeaf(YType.str, "topology-name")

                                    self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies()
                                    self.vrf_prefix_topologies.parent = self
                                    self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                    self._children_yang_names.add("vrf-prefix-topologies")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("topology_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology, self).__setattr__(name, value)


                                class VrfPrefixTopologies(Entity):
                                    """
                                    The set of all Static Topologies for this AFI.
                                    
                                    .. attribute:: vrf_prefix_topology
                                    
                                    	A static route
                                    	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, self).__init__()

                                        self.yang_name = "vrf-prefix-topologies"
                                        self.yang_parent_name = "topology"

                                        self.vrf_prefix_topology = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, self).__setattr__(name, value)


                                    class VrfPrefixTopology(Entity):
                                        """
                                        A static route
                                        
                                        .. attribute:: prefix  <key>
                                        
                                        	Destination prefix
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: prefix_length  <key>
                                        
                                        	Destination prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..128
                                        
                                        .. attribute:: vrf_recurse_routes
                                        
                                        	A recursive next VRF static route
                                        	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                        
                                        .. attribute:: vrf_route
                                        
                                        	A connected or recursive  static route
                                        	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                        
                                        .. attribute:: vrf_seg_route
                                        
                                        	A static segment route
                                        	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                            self.yang_name = "vrf-prefix-topology"
                                            self.yang_parent_name = "vrf-prefix-topologies"

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                            self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                            self.vrf_recurse_routes.parent = self
                                            self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                            self._children_yang_names.add("vrf-recurse-routes")

                                            self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                            self.vrf_route.parent = self
                                            self._children_name_map["vrf_route"] = "vrf-route"
                                            self._children_yang_names.add("vrf-route")

                                            self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                            self.vrf_seg_route.parent = self
                                            self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                            self._children_yang_names.add("vrf-seg-route")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("prefix",
                                                            "prefix_length") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)


                                        class VrfRoute(Entity):
                                            """
                                            A connected or recursive  static route
                                            
                                            .. attribute:: vrf_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                                self.yang_name = "vrf-route"
                                                self.yang_parent_name = "vrf-prefix-topology"

                                                self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                self.vrf_next_hop_table.parent = self
                                                self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                                self._children_yang_names.add("vrf-next-hop-table")


                                            class VrfNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-next-hop-table"
                                                    self.yang_parent_name = "vrf-route"

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-table" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                        for c in self.vrf_next_hop_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_explicit_path_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name"):
                                                        for c in self.vrf_next_hop_interface_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                        for c in self.vrf_next_hop_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_data())

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-route" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-table"):
                                                    if (self.vrf_next_hop_table is None):
                                                        self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                        self.vrf_next_hop_table.parent = self
                                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                                    return self.vrf_next_hop_table

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-table"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class VrfRecurseRoutes(Entity):
                                            """
                                            A recursive next VRF static route
                                            
                                            .. attribute:: vrf_recurse_route
                                            
                                            	A recursive next vrf static route
                                            	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                                self.yang_name = "vrf-recurse-routes"
                                                self.yang_parent_name = "vrf-prefix-topology"

                                                self.vrf_recurse_route = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)


                                            class VrfRecurseRoute(Entity):
                                                """
                                                A recursive next vrf static route
                                                
                                                .. attribute:: vrf_name  <key>
                                                
                                                	Fallback or recusive VRF name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: vrf_recursive_next_hop_table
                                                
                                                	The set of nexthop information configured for this route
                                                	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                    self.yang_name = "vrf-recurse-route"
                                                    self.yang_parent_name = "vrf-recurse-routes"

                                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                    self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                    self.vrf_recursive_next_hop_table.parent = self
                                                    self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                    self._children_yang_names.add("vrf-recursive-next-hop-table")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("vrf_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)


                                                class VrfRecursiveNextHopTable(Entity):
                                                    """
                                                    The set of nexthop information configured for
                                                    this route
                                                    
                                                    .. attribute:: vrf_next_hop_explicit_path_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                    
                                                    .. attribute:: vrf_next_hop_interface_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                    
                                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                    
                                                    .. attribute:: vrf_next_hop_next_hop_address
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                    
                                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                        self.yang_name = "vrf-recursive-next-hop-table"
                                                        self.yang_parent_name = "vrf-recurse-route"

                                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                                        self.vrf_next_hop_interface_name = YList(self)
                                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                        self.vrf_next_hop_next_hop_address = YList(self)
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)


                                                    class VrfNextHopInterfaceName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: interface_name  <key>
                                                        
                                                        	Forwarding interface
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2015-09-10'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-interface-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("interface_name",
                                                                            "bfd_fast_detect",
                                                                            "description",
                                                                            "detect_multiplier",
                                                                            "index",
                                                                            "load_metric",
                                                                            "metric",
                                                                            "minimum_interval",
                                                                            "object_name",
                                                                            "permanent",
                                                                            "tag",
                                                                            "tunnel_id",
                                                                            "vrf_lable") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.interface_name.is_set or
                                                                self.bfd_fast_detect.is_set or
                                                                self.description.is_set or
                                                                self.detect_multiplier.is_set or
                                                                self.index.is_set or
                                                                self.load_metric.is_set or
                                                                self.metric.is_set or
                                                                self.minimum_interval.is_set or
                                                                self.object_name.is_set or
                                                                self.permanent.is_set or
                                                                self.tag.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.vrf_lable.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.interface_name.yfilter != YFilter.not_set or
                                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                                self.description.yfilter != YFilter.not_set or
                                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                                self.index.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                                self.object_name.yfilter != YFilter.not_set or
                                                                self.permanent.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.vrf_lable.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.description.get_name_leafdata())
                                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.index.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "interface-name"):
                                                                self.interface_name = value
                                                                self.interface_name.value_namespace = name_space
                                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "bfd-fast-detect"):
                                                                self.bfd_fast_detect = value
                                                                self.bfd_fast_detect.value_namespace = name_space
                                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "description"):
                                                                self.description = value
                                                                self.description.value_namespace = name_space
                                                                self.description.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "detect-multiplier"):
                                                                self.detect_multiplier = value
                                                                self.detect_multiplier.value_namespace = name_space
                                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "index"):
                                                                self.index = value
                                                                self.index.value_namespace = name_space
                                                                self.index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "minimum-interval"):
                                                                self.minimum_interval = value
                                                                self.minimum_interval.value_namespace = name_space
                                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "object-name"):
                                                                self.object_name = value
                                                                self.object_name.value_namespace = name_space
                                                                self.object_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "permanent"):
                                                                self.permanent = value
                                                                self.permanent.value_namespace = name_space
                                                                self.permanent.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-lable"):
                                                                self.vrf_lable = value
                                                                self.vrf_lable.value_namespace = name_space
                                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: interface_name  <key>
                                                        
                                                        	Forwarding interface
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                        
                                                        .. attribute:: next_hop_address  <key>
                                                        
                                                        	Next hop address
                                                        	**type**\: one of the below types:
                                                        
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2015-09-10'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("interface_name",
                                                                            "next_hop_address",
                                                                            "bfd_fast_detect",
                                                                            "description",
                                                                            "detect_multiplier",
                                                                            "index",
                                                                            "load_metric",
                                                                            "metric",
                                                                            "minimum_interval",
                                                                            "object_name",
                                                                            "permanent",
                                                                            "tag",
                                                                            "tunnel_id",
                                                                            "vrf_lable") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.interface_name.is_set or
                                                                self.next_hop_address.is_set or
                                                                self.bfd_fast_detect.is_set or
                                                                self.description.is_set or
                                                                self.detect_multiplier.is_set or
                                                                self.index.is_set or
                                                                self.load_metric.is_set or
                                                                self.metric.is_set or
                                                                self.minimum_interval.is_set or
                                                                self.object_name.is_set or
                                                                self.permanent.is_set or
                                                                self.tag.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.vrf_lable.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.interface_name.yfilter != YFilter.not_set or
                                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                                self.description.yfilter != YFilter.not_set or
                                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                                self.index.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                                self.object_name.yfilter != YFilter.not_set or
                                                                self.permanent.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.vrf_lable.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.description.get_name_leafdata())
                                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.index.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "interface-name"):
                                                                self.interface_name = value
                                                                self.interface_name.value_namespace = name_space
                                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-address"):
                                                                self.next_hop_address = value
                                                                self.next_hop_address.value_namespace = name_space
                                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "bfd-fast-detect"):
                                                                self.bfd_fast_detect = value
                                                                self.bfd_fast_detect.value_namespace = name_space
                                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "description"):
                                                                self.description = value
                                                                self.description.value_namespace = name_space
                                                                self.description.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "detect-multiplier"):
                                                                self.detect_multiplier = value
                                                                self.detect_multiplier.value_namespace = name_space
                                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "index"):
                                                                self.index = value
                                                                self.index.value_namespace = name_space
                                                                self.index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "minimum-interval"):
                                                                self.minimum_interval = value
                                                                self.minimum_interval.value_namespace = name_space
                                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "object-name"):
                                                                self.object_name = value
                                                                self.object_name.value_namespace = name_space
                                                                self.object_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "permanent"):
                                                                self.permanent = value
                                                                self.permanent.value_namespace = name_space
                                                                self.permanent.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-lable"):
                                                                self.vrf_lable = value
                                                                self.vrf_lable.value_namespace = name_space
                                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                    class VrfNextHopNextHopAddress(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: next_hop_address  <key>
                                                        
                                                        	Next hop address
                                                        	**type**\: one of the below types:
                                                        
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2015-09-10'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("next_hop_address",
                                                                            "bfd_fast_detect",
                                                                            "description",
                                                                            "detect_multiplier",
                                                                            "index",
                                                                            "load_metric",
                                                                            "metric",
                                                                            "minimum_interval",
                                                                            "object_name",
                                                                            "permanent",
                                                                            "tag",
                                                                            "tunnel_id",
                                                                            "vrf_lable") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.next_hop_address.is_set or
                                                                self.bfd_fast_detect.is_set or
                                                                self.description.is_set or
                                                                self.detect_multiplier.is_set or
                                                                self.index.is_set or
                                                                self.load_metric.is_set or
                                                                self.metric.is_set or
                                                                self.minimum_interval.is_set or
                                                                self.object_name.is_set or
                                                                self.permanent.is_set or
                                                                self.tag.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.vrf_lable.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                                self.description.yfilter != YFilter.not_set or
                                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                                self.index.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                                self.object_name.yfilter != YFilter.not_set or
                                                                self.permanent.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.vrf_lable.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.description.get_name_leafdata())
                                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.index.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "next-hop-address"):
                                                                self.next_hop_address = value
                                                                self.next_hop_address.value_namespace = name_space
                                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "bfd-fast-detect"):
                                                                self.bfd_fast_detect = value
                                                                self.bfd_fast_detect.value_namespace = name_space
                                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "description"):
                                                                self.description = value
                                                                self.description.value_namespace = name_space
                                                                self.description.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "detect-multiplier"):
                                                                self.detect_multiplier = value
                                                                self.detect_multiplier.value_namespace = name_space
                                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "index"):
                                                                self.index = value
                                                                self.index.value_namespace = name_space
                                                                self.index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "minimum-interval"):
                                                                self.minimum_interval = value
                                                                self.minimum_interval.value_namespace = name_space
                                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "object-name"):
                                                                self.object_name = value
                                                                self.object_name.value_namespace = name_space
                                                                self.object_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "permanent"):
                                                                self.permanent = value
                                                                self.permanent.value_namespace = name_space
                                                                self.permanent.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-lable"):
                                                                self.vrf_lable = value
                                                                self.vrf_lable.value_namespace = name_space
                                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: next_hop_address  <key>
                                                        
                                                        	Next hop address
                                                        	**type**\: one of the below types:
                                                        
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        .. attribute:: explicit_path_name  <key>
                                                        
                                                        	Segment Routing mpls path name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2015-09-10'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("next_hop_address",
                                                                            "explicit_path_name",
                                                                            "bfd_fast_detect",
                                                                            "description",
                                                                            "detect_multiplier",
                                                                            "index",
                                                                            "load_metric",
                                                                            "metric",
                                                                            "minimum_interval",
                                                                            "object_name",
                                                                            "permanent",
                                                                            "tag",
                                                                            "tunnel_id",
                                                                            "vrf_lable") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.next_hop_address.is_set or
                                                                self.explicit_path_name.is_set or
                                                                self.bfd_fast_detect.is_set or
                                                                self.description.is_set or
                                                                self.detect_multiplier.is_set or
                                                                self.index.is_set or
                                                                self.load_metric.is_set or
                                                                self.metric.is_set or
                                                                self.minimum_interval.is_set or
                                                                self.object_name.is_set or
                                                                self.permanent.is_set or
                                                                self.tag.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.vrf_lable.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                                self.explicit_path_name.yfilter != YFilter.not_set or
                                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                                self.description.yfilter != YFilter.not_set or
                                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                                self.index.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                                self.object_name.yfilter != YFilter.not_set or
                                                                self.permanent.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.vrf_lable.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                            if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.description.get_name_leafdata())
                                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.index.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "next-hop-address"):
                                                                self.next_hop_address = value
                                                                self.next_hop_address.value_namespace = name_space
                                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "explicit-path-name"):
                                                                self.explicit_path_name = value
                                                                self.explicit_path_name.value_namespace = name_space
                                                                self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "bfd-fast-detect"):
                                                                self.bfd_fast_detect = value
                                                                self.bfd_fast_detect.value_namespace = name_space
                                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "description"):
                                                                self.description = value
                                                                self.description.value_namespace = name_space
                                                                self.description.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "detect-multiplier"):
                                                                self.detect_multiplier = value
                                                                self.detect_multiplier.value_namespace = name_space
                                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "index"):
                                                                self.index = value
                                                                self.index.value_namespace = name_space
                                                                self.index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "minimum-interval"):
                                                                self.minimum_interval = value
                                                                self.minimum_interval.value_namespace = name_space
                                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "object-name"):
                                                                self.object_name = value
                                                                self.object_name.value_namespace = name_space
                                                                self.object_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "permanent"):
                                                                self.permanent = value
                                                                self.permanent.value_namespace = name_space
                                                                self.permanent.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-lable"):
                                                                self.vrf_lable = value
                                                                self.vrf_lable.value_namespace = name_space
                                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                    class VrfNextHopExplicitPathName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: explicit_path_name  <key>
                                                        
                                                        	Segment Routing mpls path name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2015-09-10'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("explicit_path_name",
                                                                            "bfd_fast_detect",
                                                                            "description",
                                                                            "detect_multiplier",
                                                                            "index",
                                                                            "load_metric",
                                                                            "metric",
                                                                            "minimum_interval",
                                                                            "object_name",
                                                                            "permanent",
                                                                            "tag",
                                                                            "tunnel_id",
                                                                            "vrf_lable") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.explicit_path_name.is_set or
                                                                self.bfd_fast_detect.is_set or
                                                                self.description.is_set or
                                                                self.detect_multiplier.is_set or
                                                                self.index.is_set or
                                                                self.load_metric.is_set or
                                                                self.metric.is_set or
                                                                self.minimum_interval.is_set or
                                                                self.object_name.is_set or
                                                                self.permanent.is_set or
                                                                self.tag.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.vrf_lable.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.explicit_path_name.yfilter != YFilter.not_set or
                                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                                self.description.yfilter != YFilter.not_set or
                                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                                self.index.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                                self.object_name.yfilter != YFilter.not_set or
                                                                self.permanent.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.vrf_lable.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.description.get_name_leafdata())
                                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.index.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "explicit-path-name"):
                                                                self.explicit_path_name = value
                                                                self.explicit_path_name.value_namespace = name_space
                                                                self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "bfd-fast-detect"):
                                                                self.bfd_fast_detect = value
                                                                self.bfd_fast_detect.value_namespace = name_space
                                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "description"):
                                                                self.description = value
                                                                self.description.value_namespace = name_space
                                                                self.description.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "detect-multiplier"):
                                                                self.detect_multiplier = value
                                                                self.detect_multiplier.value_namespace = name_space
                                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "index"):
                                                                self.index = value
                                                                self.index.value_namespace = name_space
                                                                self.index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "minimum-interval"):
                                                                self.minimum_interval = value
                                                                self.minimum_interval.value_namespace = name_space
                                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "object-name"):
                                                                self.object_name = value
                                                                self.object_name.value_namespace = name_space
                                                                self.object_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "permanent"):
                                                                self.permanent = value
                                                                self.permanent.value_namespace = name_space
                                                                self.permanent.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-lable"):
                                                                self.vrf_lable = value
                                                                self.vrf_lable.value_namespace = name_space
                                                                self.vrf_lable.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.vrf_next_hop_explicit_path_name:
                                                            if (c.has_data()):
                                                                return True
                                                        for c in self.vrf_next_hop_interface_name:
                                                            if (c.has_data()):
                                                                return True
                                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                            if (c.has_data()):
                                                                return True
                                                        for c in self.vrf_next_hop_next_hop_address:
                                                            if (c.has_data()):
                                                                return True
                                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.vrf_next_hop_explicit_path_name:
                                                            if (c.has_operation()):
                                                                return True
                                                        for c in self.vrf_next_hop_interface_name:
                                                            if (c.has_operation()):
                                                                return True
                                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                            if (c.has_operation()):
                                                                return True
                                                        for c in self.vrf_next_hop_next_hop_address:
                                                            if (c.has_operation()):
                                                                return True
                                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-recursive-next-hop-table" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                            for c in self.vrf_next_hop_explicit_path_name:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.vrf_next_hop_explicit_path_name.append(c)
                                                            return c

                                                        if (child_yang_name == "vrf-next-hop-interface-name"):
                                                            for c in self.vrf_next_hop_interface_name:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.vrf_next_hop_interface_name.append(c)
                                                            return c

                                                        if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                            return c

                                                        if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                            for c in self.vrf_next_hop_next_hop_address:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.vrf_next_hop_next_hop_address.append(c)
                                                            return c

                                                        if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        self.vrf_name.is_set or
                                                        (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.vrf_name.yfilter != YFilter.not_set or
                                                        (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "vrf-recursive-next-hop-table"):
                                                        if (self.vrf_recursive_next_hop_table is None):
                                                            self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                            self.vrf_recursive_next_hop_table.parent = self
                                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                        return self.vrf_recursive_next_hop_table

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "vrf-recursive-next-hop-table" or name == "vrf-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "vrf-name"):
                                                        self.vrf_name = value
                                                        self.vrf_name.value_namespace = name_space
                                                        self.vrf_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_recurse_route:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_recurse_route:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-recurse-routes" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-recurse-route"):
                                                    for c in self.vrf_recurse_route:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_recurse_route.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-recurse-route"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class VrfSegRoute(Entity):
                                            """
                                            A static segment route
                                            
                                            .. attribute:: segment_route_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                                self.yang_name = "vrf-seg-route"
                                                self.yang_parent_name = "vrf-prefix-topology"

                                                self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                self.segment_route_next_hop_table.parent = self
                                                self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                                self._children_yang_names.add("segment-route-next-hop-table")


                                            class SegmentRouteNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                    self.yang_name = "segment-route-next-hop-table"
                                                    self.yang_parent_name = "vrf-seg-route"

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "segment-route-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "segment-route-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "segment-route-next-hop-table" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                        for c in self.vrf_next_hop_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_explicit_path_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name"):
                                                        for c in self.vrf_next_hop_interface_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                        for c in self.vrf_next_hop_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_data())

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-seg-route" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "segment-route-next-hop-table"):
                                                    if (self.segment_route_next_hop_table is None):
                                                        self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                        self.segment_route_next_hop_table.parent = self
                                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                                    return self.segment_route_next_hop_table

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "segment-route-next-hop-table"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.prefix.is_set or
                                                self.prefix_length.is_set or
                                                (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_data()) or
                                                (self.vrf_route is not None and self.vrf_route.has_data()) or
                                                (self.vrf_seg_route is not None and self.vrf_seg_route.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.prefix.yfilter != YFilter.not_set or
                                                self.prefix_length.yfilter != YFilter.not_set or
                                                (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_operation()) or
                                                (self.vrf_route is not None and self.vrf_route.has_operation()) or
                                                (self.vrf_seg_route is not None and self.vrf_seg_route.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-recurse-routes"):
                                                if (self.vrf_recurse_routes is None):
                                                    self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                                    self.vrf_recurse_routes.parent = self
                                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                                return self.vrf_recurse_routes

                                            if (child_yang_name == "vrf-route"):
                                                if (self.vrf_route is None):
                                                    self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                                    self.vrf_route.parent = self
                                                    self._children_name_map["vrf_route"] = "vrf-route"
                                                return self.vrf_route

                                            if (child_yang_name == "vrf-seg-route"):
                                                if (self.vrf_seg_route is None):
                                                    self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                                    self.vrf_seg_route.parent = self
                                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                                return self.vrf_seg_route

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-recurse-routes" or name == "vrf-route" or name == "vrf-seg-route" or name == "prefix" or name == "prefix-length"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "prefix"):
                                                self.prefix = value
                                                self.prefix.value_namespace = name_space
                                                self.prefix.value_namespace_prefix = name_space_prefix
                                            if(value_path == "prefix-length"):
                                                self.prefix_length = value
                                                self.prefix_length.value_namespace = name_space
                                                self.prefix_length.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vrf_prefix_topology:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.vrf_prefix_topology:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-prefix-topologies" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-prefix-topology"):
                                            for c in self.vrf_prefix_topology:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_prefix_topology.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-prefix-topology"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.topology_name.is_set or
                                        (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.topology_name.yfilter != YFilter.not_set or
                                        (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "topology" + "[topology-name='" + self.topology_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.topology_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-prefix-topologies"):
                                        if (self.vrf_prefix_topologies is None):
                                            self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies()
                                            self.vrf_prefix_topologies.parent = self
                                            self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                        return self.vrf_prefix_topologies

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-prefix-topologies" or name == "topology-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "topology-name"):
                                        self.topology_name = value
                                        self.topology_name.value_namespace = name_space
                                        self.topology_name.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.topology:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.topology:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "topologies" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "topology"):
                                    for c in self.topology:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.topology.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "topology"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class VrfPrefixes(Entity):
                            """
                            The set of all Static Topologies for this AFI.
                            
                            .. attribute:: vrf_prefix
                            
                            	A static route
                            	**type**\: list of    :py:class:`VrfPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2015-09-10'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes, self).__init__()

                                self.yang_name = "vrf-prefixes"
                                self.yang_parent_name = "vrf-multicast"

                                self.vrf_prefix = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes, self).__setattr__(name, value)


                            class VrfPrefix(Entity):
                                """
                                A static route
                                
                                .. attribute:: prefix  <key>
                                
                                	Destination prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: prefix_length  <key>
                                
                                	Destination prefix length
                                	**type**\:  int
                                
                                	**range:** 0..128
                                
                                .. attribute:: vrf_recurse_routes
                                
                                	A recursive next VRF static route
                                	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes>`
                                
                                .. attribute:: vrf_route
                                
                                	A connected or recursive  static route
                                	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute>`
                                
                                .. attribute:: vrf_seg_route
                                
                                	A static segment route
                                	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix, self).__init__()

                                    self.yang_name = "vrf-prefix"
                                    self.yang_parent_name = "vrf-prefixes"

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                    self.vrf_recurse_routes.parent = self
                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                    self._children_yang_names.add("vrf-recurse-routes")

                                    self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute()
                                    self.vrf_route.parent = self
                                    self._children_name_map["vrf_route"] = "vrf-route"
                                    self._children_yang_names.add("vrf-route")

                                    self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                    self.vrf_seg_route.parent = self
                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    self._children_yang_names.add("vrf-seg-route")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("prefix",
                                                    "prefix_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix, self).__setattr__(name, value)


                                class VrfRoute(Entity):
                                    """
                                    A connected or recursive  static route
                                    
                                    .. attribute:: vrf_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute, self).__init__()

                                        self.yang_name = "vrf-route"
                                        self.yang_parent_name = "vrf-prefix"

                                        self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                        self.vrf_next_hop_table.parent = self
                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        self._children_yang_names.add("vrf-next-hop-table")


                                    class VrfNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__init__()

                                            self.yang_name = "vrf-next-hop-table"
                                            self.yang_parent_name = "vrf-route"

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-table" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_explicit_path_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name"):
                                                for c in self.vrf_next_hop_interface_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_data())

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-route" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-next-hop-table"):
                                            if (self.vrf_next_hop_table is None):
                                                self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                                self.vrf_next_hop_table.parent = self
                                                self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            return self.vrf_next_hop_table

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-next-hop-table"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class VrfRecurseRoutes(Entity):
                                    """
                                    A recursive next VRF static route
                                    
                                    .. attribute:: vrf_recurse_route
                                    
                                    	A recursive next vrf static route
                                    	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__init__()

                                        self.yang_name = "vrf-recurse-routes"
                                        self.yang_parent_name = "vrf-prefix"

                                        self.vrf_recurse_route = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__setattr__(name, value)


                                    class VrfRecurseRoute(Entity):
                                        """
                                        A recursive next vrf static route
                                        
                                        .. attribute:: vrf_name  <key>
                                        
                                        	Fallback or recusive VRF name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: vrf_recursive_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                            self.yang_name = "vrf-recurse-route"
                                            self.yang_parent_name = "vrf-recurse-routes"

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                            self.vrf_recursive_next_hop_table.parent = self
                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            self._children_yang_names.add("vrf-recursive-next-hop-table")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vrf_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)


                                        class VrfRecursiveNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                self.yang_name = "vrf-recursive-next-hop-table"
                                                self.yang_parent_name = "vrf-recurse-route"

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-recursive-next-hop-table" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_explicit_path_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name"):
                                                    for c in self.vrf_next_hop_interface_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.vrf_name.is_set or
                                                (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vrf_name.yfilter != YFilter.not_set or
                                                (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-recursive-next-hop-table"):
                                                if (self.vrf_recursive_next_hop_table is None):
                                                    self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                    self.vrf_recursive_next_hop_table.parent = self
                                                    self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                return self.vrf_recursive_next_hop_table

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-recursive-next-hop-table" or name == "vrf-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vrf-name"):
                                                self.vrf_name = value
                                                self.vrf_name.value_namespace = name_space
                                                self.vrf_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vrf_recurse_route:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.vrf_recurse_route:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-recurse-routes" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-recurse-route"):
                                            for c in self.vrf_recurse_route:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_recurse_route.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-recurse-route"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class VrfSegRoute(Entity):
                                    """
                                    A static segment route
                                    
                                    .. attribute:: segment_route_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute, self).__init__()

                                        self.yang_name = "vrf-seg-route"
                                        self.yang_parent_name = "vrf-prefix"

                                        self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                        self.segment_route_next_hop_table.parent = self
                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        self._children_yang_names.add("segment-route-next-hop-table")


                                    class SegmentRouteNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                            self.yang_name = "segment-route-next-hop-table"
                                            self.yang_parent_name = "vrf-seg-route"

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "segment-route-next-hop-table" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_explicit_path_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name"):
                                                for c in self.vrf_next_hop_interface_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_data())

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-seg-route" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "segment-route-next-hop-table"):
                                            if (self.segment_route_next_hop_table is None):
                                                self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                                self.segment_route_next_hop_table.parent = self
                                                self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            return self.segment_route_next_hop_table

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "segment-route-next-hop-table"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.prefix.is_set or
                                        self.prefix_length.is_set or
                                        (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_data()) or
                                        (self.vrf_route is not None and self.vrf_route.has_data()) or
                                        (self.vrf_seg_route is not None and self.vrf_seg_route.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.prefix.yfilter != YFilter.not_set or
                                        self.prefix_length.yfilter != YFilter.not_set or
                                        (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_operation()) or
                                        (self.vrf_route is not None and self.vrf_route.has_operation()) or
                                        (self.vrf_seg_route is not None and self.vrf_seg_route.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-prefix" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-recurse-routes"):
                                        if (self.vrf_recurse_routes is None):
                                            self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                            self.vrf_recurse_routes.parent = self
                                            self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                        return self.vrf_recurse_routes

                                    if (child_yang_name == "vrf-route"):
                                        if (self.vrf_route is None):
                                            self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute()
                                            self.vrf_route.parent = self
                                            self._children_name_map["vrf_route"] = "vrf-route"
                                        return self.vrf_route

                                    if (child_yang_name == "vrf-seg-route"):
                                        if (self.vrf_seg_route is None):
                                            self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                            self.vrf_seg_route.parent = self
                                            self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        return self.vrf_seg_route

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-recurse-routes" or name == "vrf-route" or name == "vrf-seg-route" or name == "prefix" or name == "prefix-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "prefix"):
                                        self.prefix = value
                                        self.prefix.value_namespace = name_space
                                        self.prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-length"):
                                        self.prefix_length = value
                                        self.prefix_length.value_namespace = name_space
                                        self.prefix_length.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.vrf_prefix:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.vrf_prefix:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vrf-prefixes" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "vrf-prefix"):
                                    for c in self.vrf_prefix:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.vrf_prefix.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "vrf-prefix"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class DefaultTopology(Entity):
                            """
                            Default topology configuration
                            
                            .. attribute:: vrf_prefix_topologies
                            
                            	The set of all Static Topologies for this AFI
                            	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2015-09-10'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology, self).__init__()

                                self.yang_name = "default-topology"
                                self.yang_parent_name = "vrf-multicast"

                                self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies()
                                self.vrf_prefix_topologies.parent = self
                                self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                self._children_yang_names.add("vrf-prefix-topologies")


                            class VrfPrefixTopologies(Entity):
                                """
                                The set of all Static Topologies for this AFI.
                                
                                .. attribute:: vrf_prefix_topology
                                
                                	A static route
                                	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies, self).__init__()

                                    self.yang_name = "vrf-prefix-topologies"
                                    self.yang_parent_name = "default-topology"

                                    self.vrf_prefix_topology = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies, self).__setattr__(name, value)


                                class VrfPrefixTopology(Entity):
                                    """
                                    A static route
                                    
                                    .. attribute:: prefix  <key>
                                    
                                    	Destination prefix
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: prefix_length  <key>
                                    
                                    	Destination prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: vrf_recurse_routes
                                    
                                    	A recursive next VRF static route
                                    	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                    
                                    .. attribute:: vrf_route
                                    
                                    	A connected or recursive  static route
                                    	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                    
                                    .. attribute:: vrf_seg_route
                                    
                                    	A static segment route
                                    	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                        self.yang_name = "vrf-prefix-topology"
                                        self.yang_parent_name = "vrf-prefix-topologies"

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                        self._children_yang_names.add("vrf-recurse-routes")

                                        self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"
                                        self._children_yang_names.add("vrf-route")

                                        self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        self._children_yang_names.add("vrf-seg-route")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("prefix",
                                                        "prefix_length") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)


                                    class VrfRoute(Entity):
                                        """
                                        A connected or recursive  static route
                                        
                                        .. attribute:: vrf_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                            self.yang_name = "vrf-route"
                                            self.yang_parent_name = "vrf-prefix-topology"

                                            self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            self._children_yang_names.add("vrf-next-hop-table")


                                        class VrfNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                self.yang_name = "vrf-next-hop-table"
                                                self.yang_parent_name = "vrf-route"

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-table" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_explicit_path_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name"):
                                                    for c in self.vrf_next_hop_interface_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_data())

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-route" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-table"):
                                                if (self.vrf_next_hop_table is None):
                                                    self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                    self.vrf_next_hop_table.parent = self
                                                    self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                                return self.vrf_next_hop_table

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-table"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class VrfRecurseRoutes(Entity):
                                        """
                                        A recursive next VRF static route
                                        
                                        .. attribute:: vrf_recurse_route
                                        
                                        	A recursive next vrf static route
                                        	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                            self.yang_name = "vrf-recurse-routes"
                                            self.yang_parent_name = "vrf-prefix-topology"

                                            self.vrf_recurse_route = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)


                                        class VrfRecurseRoute(Entity):
                                            """
                                            A recursive next vrf static route
                                            
                                            .. attribute:: vrf_name  <key>
                                            
                                            	Fallback or recusive VRF name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: vrf_recursive_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                self.yang_name = "vrf-recurse-route"
                                                self.yang_parent_name = "vrf-recurse-routes"

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                self._children_yang_names.add("vrf-recursive-next-hop-table")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("vrf_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)


                                            class VrfRecursiveNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-recursive-next-hop-table"
                                                    self.yang_parent_name = "vrf-recurse-route"

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-recursive-next-hop-table" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                        for c in self.vrf_next_hop_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_explicit_path_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name"):
                                                        for c in self.vrf_next_hop_interface_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                        for c in self.vrf_next_hop_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.vrf_name.is_set or
                                                    (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.vrf_name.yfilter != YFilter.not_set or
                                                    (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-recursive-next-hop-table"):
                                                    if (self.vrf_recursive_next_hop_table is None):
                                                        self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                        self.vrf_recursive_next_hop_table.parent = self
                                                        self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                    return self.vrf_recursive_next_hop_table

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-recursive-next-hop-table" or name == "vrf-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "vrf-name"):
                                                    self.vrf_name = value
                                                    self.vrf_name.value_namespace = name_space
                                                    self.vrf_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_recurse_route:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_recurse_route:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-recurse-routes" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-recurse-route"):
                                                for c in self.vrf_recurse_route:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_recurse_route.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-recurse-route"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class VrfSegRoute(Entity):
                                        """
                                        A static segment route
                                        
                                        .. attribute:: segment_route_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                            self.yang_name = "vrf-seg-route"
                                            self.yang_parent_name = "vrf-prefix-topology"

                                            self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            self._children_yang_names.add("segment-route-next-hop-table")


                                        class SegmentRouteNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                self.yang_name = "segment-route-next-hop-table"
                                                self.yang_parent_name = "vrf-seg-route"

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "segment-route-next-hop-table" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_explicit_path_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name"):
                                                    for c in self.vrf_next_hop_interface_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_data())

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-seg-route" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "segment-route-next-hop-table"):
                                                if (self.segment_route_next_hop_table is None):
                                                    self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                    self.segment_route_next_hop_table.parent = self
                                                    self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                                return self.segment_route_next_hop_table

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "segment-route-next-hop-table"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.prefix.is_set or
                                            self.prefix_length.is_set or
                                            (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_data()) or
                                            (self.vrf_route is not None and self.vrf_route.has_data()) or
                                            (self.vrf_seg_route is not None and self.vrf_seg_route.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.prefix.yfilter != YFilter.not_set or
                                            self.prefix_length.yfilter != YFilter.not_set or
                                            (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_operation()) or
                                            (self.vrf_route is not None and self.vrf_route.has_operation()) or
                                            (self.vrf_seg_route is not None and self.vrf_seg_route.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix.get_name_leafdata())
                                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-recurse-routes"):
                                            if (self.vrf_recurse_routes is None):
                                                self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                                self.vrf_recurse_routes.parent = self
                                                self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                            return self.vrf_recurse_routes

                                        if (child_yang_name == "vrf-route"):
                                            if (self.vrf_route is None):
                                                self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                                self.vrf_route.parent = self
                                                self._children_name_map["vrf_route"] = "vrf-route"
                                            return self.vrf_route

                                        if (child_yang_name == "vrf-seg-route"):
                                            if (self.vrf_seg_route is None):
                                                self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                                self.vrf_seg_route.parent = self
                                                self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                            return self.vrf_seg_route

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-recurse-routes" or name == "vrf-route" or name == "vrf-seg-route" or name == "prefix" or name == "prefix-length"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "prefix"):
                                            self.prefix = value
                                            self.prefix.value_namespace = name_space
                                            self.prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "prefix-length"):
                                            self.prefix_length = value
                                            self.prefix_length.value_namespace = name_space
                                            self.prefix_length.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vrf_prefix_topology:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.vrf_prefix_topology:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-prefix-topologies" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-prefix-topology"):
                                        for c in self.vrf_prefix_topology:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vrf_prefix_topology.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-prefix-topology"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_data())

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "default-topology" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "vrf-prefix-topologies"):
                                    if (self.vrf_prefix_topologies is None):
                                        self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies()
                                        self.vrf_prefix_topologies.parent = self
                                        self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                    return self.vrf_prefix_topologies

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "vrf-prefix-topologies"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.default_topology is not None and self.default_topology.has_data()) or
                                (self.topologies is not None and self.topologies.has_data()) or
                                (self.vrf_prefixes is not None and self.vrf_prefixes.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.default_topology is not None and self.default_topology.has_operation()) or
                                (self.topologies is not None and self.topologies.has_operation()) or
                                (self.vrf_prefixes is not None and self.vrf_prefixes.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "vrf-multicast" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "default-topology"):
                                if (self.default_topology is None):
                                    self.default_topology = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology()
                                    self.default_topology.parent = self
                                    self._children_name_map["default_topology"] = "default-topology"
                                return self.default_topology

                            if (child_yang_name == "topologies"):
                                if (self.topologies is None):
                                    self.topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies()
                                    self.topologies.parent = self
                                    self._children_name_map["topologies"] = "topologies"
                                return self.topologies

                            if (child_yang_name == "vrf-prefixes"):
                                if (self.vrf_prefixes is None):
                                    self.vrf_prefixes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes()
                                    self.vrf_prefixes.parent = self
                                    self._children_name_map["vrf_prefixes"] = "vrf-prefixes"
                                return self.vrf_prefixes

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "default-topology" or name == "topologies" or name == "vrf-prefixes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.vrf_multicast is not None and self.vrf_multicast.has_data()) or
                            (self.vrf_unicast is not None and self.vrf_unicast.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.vrf_multicast is not None and self.vrf_multicast.has_operation()) or
                            (self.vrf_unicast is not None and self.vrf_unicast.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "vrfipv6" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "vrf-multicast"):
                            if (self.vrf_multicast is None):
                                self.vrf_multicast = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast()
                                self.vrf_multicast.parent = self
                                self._children_name_map["vrf_multicast"] = "vrf-multicast"
                            return self.vrf_multicast

                        if (child_yang_name == "vrf-unicast"):
                            if (self.vrf_unicast is None):
                                self.vrf_unicast = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast()
                                self.vrf_unicast.parent = self
                                self._children_name_map["vrf_unicast"] = "vrf-unicast"
                            return self.vrf_unicast

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "vrf-multicast" or name == "vrf-unicast"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.vrfipv4 is not None and self.vrfipv4.has_data()) or
                        (self.vrfipv6 is not None and self.vrfipv6.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.vrfipv4 is not None and self.vrfipv4.has_operation()) or
                        (self.vrfipv6 is not None and self.vrfipv6.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "address-family" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "vrfipv4"):
                        if (self.vrfipv4 is None):
                            self.vrfipv4 = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4()
                            self.vrfipv4.parent = self
                            self._children_name_map["vrfipv4"] = "vrfipv4"
                        return self.vrfipv4

                    if (child_yang_name == "vrfipv6"):
                        if (self.vrfipv6 is None):
                            self.vrfipv6 = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6()
                            self.vrfipv6.parent = self
                            self._children_name_map["vrfipv6"] = "vrfipv6"
                        return self.vrfipv6

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "vrfipv4" or name == "vrfipv6"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.vrf_name.is_set or
                    (self.address_family is not None and self.address_family.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.vrf_name.yfilter != YFilter.not_set or
                    (self.address_family is not None and self.address_family.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "vrf" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/vrfs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "address-family"):
                    if (self.address_family is None):
                        self.address_family = RouterStatic.Vrfs.Vrf.AddressFamily()
                        self.address_family.parent = self
                        self._children_name_map["address_family"] = "address-family"
                    return self.address_family

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "address-family" or name == "vrf-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "vrf-name"):
                    self.vrf_name = value
                    self.vrf_name.value_namespace = name_space
                    self.vrf_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.vrf:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.vrf:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "vrfs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "vrf"):
                for c in self.vrf:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RouterStatic.Vrfs.Vrf()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.vrf.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "vrf"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class DefaultVrf(Entity):
        """
        Default VRF configuration
        
        .. attribute:: address_family
        
        	Address family configuration
        	**type**\:   :py:class:`AddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily>`
        
        

        """

        _prefix = 'ip-static-cfg'
        _revision = '2015-09-10'

        def __init__(self):
            super(RouterStatic.DefaultVrf, self).__init__()

            self.yang_name = "default-vrf"
            self.yang_parent_name = "router-static"

            self.address_family = RouterStatic.DefaultVrf.AddressFamily()
            self.address_family.parent = self
            self._children_name_map["address_family"] = "address-family"
            self._children_yang_names.add("address-family")


        class AddressFamily(Entity):
            """
            Address family configuration
            
            .. attribute:: vrfipv4
            
            	IPv4 static configuration
            	**type**\:   :py:class:`Vrfipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4>`
            
            .. attribute:: vrfipv6
            
            	IPv6 static configuration
            	**type**\:   :py:class:`Vrfipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6>`
            
            

            """

            _prefix = 'ip-static-cfg'
            _revision = '2015-09-10'

            def __init__(self):
                super(RouterStatic.DefaultVrf.AddressFamily, self).__init__()

                self.yang_name = "address-family"
                self.yang_parent_name = "default-vrf"

                self.vrfipv4 = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4()
                self.vrfipv4.parent = self
                self._children_name_map["vrfipv4"] = "vrfipv4"
                self._children_yang_names.add("vrfipv4")

                self.vrfipv6 = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6()
                self.vrfipv6.parent = self
                self._children_name_map["vrfipv6"] = "vrfipv6"
                self._children_yang_names.add("vrfipv6")


            class Vrfipv4(Entity):
                """
                IPv4 static configuration
                
                .. attribute:: vrf_multicast
                
                	Multicast static configuration
                	**type**\:   :py:class:`VrfMulticast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast>`
                
                .. attribute:: vrf_unicast
                
                	Unicast static configuration
                	**type**\:   :py:class:`VrfUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast>`
                
                

                """

                _prefix = 'ip-static-cfg'
                _revision = '2015-09-10'

                def __init__(self):
                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4, self).__init__()

                    self.yang_name = "vrfipv4"
                    self.yang_parent_name = "address-family"

                    self.vrf_multicast = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast()
                    self.vrf_multicast.parent = self
                    self._children_name_map["vrf_multicast"] = "vrf-multicast"
                    self._children_yang_names.add("vrf-multicast")

                    self.vrf_unicast = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast()
                    self.vrf_unicast.parent = self
                    self._children_name_map["vrf_unicast"] = "vrf-unicast"
                    self._children_yang_names.add("vrf-unicast")


                class VrfUnicast(Entity):
                    """
                    Unicast static configuration
                    
                    .. attribute:: default_topology
                    
                    	Default topology configuration
                    	**type**\:   :py:class:`DefaultTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology>`
                    
                    .. attribute:: topologies
                    
                    	Topology static configuration container
                    	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies>`
                    
                    .. attribute:: vrf_prefixes
                    
                    	The set of all Static Topologies for this AFI
                    	**type**\:   :py:class:`VrfPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes>`
                    
                    

                    """

                    _prefix = 'ip-static-cfg'
                    _revision = '2015-09-10'

                    def __init__(self):
                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast, self).__init__()

                        self.yang_name = "vrf-unicast"
                        self.yang_parent_name = "vrfipv4"

                        self.default_topology = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology()
                        self.default_topology.parent = self
                        self._children_name_map["default_topology"] = "default-topology"
                        self._children_yang_names.add("default-topology")

                        self.topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies()
                        self.topologies.parent = self
                        self._children_name_map["topologies"] = "topologies"
                        self._children_yang_names.add("topologies")

                        self.vrf_prefixes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes()
                        self.vrf_prefixes.parent = self
                        self._children_name_map["vrf_prefixes"] = "vrf-prefixes"
                        self._children_yang_names.add("vrf-prefixes")


                    class Topologies(Entity):
                        """
                        Topology static configuration container
                        
                        .. attribute:: topology
                        
                        	Topology static configuration
                        	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2015-09-10'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies, self).__init__()

                            self.yang_name = "topologies"
                            self.yang_parent_name = "vrf-unicast"

                            self.topology = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies, self).__setattr__(name, value)


                        class Topology(Entity):
                            """
                            Topology static configuration
                            
                            .. attribute:: topology_name  <key>
                            
                            	Topology name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: vrf_prefix_topologies
                            
                            	The set of all Static Topologies for this AFI
                            	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2015-09-10'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology, self).__init__()

                                self.yang_name = "topology"
                                self.yang_parent_name = "topologies"

                                self.topology_name = YLeaf(YType.str, "topology-name")

                                self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies()
                                self.vrf_prefix_topologies.parent = self
                                self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                self._children_yang_names.add("vrf-prefix-topologies")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("topology_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology, self).__setattr__(name, value)


                            class VrfPrefixTopologies(Entity):
                                """
                                The set of all Static Topologies for this AFI.
                                
                                .. attribute:: vrf_prefix_topology
                                
                                	A static route
                                	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, self).__init__()

                                    self.yang_name = "vrf-prefix-topologies"
                                    self.yang_parent_name = "topology"

                                    self.vrf_prefix_topology = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, self).__setattr__(name, value)


                                class VrfPrefixTopology(Entity):
                                    """
                                    A static route
                                    
                                    .. attribute:: prefix  <key>
                                    
                                    	Destination prefix
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: prefix_length  <key>
                                    
                                    	Destination prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: vrf_recurse_routes
                                    
                                    	A recursive next VRF static route
                                    	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                    
                                    .. attribute:: vrf_route
                                    
                                    	A connected or recursive  static route
                                    	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                    
                                    .. attribute:: vrf_seg_route
                                    
                                    	A static segment route
                                    	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                        self.yang_name = "vrf-prefix-topology"
                                        self.yang_parent_name = "vrf-prefix-topologies"

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                        self._children_yang_names.add("vrf-recurse-routes")

                                        self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"
                                        self._children_yang_names.add("vrf-route")

                                        self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        self._children_yang_names.add("vrf-seg-route")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("prefix",
                                                        "prefix_length") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)


                                    class VrfRoute(Entity):
                                        """
                                        A connected or recursive  static route
                                        
                                        .. attribute:: vrf_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                            self.yang_name = "vrf-route"
                                            self.yang_parent_name = "vrf-prefix-topology"

                                            self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            self._children_yang_names.add("vrf-next-hop-table")


                                        class VrfNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                self.yang_name = "vrf-next-hop-table"
                                                self.yang_parent_name = "vrf-route"

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-table" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_explicit_path_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name"):
                                                    for c in self.vrf_next_hop_interface_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_data())

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-route" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-table"):
                                                if (self.vrf_next_hop_table is None):
                                                    self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                    self.vrf_next_hop_table.parent = self
                                                    self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                                return self.vrf_next_hop_table

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-table"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class VrfRecurseRoutes(Entity):
                                        """
                                        A recursive next VRF static route
                                        
                                        .. attribute:: vrf_recurse_route
                                        
                                        	A recursive next vrf static route
                                        	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                            self.yang_name = "vrf-recurse-routes"
                                            self.yang_parent_name = "vrf-prefix-topology"

                                            self.vrf_recurse_route = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)


                                        class VrfRecurseRoute(Entity):
                                            """
                                            A recursive next vrf static route
                                            
                                            .. attribute:: vrf_name  <key>
                                            
                                            	Fallback or recusive VRF name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: vrf_recursive_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                self.yang_name = "vrf-recurse-route"
                                                self.yang_parent_name = "vrf-recurse-routes"

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                self._children_yang_names.add("vrf-recursive-next-hop-table")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("vrf_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)


                                            class VrfRecursiveNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-recursive-next-hop-table"
                                                    self.yang_parent_name = "vrf-recurse-route"

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-recursive-next-hop-table" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                        for c in self.vrf_next_hop_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_explicit_path_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name"):
                                                        for c in self.vrf_next_hop_interface_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                        for c in self.vrf_next_hop_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.vrf_name.is_set or
                                                    (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.vrf_name.yfilter != YFilter.not_set or
                                                    (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-recursive-next-hop-table"):
                                                    if (self.vrf_recursive_next_hop_table is None):
                                                        self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                        self.vrf_recursive_next_hop_table.parent = self
                                                        self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                    return self.vrf_recursive_next_hop_table

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-recursive-next-hop-table" or name == "vrf-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "vrf-name"):
                                                    self.vrf_name = value
                                                    self.vrf_name.value_namespace = name_space
                                                    self.vrf_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_recurse_route:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_recurse_route:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-recurse-routes" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-recurse-route"):
                                                for c in self.vrf_recurse_route:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_recurse_route.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-recurse-route"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class VrfSegRoute(Entity):
                                        """
                                        A static segment route
                                        
                                        .. attribute:: segment_route_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                            self.yang_name = "vrf-seg-route"
                                            self.yang_parent_name = "vrf-prefix-topology"

                                            self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            self._children_yang_names.add("segment-route-next-hop-table")


                                        class SegmentRouteNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                self.yang_name = "segment-route-next-hop-table"
                                                self.yang_parent_name = "vrf-seg-route"

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "segment-route-next-hop-table" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_explicit_path_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name"):
                                                    for c in self.vrf_next_hop_interface_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_data())

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-seg-route" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "segment-route-next-hop-table"):
                                                if (self.segment_route_next_hop_table is None):
                                                    self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                    self.segment_route_next_hop_table.parent = self
                                                    self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                                return self.segment_route_next_hop_table

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "segment-route-next-hop-table"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.prefix.is_set or
                                            self.prefix_length.is_set or
                                            (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_data()) or
                                            (self.vrf_route is not None and self.vrf_route.has_data()) or
                                            (self.vrf_seg_route is not None and self.vrf_seg_route.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.prefix.yfilter != YFilter.not_set or
                                            self.prefix_length.yfilter != YFilter.not_set or
                                            (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_operation()) or
                                            (self.vrf_route is not None and self.vrf_route.has_operation()) or
                                            (self.vrf_seg_route is not None and self.vrf_seg_route.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix.get_name_leafdata())
                                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-recurse-routes"):
                                            if (self.vrf_recurse_routes is None):
                                                self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                                self.vrf_recurse_routes.parent = self
                                                self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                            return self.vrf_recurse_routes

                                        if (child_yang_name == "vrf-route"):
                                            if (self.vrf_route is None):
                                                self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                                self.vrf_route.parent = self
                                                self._children_name_map["vrf_route"] = "vrf-route"
                                            return self.vrf_route

                                        if (child_yang_name == "vrf-seg-route"):
                                            if (self.vrf_seg_route is None):
                                                self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                                self.vrf_seg_route.parent = self
                                                self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                            return self.vrf_seg_route

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-recurse-routes" or name == "vrf-route" or name == "vrf-seg-route" or name == "prefix" or name == "prefix-length"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "prefix"):
                                            self.prefix = value
                                            self.prefix.value_namespace = name_space
                                            self.prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "prefix-length"):
                                            self.prefix_length = value
                                            self.prefix_length.value_namespace = name_space
                                            self.prefix_length.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vrf_prefix_topology:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.vrf_prefix_topology:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-prefix-topologies" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-prefix-topology"):
                                        for c in self.vrf_prefix_topology:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vrf_prefix_topology.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-prefix-topology"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.topology_name.is_set or
                                    (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.topology_name.yfilter != YFilter.not_set or
                                    (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "topology" + "[topology-name='" + self.topology_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-unicast/topologies/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.topology_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "vrf-prefix-topologies"):
                                    if (self.vrf_prefix_topologies is None):
                                        self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies()
                                        self.vrf_prefix_topologies.parent = self
                                        self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                    return self.vrf_prefix_topologies

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "vrf-prefix-topologies" or name == "topology-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "topology-name"):
                                    self.topology_name = value
                                    self.topology_name.value_namespace = name_space
                                    self.topology_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.topology:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.topology:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "topologies" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-unicast/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "topology"):
                                for c in self.topology:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.topology.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "topology"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class VrfPrefixes(Entity):
                        """
                        The set of all Static Topologies for this AFI.
                        
                        .. attribute:: vrf_prefix
                        
                        	A static route
                        	**type**\: list of    :py:class:`VrfPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2015-09-10'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes, self).__init__()

                            self.yang_name = "vrf-prefixes"
                            self.yang_parent_name = "vrf-unicast"

                            self.vrf_prefix = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes, self).__setattr__(name, value)


                        class VrfPrefix(Entity):
                            """
                            A static route
                            
                            .. attribute:: prefix  <key>
                            
                            	Destination prefix
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: prefix_length  <key>
                            
                            	Destination prefix length
                            	**type**\:  int
                            
                            	**range:** 0..128
                            
                            .. attribute:: vrf_recurse_routes
                            
                            	A recursive next VRF static route
                            	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes>`
                            
                            .. attribute:: vrf_route
                            
                            	A connected or recursive  static route
                            	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute>`
                            
                            .. attribute:: vrf_seg_route
                            
                            	A static segment route
                            	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2015-09-10'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix, self).__init__()

                                self.yang_name = "vrf-prefix"
                                self.yang_parent_name = "vrf-prefixes"

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                self.vrf_recurse_routes.parent = self
                                self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                self._children_yang_names.add("vrf-recurse-routes")

                                self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute()
                                self.vrf_route.parent = self
                                self._children_name_map["vrf_route"] = "vrf-route"
                                self._children_yang_names.add("vrf-route")

                                self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                self.vrf_seg_route.parent = self
                                self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                self._children_yang_names.add("vrf-seg-route")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("prefix",
                                                "prefix_length") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix, self).__setattr__(name, value)


                            class VrfRoute(Entity):
                                """
                                A connected or recursive  static route
                                
                                .. attribute:: vrf_next_hop_table
                                
                                	The set of nexthop information configured for this route
                                	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute, self).__init__()

                                    self.yang_name = "vrf-route"
                                    self.yang_parent_name = "vrf-prefix"

                                    self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                    self.vrf_next_hop_table.parent = self
                                    self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                    self._children_yang_names.add("vrf-next-hop-table")


                                class VrfNextHopTable(Entity):
                                    """
                                    The set of nexthop information configured for
                                    this route
                                    
                                    .. attribute:: vrf_next_hop_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__init__()

                                        self.yang_name = "vrf-next-hop-table"
                                        self.yang_parent_name = "vrf-route"

                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                        self.vrf_next_hop_interface_name = YList(self)
                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)


                                    class VrfNextHopInterfaceName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name"
                                            self.yang_parent_name = "vrf-next-hop-table"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                            self.yang_parent_name = "vrf-next-hop-table"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "next_hop_address",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.next_hop_address.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-address"):
                                                self.next_hop_address = value
                                                self.next_hop_address.value_namespace = name_space
                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                            self.yang_parent_name = "vrf-next-hop-table"

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("next_hop_address",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.next_hop_address.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "next-hop-address"):
                                                self.next_hop_address = value
                                                self.next_hop_address.value_namespace = name_space
                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                            self.yang_parent_name = "vrf-next-hop-table"

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("next_hop_address",
                                                            "explicit_path_name",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.next_hop_address.is_set or
                                                self.explicit_path_name.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                self.explicit_path_name.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                            if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "next-hop-address"):
                                                self.next_hop_address = value
                                                self.next_hop_address.value_namespace = name_space
                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "explicit-path-name"):
                                                self.explicit_path_name = value
                                                self.explicit_path_name.value_namespace = name_space
                                                self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                            self.yang_parent_name = "vrf-next-hop-table"

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("explicit_path_name",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.explicit_path_name.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.explicit_path_name.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "explicit-path-name"):
                                                self.explicit_path_name = value
                                                self.explicit_path_name.value_namespace = name_space
                                                self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vrf_next_hop_explicit_path_name:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.vrf_next_hop_explicit_path_name:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-next-hop-table" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_explicit_path_name.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-interface-name"):
                                            for c in self.vrf_next_hop_interface_name:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_interface_name.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                            for c in self.vrf_next_hop_next_hop_address:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_next_hop_address.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_data())

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-route" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-next-hop-table"):
                                        if (self.vrf_next_hop_table is None):
                                            self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        return self.vrf_next_hop_table

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-next-hop-table"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class VrfRecurseRoutes(Entity):
                                """
                                A recursive next VRF static route
                                
                                .. attribute:: vrf_recurse_route
                                
                                	A recursive next vrf static route
                                	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__init__()

                                    self.yang_name = "vrf-recurse-routes"
                                    self.yang_parent_name = "vrf-prefix"

                                    self.vrf_recurse_route = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__setattr__(name, value)


                                class VrfRecurseRoute(Entity):
                                    """
                                    A recursive next vrf static route
                                    
                                    .. attribute:: vrf_name  <key>
                                    
                                    	Fallback or recusive VRF name
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: vrf_recursive_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                        self.yang_name = "vrf-recurse-route"
                                        self.yang_parent_name = "vrf-recurse-routes"

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                        self.vrf_recursive_next_hop_table.parent = self
                                        self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                        self._children_yang_names.add("vrf-recursive-next-hop-table")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vrf_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)


                                    class VrfRecursiveNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                            self.yang_name = "vrf-recursive-next-hop-table"
                                            self.yang_parent_name = "vrf-recurse-route"

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-recursive-next-hop-table" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_explicit_path_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name"):
                                                for c in self.vrf_next_hop_interface_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.vrf_name.is_set or
                                            (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vrf_name.yfilter != YFilter.not_set or
                                            (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-recursive-next-hop-table"):
                                            if (self.vrf_recursive_next_hop_table is None):
                                                self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            return self.vrf_recursive_next_hop_table

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-recursive-next-hop-table" or name == "vrf-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vrf-name"):
                                            self.vrf_name = value
                                            self.vrf_name.value_namespace = name_space
                                            self.vrf_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vrf_recurse_route:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.vrf_recurse_route:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-recurse-routes" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-recurse-route"):
                                        for c in self.vrf_recurse_route:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vrf_recurse_route.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-recurse-route"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class VrfSegRoute(Entity):
                                """
                                A static segment route
                                
                                .. attribute:: segment_route_next_hop_table
                                
                                	The set of nexthop information configured for this route
                                	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute, self).__init__()

                                    self.yang_name = "vrf-seg-route"
                                    self.yang_parent_name = "vrf-prefix"

                                    self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                    self.segment_route_next_hop_table.parent = self
                                    self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                    self._children_yang_names.add("segment-route-next-hop-table")


                                class SegmentRouteNextHopTable(Entity):
                                    """
                                    The set of nexthop information configured for
                                    this route
                                    
                                    .. attribute:: vrf_next_hop_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                        self.yang_name = "segment-route-next-hop-table"
                                        self.yang_parent_name = "vrf-seg-route"

                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                        self.vrf_next_hop_interface_name = YList(self)
                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)


                                    class VrfNextHopInterfaceName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                            self.yang_parent_name = "segment-route-next-hop-table"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "next_hop_address",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.next_hop_address.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-address"):
                                                self.next_hop_address = value
                                                self.next_hop_address.value_namespace = name_space
                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                            self.yang_parent_name = "segment-route-next-hop-table"

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("next_hop_address",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.next_hop_address.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "next-hop-address"):
                                                self.next_hop_address = value
                                                self.next_hop_address.value_namespace = name_space
                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("next_hop_address",
                                                            "explicit_path_name",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.next_hop_address.is_set or
                                                self.explicit_path_name.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                self.explicit_path_name.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                            if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "next-hop-address"):
                                                self.next_hop_address = value
                                                self.next_hop_address.value_namespace = name_space
                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "explicit-path-name"):
                                                self.explicit_path_name = value
                                                self.explicit_path_name.value_namespace = name_space
                                                self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("explicit_path_name",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.explicit_path_name.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.explicit_path_name.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "explicit-path-name"):
                                                self.explicit_path_name = value
                                                self.explicit_path_name.value_namespace = name_space
                                                self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vrf_next_hop_explicit_path_name:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.vrf_next_hop_explicit_path_name:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "segment-route-next-hop-table" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_explicit_path_name.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-interface-name"):
                                            for c in self.vrf_next_hop_interface_name:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_interface_name.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                            for c in self.vrf_next_hop_next_hop_address:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_next_hop_address.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_data())

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-seg-route" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "segment-route-next-hop-table"):
                                        if (self.segment_route_next_hop_table is None):
                                            self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        return self.segment_route_next_hop_table

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "segment-route-next-hop-table"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.prefix.is_set or
                                    self.prefix_length.is_set or
                                    (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_data()) or
                                    (self.vrf_route is not None and self.vrf_route.has_data()) or
                                    (self.vrf_seg_route is not None and self.vrf_seg_route.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.prefix.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_operation()) or
                                    (self.vrf_route is not None and self.vrf_route.has_operation()) or
                                    (self.vrf_seg_route is not None and self.vrf_seg_route.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vrf-prefix" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-unicast/vrf-prefixes/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "vrf-recurse-routes"):
                                    if (self.vrf_recurse_routes is None):
                                        self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                    return self.vrf_recurse_routes

                                if (child_yang_name == "vrf-route"):
                                    if (self.vrf_route is None):
                                        self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"
                                    return self.vrf_route

                                if (child_yang_name == "vrf-seg-route"):
                                    if (self.vrf_seg_route is None):
                                        self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    return self.vrf_seg_route

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "vrf-recurse-routes" or name == "vrf-route" or name == "vrf-seg-route" or name == "prefix" or name == "prefix-length"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "prefix"):
                                    self.prefix = value
                                    self.prefix.value_namespace = name_space
                                    self.prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.vrf_prefix:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.vrf_prefix:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "vrf-prefixes" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-unicast/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "vrf-prefix"):
                                for c in self.vrf_prefix:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.vrf_prefix.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "vrf-prefix"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class DefaultTopology(Entity):
                        """
                        Default topology configuration
                        
                        .. attribute:: vrf_prefix_topologies
                        
                        	The set of all Static Topologies for this AFI
                        	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2015-09-10'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology, self).__init__()

                            self.yang_name = "default-topology"
                            self.yang_parent_name = "vrf-unicast"

                            self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies()
                            self.vrf_prefix_topologies.parent = self
                            self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                            self._children_yang_names.add("vrf-prefix-topologies")


                        class VrfPrefixTopologies(Entity):
                            """
                            The set of all Static Topologies for this AFI.
                            
                            .. attribute:: vrf_prefix_topology
                            
                            	A static route
                            	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2015-09-10'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies, self).__init__()

                                self.yang_name = "vrf-prefix-topologies"
                                self.yang_parent_name = "default-topology"

                                self.vrf_prefix_topology = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies, self).__setattr__(name, value)


                            class VrfPrefixTopology(Entity):
                                """
                                A static route
                                
                                .. attribute:: prefix  <key>
                                
                                	Destination prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: prefix_length  <key>
                                
                                	Destination prefix length
                                	**type**\:  int
                                
                                	**range:** 0..128
                                
                                .. attribute:: vrf_recurse_routes
                                
                                	A recursive next VRF static route
                                	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                
                                .. attribute:: vrf_route
                                
                                	A connected or recursive  static route
                                	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                
                                .. attribute:: vrf_seg_route
                                
                                	A static segment route
                                	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                    self.yang_name = "vrf-prefix-topology"
                                    self.yang_parent_name = "vrf-prefix-topologies"

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                    self.vrf_recurse_routes.parent = self
                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                    self._children_yang_names.add("vrf-recurse-routes")

                                    self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                    self.vrf_route.parent = self
                                    self._children_name_map["vrf_route"] = "vrf-route"
                                    self._children_yang_names.add("vrf-route")

                                    self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                    self.vrf_seg_route.parent = self
                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    self._children_yang_names.add("vrf-seg-route")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("prefix",
                                                    "prefix_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)


                                class VrfRoute(Entity):
                                    """
                                    A connected or recursive  static route
                                    
                                    .. attribute:: vrf_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                        self.yang_name = "vrf-route"
                                        self.yang_parent_name = "vrf-prefix-topology"

                                        self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                        self.vrf_next_hop_table.parent = self
                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        self._children_yang_names.add("vrf-next-hop-table")


                                    class VrfNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                            self.yang_name = "vrf-next-hop-table"
                                            self.yang_parent_name = "vrf-route"

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-table" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_explicit_path_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name"):
                                                for c in self.vrf_next_hop_interface_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_data())

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-route" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-next-hop-table"):
                                            if (self.vrf_next_hop_table is None):
                                                self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                self.vrf_next_hop_table.parent = self
                                                self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            return self.vrf_next_hop_table

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-next-hop-table"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class VrfRecurseRoutes(Entity):
                                    """
                                    A recursive next VRF static route
                                    
                                    .. attribute:: vrf_recurse_route
                                    
                                    	A recursive next vrf static route
                                    	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                        self.yang_name = "vrf-recurse-routes"
                                        self.yang_parent_name = "vrf-prefix-topology"

                                        self.vrf_recurse_route = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)


                                    class VrfRecurseRoute(Entity):
                                        """
                                        A recursive next vrf static route
                                        
                                        .. attribute:: vrf_name  <key>
                                        
                                        	Fallback or recusive VRF name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: vrf_recursive_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                            self.yang_name = "vrf-recurse-route"
                                            self.yang_parent_name = "vrf-recurse-routes"

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                            self.vrf_recursive_next_hop_table.parent = self
                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            self._children_yang_names.add("vrf-recursive-next-hop-table")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vrf_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)


                                        class VrfRecursiveNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                self.yang_name = "vrf-recursive-next-hop-table"
                                                self.yang_parent_name = "vrf-recurse-route"

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-recursive-next-hop-table" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_explicit_path_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name"):
                                                    for c in self.vrf_next_hop_interface_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.vrf_name.is_set or
                                                (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vrf_name.yfilter != YFilter.not_set or
                                                (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-recursive-next-hop-table"):
                                                if (self.vrf_recursive_next_hop_table is None):
                                                    self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                    self.vrf_recursive_next_hop_table.parent = self
                                                    self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                return self.vrf_recursive_next_hop_table

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-recursive-next-hop-table" or name == "vrf-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vrf-name"):
                                                self.vrf_name = value
                                                self.vrf_name.value_namespace = name_space
                                                self.vrf_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vrf_recurse_route:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.vrf_recurse_route:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-recurse-routes" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-recurse-route"):
                                            for c in self.vrf_recurse_route:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_recurse_route.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-recurse-route"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class VrfSegRoute(Entity):
                                    """
                                    A static segment route
                                    
                                    .. attribute:: segment_route_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                        self.yang_name = "vrf-seg-route"
                                        self.yang_parent_name = "vrf-prefix-topology"

                                        self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                        self.segment_route_next_hop_table.parent = self
                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        self._children_yang_names.add("segment-route-next-hop-table")


                                    class SegmentRouteNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                            self.yang_name = "segment-route-next-hop-table"
                                            self.yang_parent_name = "vrf-seg-route"

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "segment-route-next-hop-table" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_explicit_path_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name"):
                                                for c in self.vrf_next_hop_interface_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_data())

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-seg-route" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "segment-route-next-hop-table"):
                                            if (self.segment_route_next_hop_table is None):
                                                self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                self.segment_route_next_hop_table.parent = self
                                                self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            return self.segment_route_next_hop_table

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "segment-route-next-hop-table"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.prefix.is_set or
                                        self.prefix_length.is_set or
                                        (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_data()) or
                                        (self.vrf_route is not None and self.vrf_route.has_data()) or
                                        (self.vrf_seg_route is not None and self.vrf_seg_route.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.prefix.yfilter != YFilter.not_set or
                                        self.prefix_length.yfilter != YFilter.not_set or
                                        (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_operation()) or
                                        (self.vrf_route is not None and self.vrf_route.has_operation()) or
                                        (self.vrf_seg_route is not None and self.vrf_seg_route.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-unicast/default-topology/vrf-prefix-topologies/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-recurse-routes"):
                                        if (self.vrf_recurse_routes is None):
                                            self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                            self.vrf_recurse_routes.parent = self
                                            self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                        return self.vrf_recurse_routes

                                    if (child_yang_name == "vrf-route"):
                                        if (self.vrf_route is None):
                                            self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                            self.vrf_route.parent = self
                                            self._children_name_map["vrf_route"] = "vrf-route"
                                        return self.vrf_route

                                    if (child_yang_name == "vrf-seg-route"):
                                        if (self.vrf_seg_route is None):
                                            self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                            self.vrf_seg_route.parent = self
                                            self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        return self.vrf_seg_route

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-recurse-routes" or name == "vrf-route" or name == "vrf-seg-route" or name == "prefix" or name == "prefix-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "prefix"):
                                        self.prefix = value
                                        self.prefix.value_namespace = name_space
                                        self.prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-length"):
                                        self.prefix_length = value
                                        self.prefix_length.value_namespace = name_space
                                        self.prefix_length.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.vrf_prefix_topology:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.vrf_prefix_topology:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vrf-prefix-topologies" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-unicast/default-topology/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "vrf-prefix-topology"):
                                    for c in self.vrf_prefix_topology:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.vrf_prefix_topology.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "vrf-prefix-topology"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "default-topology" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-unicast/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "vrf-prefix-topologies"):
                                if (self.vrf_prefix_topologies is None):
                                    self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies()
                                    self.vrf_prefix_topologies.parent = self
                                    self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                return self.vrf_prefix_topologies

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "vrf-prefix-topologies"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.default_topology is not None and self.default_topology.has_data()) or
                            (self.topologies is not None and self.topologies.has_data()) or
                            (self.vrf_prefixes is not None and self.vrf_prefixes.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.default_topology is not None and self.default_topology.has_operation()) or
                            (self.topologies is not None and self.topologies.has_operation()) or
                            (self.vrf_prefixes is not None and self.vrf_prefixes.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "vrf-unicast" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "default-topology"):
                            if (self.default_topology is None):
                                self.default_topology = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology()
                                self.default_topology.parent = self
                                self._children_name_map["default_topology"] = "default-topology"
                            return self.default_topology

                        if (child_yang_name == "topologies"):
                            if (self.topologies is None):
                                self.topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies()
                                self.topologies.parent = self
                                self._children_name_map["topologies"] = "topologies"
                            return self.topologies

                        if (child_yang_name == "vrf-prefixes"):
                            if (self.vrf_prefixes is None):
                                self.vrf_prefixes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes()
                                self.vrf_prefixes.parent = self
                                self._children_name_map["vrf_prefixes"] = "vrf-prefixes"
                            return self.vrf_prefixes

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "default-topology" or name == "topologies" or name == "vrf-prefixes"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class VrfMulticast(Entity):
                    """
                    Multicast static configuration
                    
                    .. attribute:: default_topology
                    
                    	Default topology configuration
                    	**type**\:   :py:class:`DefaultTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology>`
                    
                    .. attribute:: topologies
                    
                    	Topology static configuration container
                    	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies>`
                    
                    .. attribute:: vrf_prefixes
                    
                    	The set of all Static Topologies for this AFI
                    	**type**\:   :py:class:`VrfPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes>`
                    
                    

                    """

                    _prefix = 'ip-static-cfg'
                    _revision = '2015-09-10'

                    def __init__(self):
                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast, self).__init__()

                        self.yang_name = "vrf-multicast"
                        self.yang_parent_name = "vrfipv4"

                        self.default_topology = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology()
                        self.default_topology.parent = self
                        self._children_name_map["default_topology"] = "default-topology"
                        self._children_yang_names.add("default-topology")

                        self.topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies()
                        self.topologies.parent = self
                        self._children_name_map["topologies"] = "topologies"
                        self._children_yang_names.add("topologies")

                        self.vrf_prefixes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes()
                        self.vrf_prefixes.parent = self
                        self._children_name_map["vrf_prefixes"] = "vrf-prefixes"
                        self._children_yang_names.add("vrf-prefixes")


                    class Topologies(Entity):
                        """
                        Topology static configuration container
                        
                        .. attribute:: topology
                        
                        	Topology static configuration
                        	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2015-09-10'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies, self).__init__()

                            self.yang_name = "topologies"
                            self.yang_parent_name = "vrf-multicast"

                            self.topology = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies, self).__setattr__(name, value)


                        class Topology(Entity):
                            """
                            Topology static configuration
                            
                            .. attribute:: topology_name  <key>
                            
                            	Topology name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: vrf_prefix_topologies
                            
                            	The set of all Static Topologies for this AFI
                            	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2015-09-10'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology, self).__init__()

                                self.yang_name = "topology"
                                self.yang_parent_name = "topologies"

                                self.topology_name = YLeaf(YType.str, "topology-name")

                                self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies()
                                self.vrf_prefix_topologies.parent = self
                                self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                self._children_yang_names.add("vrf-prefix-topologies")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("topology_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology, self).__setattr__(name, value)


                            class VrfPrefixTopologies(Entity):
                                """
                                The set of all Static Topologies for this AFI.
                                
                                .. attribute:: vrf_prefix_topology
                                
                                	A static route
                                	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, self).__init__()

                                    self.yang_name = "vrf-prefix-topologies"
                                    self.yang_parent_name = "topology"

                                    self.vrf_prefix_topology = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, self).__setattr__(name, value)


                                class VrfPrefixTopology(Entity):
                                    """
                                    A static route
                                    
                                    .. attribute:: prefix  <key>
                                    
                                    	Destination prefix
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: prefix_length  <key>
                                    
                                    	Destination prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: vrf_recurse_routes
                                    
                                    	A recursive next VRF static route
                                    	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                    
                                    .. attribute:: vrf_route
                                    
                                    	A connected or recursive  static route
                                    	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                    
                                    .. attribute:: vrf_seg_route
                                    
                                    	A static segment route
                                    	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                        self.yang_name = "vrf-prefix-topology"
                                        self.yang_parent_name = "vrf-prefix-topologies"

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                        self._children_yang_names.add("vrf-recurse-routes")

                                        self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"
                                        self._children_yang_names.add("vrf-route")

                                        self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        self._children_yang_names.add("vrf-seg-route")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("prefix",
                                                        "prefix_length") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)


                                    class VrfRoute(Entity):
                                        """
                                        A connected or recursive  static route
                                        
                                        .. attribute:: vrf_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                            self.yang_name = "vrf-route"
                                            self.yang_parent_name = "vrf-prefix-topology"

                                            self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            self._children_yang_names.add("vrf-next-hop-table")


                                        class VrfNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                self.yang_name = "vrf-next-hop-table"
                                                self.yang_parent_name = "vrf-route"

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-table" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_explicit_path_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name"):
                                                    for c in self.vrf_next_hop_interface_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_data())

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-route" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-table"):
                                                if (self.vrf_next_hop_table is None):
                                                    self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                    self.vrf_next_hop_table.parent = self
                                                    self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                                return self.vrf_next_hop_table

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-table"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class VrfRecurseRoutes(Entity):
                                        """
                                        A recursive next VRF static route
                                        
                                        .. attribute:: vrf_recurse_route
                                        
                                        	A recursive next vrf static route
                                        	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                            self.yang_name = "vrf-recurse-routes"
                                            self.yang_parent_name = "vrf-prefix-topology"

                                            self.vrf_recurse_route = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)


                                        class VrfRecurseRoute(Entity):
                                            """
                                            A recursive next vrf static route
                                            
                                            .. attribute:: vrf_name  <key>
                                            
                                            	Fallback or recusive VRF name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: vrf_recursive_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                self.yang_name = "vrf-recurse-route"
                                                self.yang_parent_name = "vrf-recurse-routes"

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                self._children_yang_names.add("vrf-recursive-next-hop-table")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("vrf_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)


                                            class VrfRecursiveNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-recursive-next-hop-table"
                                                    self.yang_parent_name = "vrf-recurse-route"

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-recursive-next-hop-table" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                        for c in self.vrf_next_hop_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_explicit_path_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name"):
                                                        for c in self.vrf_next_hop_interface_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                        for c in self.vrf_next_hop_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.vrf_name.is_set or
                                                    (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.vrf_name.yfilter != YFilter.not_set or
                                                    (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-recursive-next-hop-table"):
                                                    if (self.vrf_recursive_next_hop_table is None):
                                                        self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                        self.vrf_recursive_next_hop_table.parent = self
                                                        self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                    return self.vrf_recursive_next_hop_table

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-recursive-next-hop-table" or name == "vrf-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "vrf-name"):
                                                    self.vrf_name = value
                                                    self.vrf_name.value_namespace = name_space
                                                    self.vrf_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_recurse_route:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_recurse_route:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-recurse-routes" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-recurse-route"):
                                                for c in self.vrf_recurse_route:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_recurse_route.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-recurse-route"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class VrfSegRoute(Entity):
                                        """
                                        A static segment route
                                        
                                        .. attribute:: segment_route_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                            self.yang_name = "vrf-seg-route"
                                            self.yang_parent_name = "vrf-prefix-topology"

                                            self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            self._children_yang_names.add("segment-route-next-hop-table")


                                        class SegmentRouteNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                self.yang_name = "segment-route-next-hop-table"
                                                self.yang_parent_name = "vrf-seg-route"

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "segment-route-next-hop-table" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_explicit_path_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name"):
                                                    for c in self.vrf_next_hop_interface_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_data())

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-seg-route" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "segment-route-next-hop-table"):
                                                if (self.segment_route_next_hop_table is None):
                                                    self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                    self.segment_route_next_hop_table.parent = self
                                                    self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                                return self.segment_route_next_hop_table

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "segment-route-next-hop-table"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.prefix.is_set or
                                            self.prefix_length.is_set or
                                            (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_data()) or
                                            (self.vrf_route is not None and self.vrf_route.has_data()) or
                                            (self.vrf_seg_route is not None and self.vrf_seg_route.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.prefix.yfilter != YFilter.not_set or
                                            self.prefix_length.yfilter != YFilter.not_set or
                                            (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_operation()) or
                                            (self.vrf_route is not None and self.vrf_route.has_operation()) or
                                            (self.vrf_seg_route is not None and self.vrf_seg_route.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix.get_name_leafdata())
                                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-recurse-routes"):
                                            if (self.vrf_recurse_routes is None):
                                                self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                                self.vrf_recurse_routes.parent = self
                                                self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                            return self.vrf_recurse_routes

                                        if (child_yang_name == "vrf-route"):
                                            if (self.vrf_route is None):
                                                self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                                self.vrf_route.parent = self
                                                self._children_name_map["vrf_route"] = "vrf-route"
                                            return self.vrf_route

                                        if (child_yang_name == "vrf-seg-route"):
                                            if (self.vrf_seg_route is None):
                                                self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                                self.vrf_seg_route.parent = self
                                                self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                            return self.vrf_seg_route

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-recurse-routes" or name == "vrf-route" or name == "vrf-seg-route" or name == "prefix" or name == "prefix-length"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "prefix"):
                                            self.prefix = value
                                            self.prefix.value_namespace = name_space
                                            self.prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "prefix-length"):
                                            self.prefix_length = value
                                            self.prefix_length.value_namespace = name_space
                                            self.prefix_length.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vrf_prefix_topology:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.vrf_prefix_topology:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-prefix-topologies" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-prefix-topology"):
                                        for c in self.vrf_prefix_topology:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vrf_prefix_topology.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-prefix-topology"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.topology_name.is_set or
                                    (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.topology_name.yfilter != YFilter.not_set or
                                    (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "topology" + "[topology-name='" + self.topology_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-multicast/topologies/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.topology_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "vrf-prefix-topologies"):
                                    if (self.vrf_prefix_topologies is None):
                                        self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies()
                                        self.vrf_prefix_topologies.parent = self
                                        self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                    return self.vrf_prefix_topologies

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "vrf-prefix-topologies" or name == "topology-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "topology-name"):
                                    self.topology_name = value
                                    self.topology_name.value_namespace = name_space
                                    self.topology_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.topology:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.topology:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "topologies" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-multicast/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "topology"):
                                for c in self.topology:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.topology.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "topology"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class VrfPrefixes(Entity):
                        """
                        The set of all Static Topologies for this AFI.
                        
                        .. attribute:: vrf_prefix
                        
                        	A static route
                        	**type**\: list of    :py:class:`VrfPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2015-09-10'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes, self).__init__()

                            self.yang_name = "vrf-prefixes"
                            self.yang_parent_name = "vrf-multicast"

                            self.vrf_prefix = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes, self).__setattr__(name, value)


                        class VrfPrefix(Entity):
                            """
                            A static route
                            
                            .. attribute:: prefix  <key>
                            
                            	Destination prefix
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: prefix_length  <key>
                            
                            	Destination prefix length
                            	**type**\:  int
                            
                            	**range:** 0..128
                            
                            .. attribute:: vrf_recurse_routes
                            
                            	A recursive next VRF static route
                            	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes>`
                            
                            .. attribute:: vrf_route
                            
                            	A connected or recursive  static route
                            	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute>`
                            
                            .. attribute:: vrf_seg_route
                            
                            	A static segment route
                            	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2015-09-10'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix, self).__init__()

                                self.yang_name = "vrf-prefix"
                                self.yang_parent_name = "vrf-prefixes"

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                self.vrf_recurse_routes.parent = self
                                self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                self._children_yang_names.add("vrf-recurse-routes")

                                self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute()
                                self.vrf_route.parent = self
                                self._children_name_map["vrf_route"] = "vrf-route"
                                self._children_yang_names.add("vrf-route")

                                self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                self.vrf_seg_route.parent = self
                                self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                self._children_yang_names.add("vrf-seg-route")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("prefix",
                                                "prefix_length") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix, self).__setattr__(name, value)


                            class VrfRoute(Entity):
                                """
                                A connected or recursive  static route
                                
                                .. attribute:: vrf_next_hop_table
                                
                                	The set of nexthop information configured for this route
                                	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute, self).__init__()

                                    self.yang_name = "vrf-route"
                                    self.yang_parent_name = "vrf-prefix"

                                    self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                    self.vrf_next_hop_table.parent = self
                                    self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                    self._children_yang_names.add("vrf-next-hop-table")


                                class VrfNextHopTable(Entity):
                                    """
                                    The set of nexthop information configured for
                                    this route
                                    
                                    .. attribute:: vrf_next_hop_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__init__()

                                        self.yang_name = "vrf-next-hop-table"
                                        self.yang_parent_name = "vrf-route"

                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                        self.vrf_next_hop_interface_name = YList(self)
                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)


                                    class VrfNextHopInterfaceName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name"
                                            self.yang_parent_name = "vrf-next-hop-table"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                            self.yang_parent_name = "vrf-next-hop-table"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "next_hop_address",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.next_hop_address.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-address"):
                                                self.next_hop_address = value
                                                self.next_hop_address.value_namespace = name_space
                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                            self.yang_parent_name = "vrf-next-hop-table"

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("next_hop_address",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.next_hop_address.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "next-hop-address"):
                                                self.next_hop_address = value
                                                self.next_hop_address.value_namespace = name_space
                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                            self.yang_parent_name = "vrf-next-hop-table"

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("next_hop_address",
                                                            "explicit_path_name",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.next_hop_address.is_set or
                                                self.explicit_path_name.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                self.explicit_path_name.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                            if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "next-hop-address"):
                                                self.next_hop_address = value
                                                self.next_hop_address.value_namespace = name_space
                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "explicit-path-name"):
                                                self.explicit_path_name = value
                                                self.explicit_path_name.value_namespace = name_space
                                                self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                            self.yang_parent_name = "vrf-next-hop-table"

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("explicit_path_name",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.explicit_path_name.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.explicit_path_name.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "explicit-path-name"):
                                                self.explicit_path_name = value
                                                self.explicit_path_name.value_namespace = name_space
                                                self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vrf_next_hop_explicit_path_name:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.vrf_next_hop_explicit_path_name:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-next-hop-table" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_explicit_path_name.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-interface-name"):
                                            for c in self.vrf_next_hop_interface_name:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_interface_name.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                            for c in self.vrf_next_hop_next_hop_address:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_next_hop_address.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_data())

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-route" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-next-hop-table"):
                                        if (self.vrf_next_hop_table is None):
                                            self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        return self.vrf_next_hop_table

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-next-hop-table"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class VrfRecurseRoutes(Entity):
                                """
                                A recursive next VRF static route
                                
                                .. attribute:: vrf_recurse_route
                                
                                	A recursive next vrf static route
                                	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__init__()

                                    self.yang_name = "vrf-recurse-routes"
                                    self.yang_parent_name = "vrf-prefix"

                                    self.vrf_recurse_route = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__setattr__(name, value)


                                class VrfRecurseRoute(Entity):
                                    """
                                    A recursive next vrf static route
                                    
                                    .. attribute:: vrf_name  <key>
                                    
                                    	Fallback or recusive VRF name
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: vrf_recursive_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                        self.yang_name = "vrf-recurse-route"
                                        self.yang_parent_name = "vrf-recurse-routes"

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                        self.vrf_recursive_next_hop_table.parent = self
                                        self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                        self._children_yang_names.add("vrf-recursive-next-hop-table")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vrf_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)


                                    class VrfRecursiveNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                            self.yang_name = "vrf-recursive-next-hop-table"
                                            self.yang_parent_name = "vrf-recurse-route"

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-recursive-next-hop-table" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_explicit_path_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name"):
                                                for c in self.vrf_next_hop_interface_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.vrf_name.is_set or
                                            (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vrf_name.yfilter != YFilter.not_set or
                                            (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-recursive-next-hop-table"):
                                            if (self.vrf_recursive_next_hop_table is None):
                                                self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            return self.vrf_recursive_next_hop_table

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-recursive-next-hop-table" or name == "vrf-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vrf-name"):
                                            self.vrf_name = value
                                            self.vrf_name.value_namespace = name_space
                                            self.vrf_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vrf_recurse_route:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.vrf_recurse_route:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-recurse-routes" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-recurse-route"):
                                        for c in self.vrf_recurse_route:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vrf_recurse_route.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-recurse-route"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class VrfSegRoute(Entity):
                                """
                                A static segment route
                                
                                .. attribute:: segment_route_next_hop_table
                                
                                	The set of nexthop information configured for this route
                                	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute, self).__init__()

                                    self.yang_name = "vrf-seg-route"
                                    self.yang_parent_name = "vrf-prefix"

                                    self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                    self.segment_route_next_hop_table.parent = self
                                    self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                    self._children_yang_names.add("segment-route-next-hop-table")


                                class SegmentRouteNextHopTable(Entity):
                                    """
                                    The set of nexthop information configured for
                                    this route
                                    
                                    .. attribute:: vrf_next_hop_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                        self.yang_name = "segment-route-next-hop-table"
                                        self.yang_parent_name = "vrf-seg-route"

                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                        self.vrf_next_hop_interface_name = YList(self)
                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)


                                    class VrfNextHopInterfaceName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                            self.yang_parent_name = "segment-route-next-hop-table"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "next_hop_address",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.next_hop_address.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-address"):
                                                self.next_hop_address = value
                                                self.next_hop_address.value_namespace = name_space
                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                            self.yang_parent_name = "segment-route-next-hop-table"

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("next_hop_address",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.next_hop_address.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "next-hop-address"):
                                                self.next_hop_address = value
                                                self.next_hop_address.value_namespace = name_space
                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("next_hop_address",
                                                            "explicit_path_name",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.next_hop_address.is_set or
                                                self.explicit_path_name.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                self.explicit_path_name.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                            if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "next-hop-address"):
                                                self.next_hop_address = value
                                                self.next_hop_address.value_namespace = name_space
                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "explicit-path-name"):
                                                self.explicit_path_name = value
                                                self.explicit_path_name.value_namespace = name_space
                                                self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("explicit_path_name",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.explicit_path_name.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.explicit_path_name.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "explicit-path-name"):
                                                self.explicit_path_name = value
                                                self.explicit_path_name.value_namespace = name_space
                                                self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vrf_next_hop_explicit_path_name:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.vrf_next_hop_explicit_path_name:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "segment-route-next-hop-table" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_explicit_path_name.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-interface-name"):
                                            for c in self.vrf_next_hop_interface_name:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_interface_name.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                            for c in self.vrf_next_hop_next_hop_address:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_next_hop_address.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_data())

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-seg-route" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "segment-route-next-hop-table"):
                                        if (self.segment_route_next_hop_table is None):
                                            self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        return self.segment_route_next_hop_table

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "segment-route-next-hop-table"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.prefix.is_set or
                                    self.prefix_length.is_set or
                                    (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_data()) or
                                    (self.vrf_route is not None and self.vrf_route.has_data()) or
                                    (self.vrf_seg_route is not None and self.vrf_seg_route.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.prefix.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_operation()) or
                                    (self.vrf_route is not None and self.vrf_route.has_operation()) or
                                    (self.vrf_seg_route is not None and self.vrf_seg_route.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vrf-prefix" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-multicast/vrf-prefixes/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "vrf-recurse-routes"):
                                    if (self.vrf_recurse_routes is None):
                                        self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                    return self.vrf_recurse_routes

                                if (child_yang_name == "vrf-route"):
                                    if (self.vrf_route is None):
                                        self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"
                                    return self.vrf_route

                                if (child_yang_name == "vrf-seg-route"):
                                    if (self.vrf_seg_route is None):
                                        self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    return self.vrf_seg_route

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "vrf-recurse-routes" or name == "vrf-route" or name == "vrf-seg-route" or name == "prefix" or name == "prefix-length"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "prefix"):
                                    self.prefix = value
                                    self.prefix.value_namespace = name_space
                                    self.prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.vrf_prefix:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.vrf_prefix:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "vrf-prefixes" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-multicast/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "vrf-prefix"):
                                for c in self.vrf_prefix:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.vrf_prefix.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "vrf-prefix"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class DefaultTopology(Entity):
                        """
                        Default topology configuration
                        
                        .. attribute:: vrf_prefix_topologies
                        
                        	The set of all Static Topologies for this AFI
                        	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2015-09-10'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology, self).__init__()

                            self.yang_name = "default-topology"
                            self.yang_parent_name = "vrf-multicast"

                            self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies()
                            self.vrf_prefix_topologies.parent = self
                            self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                            self._children_yang_names.add("vrf-prefix-topologies")


                        class VrfPrefixTopologies(Entity):
                            """
                            The set of all Static Topologies for this AFI.
                            
                            .. attribute:: vrf_prefix_topology
                            
                            	A static route
                            	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2015-09-10'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies, self).__init__()

                                self.yang_name = "vrf-prefix-topologies"
                                self.yang_parent_name = "default-topology"

                                self.vrf_prefix_topology = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies, self).__setattr__(name, value)


                            class VrfPrefixTopology(Entity):
                                """
                                A static route
                                
                                .. attribute:: prefix  <key>
                                
                                	Destination prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: prefix_length  <key>
                                
                                	Destination prefix length
                                	**type**\:  int
                                
                                	**range:** 0..128
                                
                                .. attribute:: vrf_recurse_routes
                                
                                	A recursive next VRF static route
                                	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                
                                .. attribute:: vrf_route
                                
                                	A connected or recursive  static route
                                	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                
                                .. attribute:: vrf_seg_route
                                
                                	A static segment route
                                	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                    self.yang_name = "vrf-prefix-topology"
                                    self.yang_parent_name = "vrf-prefix-topologies"

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                    self.vrf_recurse_routes.parent = self
                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                    self._children_yang_names.add("vrf-recurse-routes")

                                    self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                    self.vrf_route.parent = self
                                    self._children_name_map["vrf_route"] = "vrf-route"
                                    self._children_yang_names.add("vrf-route")

                                    self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                    self.vrf_seg_route.parent = self
                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    self._children_yang_names.add("vrf-seg-route")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("prefix",
                                                    "prefix_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)


                                class VrfRoute(Entity):
                                    """
                                    A connected or recursive  static route
                                    
                                    .. attribute:: vrf_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                        self.yang_name = "vrf-route"
                                        self.yang_parent_name = "vrf-prefix-topology"

                                        self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                        self.vrf_next_hop_table.parent = self
                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        self._children_yang_names.add("vrf-next-hop-table")


                                    class VrfNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                            self.yang_name = "vrf-next-hop-table"
                                            self.yang_parent_name = "vrf-route"

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-table" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_explicit_path_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name"):
                                                for c in self.vrf_next_hop_interface_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_data())

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-route" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-next-hop-table"):
                                            if (self.vrf_next_hop_table is None):
                                                self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                self.vrf_next_hop_table.parent = self
                                                self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            return self.vrf_next_hop_table

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-next-hop-table"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class VrfRecurseRoutes(Entity):
                                    """
                                    A recursive next VRF static route
                                    
                                    .. attribute:: vrf_recurse_route
                                    
                                    	A recursive next vrf static route
                                    	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                        self.yang_name = "vrf-recurse-routes"
                                        self.yang_parent_name = "vrf-prefix-topology"

                                        self.vrf_recurse_route = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)


                                    class VrfRecurseRoute(Entity):
                                        """
                                        A recursive next vrf static route
                                        
                                        .. attribute:: vrf_name  <key>
                                        
                                        	Fallback or recusive VRF name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: vrf_recursive_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                            self.yang_name = "vrf-recurse-route"
                                            self.yang_parent_name = "vrf-recurse-routes"

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                            self.vrf_recursive_next_hop_table.parent = self
                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            self._children_yang_names.add("vrf-recursive-next-hop-table")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vrf_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)


                                        class VrfRecursiveNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                self.yang_name = "vrf-recursive-next-hop-table"
                                                self.yang_parent_name = "vrf-recurse-route"

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-recursive-next-hop-table" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_explicit_path_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name"):
                                                    for c in self.vrf_next_hop_interface_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.vrf_name.is_set or
                                                (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vrf_name.yfilter != YFilter.not_set or
                                                (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-recursive-next-hop-table"):
                                                if (self.vrf_recursive_next_hop_table is None):
                                                    self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                    self.vrf_recursive_next_hop_table.parent = self
                                                    self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                return self.vrf_recursive_next_hop_table

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-recursive-next-hop-table" or name == "vrf-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vrf-name"):
                                                self.vrf_name = value
                                                self.vrf_name.value_namespace = name_space
                                                self.vrf_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vrf_recurse_route:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.vrf_recurse_route:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-recurse-routes" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-recurse-route"):
                                            for c in self.vrf_recurse_route:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_recurse_route.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-recurse-route"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class VrfSegRoute(Entity):
                                    """
                                    A static segment route
                                    
                                    .. attribute:: segment_route_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                        self.yang_name = "vrf-seg-route"
                                        self.yang_parent_name = "vrf-prefix-topology"

                                        self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                        self.segment_route_next_hop_table.parent = self
                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        self._children_yang_names.add("segment-route-next-hop-table")


                                    class SegmentRouteNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                            self.yang_name = "segment-route-next-hop-table"
                                            self.yang_parent_name = "vrf-seg-route"

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "segment-route-next-hop-table" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_explicit_path_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name"):
                                                for c in self.vrf_next_hop_interface_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_data())

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-seg-route" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "segment-route-next-hop-table"):
                                            if (self.segment_route_next_hop_table is None):
                                                self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                self.segment_route_next_hop_table.parent = self
                                                self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            return self.segment_route_next_hop_table

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "segment-route-next-hop-table"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.prefix.is_set or
                                        self.prefix_length.is_set or
                                        (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_data()) or
                                        (self.vrf_route is not None and self.vrf_route.has_data()) or
                                        (self.vrf_seg_route is not None and self.vrf_seg_route.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.prefix.yfilter != YFilter.not_set or
                                        self.prefix_length.yfilter != YFilter.not_set or
                                        (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_operation()) or
                                        (self.vrf_route is not None and self.vrf_route.has_operation()) or
                                        (self.vrf_seg_route is not None and self.vrf_seg_route.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-multicast/default-topology/vrf-prefix-topologies/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-recurse-routes"):
                                        if (self.vrf_recurse_routes is None):
                                            self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                            self.vrf_recurse_routes.parent = self
                                            self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                        return self.vrf_recurse_routes

                                    if (child_yang_name == "vrf-route"):
                                        if (self.vrf_route is None):
                                            self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                            self.vrf_route.parent = self
                                            self._children_name_map["vrf_route"] = "vrf-route"
                                        return self.vrf_route

                                    if (child_yang_name == "vrf-seg-route"):
                                        if (self.vrf_seg_route is None):
                                            self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                            self.vrf_seg_route.parent = self
                                            self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        return self.vrf_seg_route

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-recurse-routes" or name == "vrf-route" or name == "vrf-seg-route" or name == "prefix" or name == "prefix-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "prefix"):
                                        self.prefix = value
                                        self.prefix.value_namespace = name_space
                                        self.prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-length"):
                                        self.prefix_length = value
                                        self.prefix_length.value_namespace = name_space
                                        self.prefix_length.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.vrf_prefix_topology:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.vrf_prefix_topology:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vrf-prefix-topologies" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-multicast/default-topology/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "vrf-prefix-topology"):
                                    for c in self.vrf_prefix_topology:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.vrf_prefix_topology.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "vrf-prefix-topology"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "default-topology" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-multicast/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "vrf-prefix-topologies"):
                                if (self.vrf_prefix_topologies is None):
                                    self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies()
                                    self.vrf_prefix_topologies.parent = self
                                    self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                return self.vrf_prefix_topologies

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "vrf-prefix-topologies"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.default_topology is not None and self.default_topology.has_data()) or
                            (self.topologies is not None and self.topologies.has_data()) or
                            (self.vrf_prefixes is not None and self.vrf_prefixes.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.default_topology is not None and self.default_topology.has_operation()) or
                            (self.topologies is not None and self.topologies.has_operation()) or
                            (self.vrf_prefixes is not None and self.vrf_prefixes.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "vrf-multicast" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "default-topology"):
                            if (self.default_topology is None):
                                self.default_topology = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology()
                                self.default_topology.parent = self
                                self._children_name_map["default_topology"] = "default-topology"
                            return self.default_topology

                        if (child_yang_name == "topologies"):
                            if (self.topologies is None):
                                self.topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies()
                                self.topologies.parent = self
                                self._children_name_map["topologies"] = "topologies"
                            return self.topologies

                        if (child_yang_name == "vrf-prefixes"):
                            if (self.vrf_prefixes is None):
                                self.vrf_prefixes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes()
                                self.vrf_prefixes.parent = self
                                self._children_name_map["vrf_prefixes"] = "vrf-prefixes"
                            return self.vrf_prefixes

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "default-topology" or name == "topologies" or name == "vrf-prefixes"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.vrf_multicast is not None and self.vrf_multicast.has_data()) or
                        (self.vrf_unicast is not None and self.vrf_unicast.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.vrf_multicast is not None and self.vrf_multicast.has_operation()) or
                        (self.vrf_unicast is not None and self.vrf_unicast.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "vrfipv4" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "vrf-multicast"):
                        if (self.vrf_multicast is None):
                            self.vrf_multicast = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast()
                            self.vrf_multicast.parent = self
                            self._children_name_map["vrf_multicast"] = "vrf-multicast"
                        return self.vrf_multicast

                    if (child_yang_name == "vrf-unicast"):
                        if (self.vrf_unicast is None):
                            self.vrf_unicast = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast()
                            self.vrf_unicast.parent = self
                            self._children_name_map["vrf_unicast"] = "vrf-unicast"
                        return self.vrf_unicast

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "vrf-multicast" or name == "vrf-unicast"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Vrfipv6(Entity):
                """
                IPv6 static configuration
                
                .. attribute:: vrf_multicast
                
                	Multicast static configuration
                	**type**\:   :py:class:`VrfMulticast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast>`
                
                .. attribute:: vrf_unicast
                
                	Unicast static configuration
                	**type**\:   :py:class:`VrfUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast>`
                
                

                """

                _prefix = 'ip-static-cfg'
                _revision = '2015-09-10'

                def __init__(self):
                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6, self).__init__()

                    self.yang_name = "vrfipv6"
                    self.yang_parent_name = "address-family"

                    self.vrf_multicast = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast()
                    self.vrf_multicast.parent = self
                    self._children_name_map["vrf_multicast"] = "vrf-multicast"
                    self._children_yang_names.add("vrf-multicast")

                    self.vrf_unicast = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast()
                    self.vrf_unicast.parent = self
                    self._children_name_map["vrf_unicast"] = "vrf-unicast"
                    self._children_yang_names.add("vrf-unicast")


                class VrfUnicast(Entity):
                    """
                    Unicast static configuration
                    
                    .. attribute:: default_topology
                    
                    	Default topology configuration
                    	**type**\:   :py:class:`DefaultTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology>`
                    
                    .. attribute:: topologies
                    
                    	Topology static configuration container
                    	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies>`
                    
                    .. attribute:: vrf_prefixes
                    
                    	The set of all Static Topologies for this AFI
                    	**type**\:   :py:class:`VrfPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes>`
                    
                    

                    """

                    _prefix = 'ip-static-cfg'
                    _revision = '2015-09-10'

                    def __init__(self):
                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast, self).__init__()

                        self.yang_name = "vrf-unicast"
                        self.yang_parent_name = "vrfipv6"

                        self.default_topology = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology()
                        self.default_topology.parent = self
                        self._children_name_map["default_topology"] = "default-topology"
                        self._children_yang_names.add("default-topology")

                        self.topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies()
                        self.topologies.parent = self
                        self._children_name_map["topologies"] = "topologies"
                        self._children_yang_names.add("topologies")

                        self.vrf_prefixes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes()
                        self.vrf_prefixes.parent = self
                        self._children_name_map["vrf_prefixes"] = "vrf-prefixes"
                        self._children_yang_names.add("vrf-prefixes")


                    class Topologies(Entity):
                        """
                        Topology static configuration container
                        
                        .. attribute:: topology
                        
                        	Topology static configuration
                        	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2015-09-10'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies, self).__init__()

                            self.yang_name = "topologies"
                            self.yang_parent_name = "vrf-unicast"

                            self.topology = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies, self).__setattr__(name, value)


                        class Topology(Entity):
                            """
                            Topology static configuration
                            
                            .. attribute:: topology_name  <key>
                            
                            	Topology name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: vrf_prefix_topologies
                            
                            	The set of all Static Topologies for this AFI
                            	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2015-09-10'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology, self).__init__()

                                self.yang_name = "topology"
                                self.yang_parent_name = "topologies"

                                self.topology_name = YLeaf(YType.str, "topology-name")

                                self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies()
                                self.vrf_prefix_topologies.parent = self
                                self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                self._children_yang_names.add("vrf-prefix-topologies")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("topology_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology, self).__setattr__(name, value)


                            class VrfPrefixTopologies(Entity):
                                """
                                The set of all Static Topologies for this AFI.
                                
                                .. attribute:: vrf_prefix_topology
                                
                                	A static route
                                	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, self).__init__()

                                    self.yang_name = "vrf-prefix-topologies"
                                    self.yang_parent_name = "topology"

                                    self.vrf_prefix_topology = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, self).__setattr__(name, value)


                                class VrfPrefixTopology(Entity):
                                    """
                                    A static route
                                    
                                    .. attribute:: prefix  <key>
                                    
                                    	Destination prefix
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: prefix_length  <key>
                                    
                                    	Destination prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: vrf_recurse_routes
                                    
                                    	A recursive next VRF static route
                                    	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                    
                                    .. attribute:: vrf_route
                                    
                                    	A connected or recursive  static route
                                    	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                    
                                    .. attribute:: vrf_seg_route
                                    
                                    	A static segment route
                                    	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                        self.yang_name = "vrf-prefix-topology"
                                        self.yang_parent_name = "vrf-prefix-topologies"

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                        self._children_yang_names.add("vrf-recurse-routes")

                                        self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"
                                        self._children_yang_names.add("vrf-route")

                                        self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        self._children_yang_names.add("vrf-seg-route")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("prefix",
                                                        "prefix_length") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)


                                    class VrfRoute(Entity):
                                        """
                                        A connected or recursive  static route
                                        
                                        .. attribute:: vrf_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                            self.yang_name = "vrf-route"
                                            self.yang_parent_name = "vrf-prefix-topology"

                                            self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            self._children_yang_names.add("vrf-next-hop-table")


                                        class VrfNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                self.yang_name = "vrf-next-hop-table"
                                                self.yang_parent_name = "vrf-route"

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-table" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_explicit_path_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name"):
                                                    for c in self.vrf_next_hop_interface_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_data())

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-route" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-table"):
                                                if (self.vrf_next_hop_table is None):
                                                    self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                    self.vrf_next_hop_table.parent = self
                                                    self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                                return self.vrf_next_hop_table

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-table"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class VrfRecurseRoutes(Entity):
                                        """
                                        A recursive next VRF static route
                                        
                                        .. attribute:: vrf_recurse_route
                                        
                                        	A recursive next vrf static route
                                        	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                            self.yang_name = "vrf-recurse-routes"
                                            self.yang_parent_name = "vrf-prefix-topology"

                                            self.vrf_recurse_route = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)


                                        class VrfRecurseRoute(Entity):
                                            """
                                            A recursive next vrf static route
                                            
                                            .. attribute:: vrf_name  <key>
                                            
                                            	Fallback or recusive VRF name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: vrf_recursive_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                self.yang_name = "vrf-recurse-route"
                                                self.yang_parent_name = "vrf-recurse-routes"

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                self._children_yang_names.add("vrf-recursive-next-hop-table")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("vrf_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)


                                            class VrfRecursiveNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-recursive-next-hop-table"
                                                    self.yang_parent_name = "vrf-recurse-route"

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-recursive-next-hop-table" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                        for c in self.vrf_next_hop_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_explicit_path_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name"):
                                                        for c in self.vrf_next_hop_interface_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                        for c in self.vrf_next_hop_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.vrf_name.is_set or
                                                    (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.vrf_name.yfilter != YFilter.not_set or
                                                    (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-recursive-next-hop-table"):
                                                    if (self.vrf_recursive_next_hop_table is None):
                                                        self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                        self.vrf_recursive_next_hop_table.parent = self
                                                        self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                    return self.vrf_recursive_next_hop_table

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-recursive-next-hop-table" or name == "vrf-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "vrf-name"):
                                                    self.vrf_name = value
                                                    self.vrf_name.value_namespace = name_space
                                                    self.vrf_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_recurse_route:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_recurse_route:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-recurse-routes" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-recurse-route"):
                                                for c in self.vrf_recurse_route:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_recurse_route.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-recurse-route"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class VrfSegRoute(Entity):
                                        """
                                        A static segment route
                                        
                                        .. attribute:: segment_route_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                            self.yang_name = "vrf-seg-route"
                                            self.yang_parent_name = "vrf-prefix-topology"

                                            self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            self._children_yang_names.add("segment-route-next-hop-table")


                                        class SegmentRouteNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                self.yang_name = "segment-route-next-hop-table"
                                                self.yang_parent_name = "vrf-seg-route"

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "segment-route-next-hop-table" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_explicit_path_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name"):
                                                    for c in self.vrf_next_hop_interface_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_data())

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-seg-route" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "segment-route-next-hop-table"):
                                                if (self.segment_route_next_hop_table is None):
                                                    self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                    self.segment_route_next_hop_table.parent = self
                                                    self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                                return self.segment_route_next_hop_table

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "segment-route-next-hop-table"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.prefix.is_set or
                                            self.prefix_length.is_set or
                                            (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_data()) or
                                            (self.vrf_route is not None and self.vrf_route.has_data()) or
                                            (self.vrf_seg_route is not None and self.vrf_seg_route.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.prefix.yfilter != YFilter.not_set or
                                            self.prefix_length.yfilter != YFilter.not_set or
                                            (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_operation()) or
                                            (self.vrf_route is not None and self.vrf_route.has_operation()) or
                                            (self.vrf_seg_route is not None and self.vrf_seg_route.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix.get_name_leafdata())
                                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-recurse-routes"):
                                            if (self.vrf_recurse_routes is None):
                                                self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                                self.vrf_recurse_routes.parent = self
                                                self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                            return self.vrf_recurse_routes

                                        if (child_yang_name == "vrf-route"):
                                            if (self.vrf_route is None):
                                                self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                                self.vrf_route.parent = self
                                                self._children_name_map["vrf_route"] = "vrf-route"
                                            return self.vrf_route

                                        if (child_yang_name == "vrf-seg-route"):
                                            if (self.vrf_seg_route is None):
                                                self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                                self.vrf_seg_route.parent = self
                                                self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                            return self.vrf_seg_route

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-recurse-routes" or name == "vrf-route" or name == "vrf-seg-route" or name == "prefix" or name == "prefix-length"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "prefix"):
                                            self.prefix = value
                                            self.prefix.value_namespace = name_space
                                            self.prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "prefix-length"):
                                            self.prefix_length = value
                                            self.prefix_length.value_namespace = name_space
                                            self.prefix_length.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vrf_prefix_topology:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.vrf_prefix_topology:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-prefix-topologies" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-prefix-topology"):
                                        for c in self.vrf_prefix_topology:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vrf_prefix_topology.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-prefix-topology"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.topology_name.is_set or
                                    (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.topology_name.yfilter != YFilter.not_set or
                                    (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "topology" + "[topology-name='" + self.topology_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-unicast/topologies/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.topology_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "vrf-prefix-topologies"):
                                    if (self.vrf_prefix_topologies is None):
                                        self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies()
                                        self.vrf_prefix_topologies.parent = self
                                        self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                    return self.vrf_prefix_topologies

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "vrf-prefix-topologies" or name == "topology-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "topology-name"):
                                    self.topology_name = value
                                    self.topology_name.value_namespace = name_space
                                    self.topology_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.topology:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.topology:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "topologies" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-unicast/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "topology"):
                                for c in self.topology:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.topology.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "topology"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class VrfPrefixes(Entity):
                        """
                        The set of all Static Topologies for this AFI.
                        
                        .. attribute:: vrf_prefix
                        
                        	A static route
                        	**type**\: list of    :py:class:`VrfPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2015-09-10'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes, self).__init__()

                            self.yang_name = "vrf-prefixes"
                            self.yang_parent_name = "vrf-unicast"

                            self.vrf_prefix = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes, self).__setattr__(name, value)


                        class VrfPrefix(Entity):
                            """
                            A static route
                            
                            .. attribute:: prefix  <key>
                            
                            	Destination prefix
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: prefix_length  <key>
                            
                            	Destination prefix length
                            	**type**\:  int
                            
                            	**range:** 0..128
                            
                            .. attribute:: vrf_recurse_routes
                            
                            	A recursive next VRF static route
                            	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes>`
                            
                            .. attribute:: vrf_route
                            
                            	A connected or recursive  static route
                            	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute>`
                            
                            .. attribute:: vrf_seg_route
                            
                            	A static segment route
                            	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2015-09-10'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix, self).__init__()

                                self.yang_name = "vrf-prefix"
                                self.yang_parent_name = "vrf-prefixes"

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                self.vrf_recurse_routes.parent = self
                                self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                self._children_yang_names.add("vrf-recurse-routes")

                                self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute()
                                self.vrf_route.parent = self
                                self._children_name_map["vrf_route"] = "vrf-route"
                                self._children_yang_names.add("vrf-route")

                                self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                self.vrf_seg_route.parent = self
                                self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                self._children_yang_names.add("vrf-seg-route")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("prefix",
                                                "prefix_length") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix, self).__setattr__(name, value)


                            class VrfRoute(Entity):
                                """
                                A connected or recursive  static route
                                
                                .. attribute:: vrf_next_hop_table
                                
                                	The set of nexthop information configured for this route
                                	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute, self).__init__()

                                    self.yang_name = "vrf-route"
                                    self.yang_parent_name = "vrf-prefix"

                                    self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                    self.vrf_next_hop_table.parent = self
                                    self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                    self._children_yang_names.add("vrf-next-hop-table")


                                class VrfNextHopTable(Entity):
                                    """
                                    The set of nexthop information configured for
                                    this route
                                    
                                    .. attribute:: vrf_next_hop_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__init__()

                                        self.yang_name = "vrf-next-hop-table"
                                        self.yang_parent_name = "vrf-route"

                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                        self.vrf_next_hop_interface_name = YList(self)
                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)


                                    class VrfNextHopInterfaceName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name"
                                            self.yang_parent_name = "vrf-next-hop-table"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                            self.yang_parent_name = "vrf-next-hop-table"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "next_hop_address",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.next_hop_address.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-address"):
                                                self.next_hop_address = value
                                                self.next_hop_address.value_namespace = name_space
                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                            self.yang_parent_name = "vrf-next-hop-table"

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("next_hop_address",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.next_hop_address.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "next-hop-address"):
                                                self.next_hop_address = value
                                                self.next_hop_address.value_namespace = name_space
                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                            self.yang_parent_name = "vrf-next-hop-table"

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("next_hop_address",
                                                            "explicit_path_name",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.next_hop_address.is_set or
                                                self.explicit_path_name.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                self.explicit_path_name.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                            if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "next-hop-address"):
                                                self.next_hop_address = value
                                                self.next_hop_address.value_namespace = name_space
                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "explicit-path-name"):
                                                self.explicit_path_name = value
                                                self.explicit_path_name.value_namespace = name_space
                                                self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                            self.yang_parent_name = "vrf-next-hop-table"

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("explicit_path_name",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.explicit_path_name.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.explicit_path_name.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "explicit-path-name"):
                                                self.explicit_path_name = value
                                                self.explicit_path_name.value_namespace = name_space
                                                self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vrf_next_hop_explicit_path_name:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.vrf_next_hop_explicit_path_name:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-next-hop-table" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_explicit_path_name.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-interface-name"):
                                            for c in self.vrf_next_hop_interface_name:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_interface_name.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                            for c in self.vrf_next_hop_next_hop_address:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_next_hop_address.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_data())

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-route" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-next-hop-table"):
                                        if (self.vrf_next_hop_table is None):
                                            self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        return self.vrf_next_hop_table

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-next-hop-table"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class VrfRecurseRoutes(Entity):
                                """
                                A recursive next VRF static route
                                
                                .. attribute:: vrf_recurse_route
                                
                                	A recursive next vrf static route
                                	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__init__()

                                    self.yang_name = "vrf-recurse-routes"
                                    self.yang_parent_name = "vrf-prefix"

                                    self.vrf_recurse_route = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__setattr__(name, value)


                                class VrfRecurseRoute(Entity):
                                    """
                                    A recursive next vrf static route
                                    
                                    .. attribute:: vrf_name  <key>
                                    
                                    	Fallback or recusive VRF name
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: vrf_recursive_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                        self.yang_name = "vrf-recurse-route"
                                        self.yang_parent_name = "vrf-recurse-routes"

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                        self.vrf_recursive_next_hop_table.parent = self
                                        self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                        self._children_yang_names.add("vrf-recursive-next-hop-table")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vrf_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)


                                    class VrfRecursiveNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                            self.yang_name = "vrf-recursive-next-hop-table"
                                            self.yang_parent_name = "vrf-recurse-route"

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-recursive-next-hop-table" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_explicit_path_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name"):
                                                for c in self.vrf_next_hop_interface_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.vrf_name.is_set or
                                            (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vrf_name.yfilter != YFilter.not_set or
                                            (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-recursive-next-hop-table"):
                                            if (self.vrf_recursive_next_hop_table is None):
                                                self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            return self.vrf_recursive_next_hop_table

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-recursive-next-hop-table" or name == "vrf-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vrf-name"):
                                            self.vrf_name = value
                                            self.vrf_name.value_namespace = name_space
                                            self.vrf_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vrf_recurse_route:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.vrf_recurse_route:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-recurse-routes" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-recurse-route"):
                                        for c in self.vrf_recurse_route:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vrf_recurse_route.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-recurse-route"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class VrfSegRoute(Entity):
                                """
                                A static segment route
                                
                                .. attribute:: segment_route_next_hop_table
                                
                                	The set of nexthop information configured for this route
                                	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute, self).__init__()

                                    self.yang_name = "vrf-seg-route"
                                    self.yang_parent_name = "vrf-prefix"

                                    self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                    self.segment_route_next_hop_table.parent = self
                                    self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                    self._children_yang_names.add("segment-route-next-hop-table")


                                class SegmentRouteNextHopTable(Entity):
                                    """
                                    The set of nexthop information configured for
                                    this route
                                    
                                    .. attribute:: vrf_next_hop_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                        self.yang_name = "segment-route-next-hop-table"
                                        self.yang_parent_name = "vrf-seg-route"

                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                        self.vrf_next_hop_interface_name = YList(self)
                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)


                                    class VrfNextHopInterfaceName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                            self.yang_parent_name = "segment-route-next-hop-table"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "next_hop_address",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.next_hop_address.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-address"):
                                                self.next_hop_address = value
                                                self.next_hop_address.value_namespace = name_space
                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                            self.yang_parent_name = "segment-route-next-hop-table"

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("next_hop_address",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.next_hop_address.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "next-hop-address"):
                                                self.next_hop_address = value
                                                self.next_hop_address.value_namespace = name_space
                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("next_hop_address",
                                                            "explicit_path_name",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.next_hop_address.is_set or
                                                self.explicit_path_name.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                self.explicit_path_name.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                            if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "next-hop-address"):
                                                self.next_hop_address = value
                                                self.next_hop_address.value_namespace = name_space
                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "explicit-path-name"):
                                                self.explicit_path_name = value
                                                self.explicit_path_name.value_namespace = name_space
                                                self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("explicit_path_name",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.explicit_path_name.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.explicit_path_name.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "explicit-path-name"):
                                                self.explicit_path_name = value
                                                self.explicit_path_name.value_namespace = name_space
                                                self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vrf_next_hop_explicit_path_name:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.vrf_next_hop_explicit_path_name:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "segment-route-next-hop-table" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_explicit_path_name.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-interface-name"):
                                            for c in self.vrf_next_hop_interface_name:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_interface_name.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                            for c in self.vrf_next_hop_next_hop_address:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_next_hop_address.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_data())

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-seg-route" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "segment-route-next-hop-table"):
                                        if (self.segment_route_next_hop_table is None):
                                            self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        return self.segment_route_next_hop_table

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "segment-route-next-hop-table"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.prefix.is_set or
                                    self.prefix_length.is_set or
                                    (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_data()) or
                                    (self.vrf_route is not None and self.vrf_route.has_data()) or
                                    (self.vrf_seg_route is not None and self.vrf_seg_route.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.prefix.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_operation()) or
                                    (self.vrf_route is not None and self.vrf_route.has_operation()) or
                                    (self.vrf_seg_route is not None and self.vrf_seg_route.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vrf-prefix" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-unicast/vrf-prefixes/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "vrf-recurse-routes"):
                                    if (self.vrf_recurse_routes is None):
                                        self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                    return self.vrf_recurse_routes

                                if (child_yang_name == "vrf-route"):
                                    if (self.vrf_route is None):
                                        self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"
                                    return self.vrf_route

                                if (child_yang_name == "vrf-seg-route"):
                                    if (self.vrf_seg_route is None):
                                        self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    return self.vrf_seg_route

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "vrf-recurse-routes" or name == "vrf-route" or name == "vrf-seg-route" or name == "prefix" or name == "prefix-length"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "prefix"):
                                    self.prefix = value
                                    self.prefix.value_namespace = name_space
                                    self.prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.vrf_prefix:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.vrf_prefix:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "vrf-prefixes" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-unicast/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "vrf-prefix"):
                                for c in self.vrf_prefix:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.vrf_prefix.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "vrf-prefix"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class DefaultTopology(Entity):
                        """
                        Default topology configuration
                        
                        .. attribute:: vrf_prefix_topologies
                        
                        	The set of all Static Topologies for this AFI
                        	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2015-09-10'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology, self).__init__()

                            self.yang_name = "default-topology"
                            self.yang_parent_name = "vrf-unicast"

                            self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies()
                            self.vrf_prefix_topologies.parent = self
                            self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                            self._children_yang_names.add("vrf-prefix-topologies")


                        class VrfPrefixTopologies(Entity):
                            """
                            The set of all Static Topologies for this AFI.
                            
                            .. attribute:: vrf_prefix_topology
                            
                            	A static route
                            	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2015-09-10'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies, self).__init__()

                                self.yang_name = "vrf-prefix-topologies"
                                self.yang_parent_name = "default-topology"

                                self.vrf_prefix_topology = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies, self).__setattr__(name, value)


                            class VrfPrefixTopology(Entity):
                                """
                                A static route
                                
                                .. attribute:: prefix  <key>
                                
                                	Destination prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: prefix_length  <key>
                                
                                	Destination prefix length
                                	**type**\:  int
                                
                                	**range:** 0..128
                                
                                .. attribute:: vrf_recurse_routes
                                
                                	A recursive next VRF static route
                                	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                
                                .. attribute:: vrf_route
                                
                                	A connected or recursive  static route
                                	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                
                                .. attribute:: vrf_seg_route
                                
                                	A static segment route
                                	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                    self.yang_name = "vrf-prefix-topology"
                                    self.yang_parent_name = "vrf-prefix-topologies"

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                    self.vrf_recurse_routes.parent = self
                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                    self._children_yang_names.add("vrf-recurse-routes")

                                    self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                    self.vrf_route.parent = self
                                    self._children_name_map["vrf_route"] = "vrf-route"
                                    self._children_yang_names.add("vrf-route")

                                    self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                    self.vrf_seg_route.parent = self
                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    self._children_yang_names.add("vrf-seg-route")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("prefix",
                                                    "prefix_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)


                                class VrfRoute(Entity):
                                    """
                                    A connected or recursive  static route
                                    
                                    .. attribute:: vrf_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                        self.yang_name = "vrf-route"
                                        self.yang_parent_name = "vrf-prefix-topology"

                                        self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                        self.vrf_next_hop_table.parent = self
                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        self._children_yang_names.add("vrf-next-hop-table")


                                    class VrfNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                            self.yang_name = "vrf-next-hop-table"
                                            self.yang_parent_name = "vrf-route"

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-table" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_explicit_path_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name"):
                                                for c in self.vrf_next_hop_interface_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_data())

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-route" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-next-hop-table"):
                                            if (self.vrf_next_hop_table is None):
                                                self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                self.vrf_next_hop_table.parent = self
                                                self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            return self.vrf_next_hop_table

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-next-hop-table"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class VrfRecurseRoutes(Entity):
                                    """
                                    A recursive next VRF static route
                                    
                                    .. attribute:: vrf_recurse_route
                                    
                                    	A recursive next vrf static route
                                    	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                        self.yang_name = "vrf-recurse-routes"
                                        self.yang_parent_name = "vrf-prefix-topology"

                                        self.vrf_recurse_route = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)


                                    class VrfRecurseRoute(Entity):
                                        """
                                        A recursive next vrf static route
                                        
                                        .. attribute:: vrf_name  <key>
                                        
                                        	Fallback or recusive VRF name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: vrf_recursive_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                            self.yang_name = "vrf-recurse-route"
                                            self.yang_parent_name = "vrf-recurse-routes"

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                            self.vrf_recursive_next_hop_table.parent = self
                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            self._children_yang_names.add("vrf-recursive-next-hop-table")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vrf_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)


                                        class VrfRecursiveNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                self.yang_name = "vrf-recursive-next-hop-table"
                                                self.yang_parent_name = "vrf-recurse-route"

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-recursive-next-hop-table" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_explicit_path_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name"):
                                                    for c in self.vrf_next_hop_interface_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.vrf_name.is_set or
                                                (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vrf_name.yfilter != YFilter.not_set or
                                                (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-recursive-next-hop-table"):
                                                if (self.vrf_recursive_next_hop_table is None):
                                                    self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                    self.vrf_recursive_next_hop_table.parent = self
                                                    self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                return self.vrf_recursive_next_hop_table

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-recursive-next-hop-table" or name == "vrf-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vrf-name"):
                                                self.vrf_name = value
                                                self.vrf_name.value_namespace = name_space
                                                self.vrf_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vrf_recurse_route:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.vrf_recurse_route:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-recurse-routes" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-recurse-route"):
                                            for c in self.vrf_recurse_route:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_recurse_route.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-recurse-route"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class VrfSegRoute(Entity):
                                    """
                                    A static segment route
                                    
                                    .. attribute:: segment_route_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                        self.yang_name = "vrf-seg-route"
                                        self.yang_parent_name = "vrf-prefix-topology"

                                        self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                        self.segment_route_next_hop_table.parent = self
                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        self._children_yang_names.add("segment-route-next-hop-table")


                                    class SegmentRouteNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                            self.yang_name = "segment-route-next-hop-table"
                                            self.yang_parent_name = "vrf-seg-route"

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "segment-route-next-hop-table" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_explicit_path_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name"):
                                                for c in self.vrf_next_hop_interface_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_data())

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-seg-route" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "segment-route-next-hop-table"):
                                            if (self.segment_route_next_hop_table is None):
                                                self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                self.segment_route_next_hop_table.parent = self
                                                self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            return self.segment_route_next_hop_table

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "segment-route-next-hop-table"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.prefix.is_set or
                                        self.prefix_length.is_set or
                                        (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_data()) or
                                        (self.vrf_route is not None and self.vrf_route.has_data()) or
                                        (self.vrf_seg_route is not None and self.vrf_seg_route.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.prefix.yfilter != YFilter.not_set or
                                        self.prefix_length.yfilter != YFilter.not_set or
                                        (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_operation()) or
                                        (self.vrf_route is not None and self.vrf_route.has_operation()) or
                                        (self.vrf_seg_route is not None and self.vrf_seg_route.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-unicast/default-topology/vrf-prefix-topologies/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-recurse-routes"):
                                        if (self.vrf_recurse_routes is None):
                                            self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                            self.vrf_recurse_routes.parent = self
                                            self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                        return self.vrf_recurse_routes

                                    if (child_yang_name == "vrf-route"):
                                        if (self.vrf_route is None):
                                            self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                            self.vrf_route.parent = self
                                            self._children_name_map["vrf_route"] = "vrf-route"
                                        return self.vrf_route

                                    if (child_yang_name == "vrf-seg-route"):
                                        if (self.vrf_seg_route is None):
                                            self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                            self.vrf_seg_route.parent = self
                                            self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        return self.vrf_seg_route

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-recurse-routes" or name == "vrf-route" or name == "vrf-seg-route" or name == "prefix" or name == "prefix-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "prefix"):
                                        self.prefix = value
                                        self.prefix.value_namespace = name_space
                                        self.prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-length"):
                                        self.prefix_length = value
                                        self.prefix_length.value_namespace = name_space
                                        self.prefix_length.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.vrf_prefix_topology:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.vrf_prefix_topology:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vrf-prefix-topologies" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-unicast/default-topology/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "vrf-prefix-topology"):
                                    for c in self.vrf_prefix_topology:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.vrf_prefix_topology.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "vrf-prefix-topology"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "default-topology" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-unicast/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "vrf-prefix-topologies"):
                                if (self.vrf_prefix_topologies is None):
                                    self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies()
                                    self.vrf_prefix_topologies.parent = self
                                    self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                return self.vrf_prefix_topologies

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "vrf-prefix-topologies"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.default_topology is not None and self.default_topology.has_data()) or
                            (self.topologies is not None and self.topologies.has_data()) or
                            (self.vrf_prefixes is not None and self.vrf_prefixes.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.default_topology is not None and self.default_topology.has_operation()) or
                            (self.topologies is not None and self.topologies.has_operation()) or
                            (self.vrf_prefixes is not None and self.vrf_prefixes.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "vrf-unicast" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "default-topology"):
                            if (self.default_topology is None):
                                self.default_topology = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology()
                                self.default_topology.parent = self
                                self._children_name_map["default_topology"] = "default-topology"
                            return self.default_topology

                        if (child_yang_name == "topologies"):
                            if (self.topologies is None):
                                self.topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies()
                                self.topologies.parent = self
                                self._children_name_map["topologies"] = "topologies"
                            return self.topologies

                        if (child_yang_name == "vrf-prefixes"):
                            if (self.vrf_prefixes is None):
                                self.vrf_prefixes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes()
                                self.vrf_prefixes.parent = self
                                self._children_name_map["vrf_prefixes"] = "vrf-prefixes"
                            return self.vrf_prefixes

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "default-topology" or name == "topologies" or name == "vrf-prefixes"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class VrfMulticast(Entity):
                    """
                    Multicast static configuration
                    
                    .. attribute:: default_topology
                    
                    	Default topology configuration
                    	**type**\:   :py:class:`DefaultTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology>`
                    
                    .. attribute:: topologies
                    
                    	Topology static configuration container
                    	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies>`
                    
                    .. attribute:: vrf_prefixes
                    
                    	The set of all Static Topologies for this AFI
                    	**type**\:   :py:class:`VrfPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes>`
                    
                    

                    """

                    _prefix = 'ip-static-cfg'
                    _revision = '2015-09-10'

                    def __init__(self):
                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast, self).__init__()

                        self.yang_name = "vrf-multicast"
                        self.yang_parent_name = "vrfipv6"

                        self.default_topology = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology()
                        self.default_topology.parent = self
                        self._children_name_map["default_topology"] = "default-topology"
                        self._children_yang_names.add("default-topology")

                        self.topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies()
                        self.topologies.parent = self
                        self._children_name_map["topologies"] = "topologies"
                        self._children_yang_names.add("topologies")

                        self.vrf_prefixes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes()
                        self.vrf_prefixes.parent = self
                        self._children_name_map["vrf_prefixes"] = "vrf-prefixes"
                        self._children_yang_names.add("vrf-prefixes")


                    class Topologies(Entity):
                        """
                        Topology static configuration container
                        
                        .. attribute:: topology
                        
                        	Topology static configuration
                        	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2015-09-10'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies, self).__init__()

                            self.yang_name = "topologies"
                            self.yang_parent_name = "vrf-multicast"

                            self.topology = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies, self).__setattr__(name, value)


                        class Topology(Entity):
                            """
                            Topology static configuration
                            
                            .. attribute:: topology_name  <key>
                            
                            	Topology name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: vrf_prefix_topologies
                            
                            	The set of all Static Topologies for this AFI
                            	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2015-09-10'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology, self).__init__()

                                self.yang_name = "topology"
                                self.yang_parent_name = "topologies"

                                self.topology_name = YLeaf(YType.str, "topology-name")

                                self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies()
                                self.vrf_prefix_topologies.parent = self
                                self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                self._children_yang_names.add("vrf-prefix-topologies")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("topology_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology, self).__setattr__(name, value)


                            class VrfPrefixTopologies(Entity):
                                """
                                The set of all Static Topologies for this AFI.
                                
                                .. attribute:: vrf_prefix_topology
                                
                                	A static route
                                	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, self).__init__()

                                    self.yang_name = "vrf-prefix-topologies"
                                    self.yang_parent_name = "topology"

                                    self.vrf_prefix_topology = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, self).__setattr__(name, value)


                                class VrfPrefixTopology(Entity):
                                    """
                                    A static route
                                    
                                    .. attribute:: prefix  <key>
                                    
                                    	Destination prefix
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: prefix_length  <key>
                                    
                                    	Destination prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: vrf_recurse_routes
                                    
                                    	A recursive next VRF static route
                                    	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                    
                                    .. attribute:: vrf_route
                                    
                                    	A connected or recursive  static route
                                    	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                    
                                    .. attribute:: vrf_seg_route
                                    
                                    	A static segment route
                                    	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                        self.yang_name = "vrf-prefix-topology"
                                        self.yang_parent_name = "vrf-prefix-topologies"

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                        self._children_yang_names.add("vrf-recurse-routes")

                                        self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"
                                        self._children_yang_names.add("vrf-route")

                                        self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        self._children_yang_names.add("vrf-seg-route")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("prefix",
                                                        "prefix_length") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)


                                    class VrfRoute(Entity):
                                        """
                                        A connected or recursive  static route
                                        
                                        .. attribute:: vrf_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                            self.yang_name = "vrf-route"
                                            self.yang_parent_name = "vrf-prefix-topology"

                                            self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            self._children_yang_names.add("vrf-next-hop-table")


                                        class VrfNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                self.yang_name = "vrf-next-hop-table"
                                                self.yang_parent_name = "vrf-route"

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-table" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_explicit_path_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name"):
                                                    for c in self.vrf_next_hop_interface_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_data())

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-route" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-table"):
                                                if (self.vrf_next_hop_table is None):
                                                    self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                    self.vrf_next_hop_table.parent = self
                                                    self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                                return self.vrf_next_hop_table

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-table"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class VrfRecurseRoutes(Entity):
                                        """
                                        A recursive next VRF static route
                                        
                                        .. attribute:: vrf_recurse_route
                                        
                                        	A recursive next vrf static route
                                        	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                            self.yang_name = "vrf-recurse-routes"
                                            self.yang_parent_name = "vrf-prefix-topology"

                                            self.vrf_recurse_route = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)


                                        class VrfRecurseRoute(Entity):
                                            """
                                            A recursive next vrf static route
                                            
                                            .. attribute:: vrf_name  <key>
                                            
                                            	Fallback or recusive VRF name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: vrf_recursive_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                self.yang_name = "vrf-recurse-route"
                                                self.yang_parent_name = "vrf-recurse-routes"

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                self._children_yang_names.add("vrf-recursive-next-hop-table")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("vrf_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)


                                            class VrfRecursiveNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-recursive-next-hop-table"
                                                    self.yang_parent_name = "vrf-recurse-route"

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("next_hop_address",
                                                                        "explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.next_hop_address.is_set or
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.next_hop_address.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "next-hop-address"):
                                                            self.next_hop_address = value
                                                            self.next_hop_address.value_namespace = name_space
                                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2015-09-10'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("explicit_path_name",
                                                                        "bfd_fast_detect",
                                                                        "description",
                                                                        "detect_multiplier",
                                                                        "index",
                                                                        "load_metric",
                                                                        "metric",
                                                                        "minimum_interval",
                                                                        "object_name",
                                                                        "permanent",
                                                                        "tag",
                                                                        "tunnel_id",
                                                                        "vrf_lable") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.explicit_path_name.is_set or
                                                            self.bfd_fast_detect.is_set or
                                                            self.description.is_set or
                                                            self.detect_multiplier.is_set or
                                                            self.index.is_set or
                                                            self.load_metric.is_set or
                                                            self.metric.is_set or
                                                            self.minimum_interval.is_set or
                                                            self.object_name.is_set or
                                                            self.permanent.is_set or
                                                            self.tag.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.vrf_lable.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.explicit_path_name.yfilter != YFilter.not_set or
                                                            self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                            self.description.yfilter != YFilter.not_set or
                                                            self.detect_multiplier.yfilter != YFilter.not_set or
                                                            self.index.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.minimum_interval.yfilter != YFilter.not_set or
                                                            self.object_name.yfilter != YFilter.not_set or
                                                            self.permanent.yfilter != YFilter.not_set or
                                                            self.tag.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.vrf_lable.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                        if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.description.get_name_leafdata())
                                                        if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.index.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                        if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.object_name.get_name_leafdata())
                                                        if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.permanent.get_name_leafdata())
                                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tag.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "explicit-path-name"):
                                                            self.explicit_path_name = value
                                                            self.explicit_path_name.value_namespace = name_space
                                                            self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "bfd-fast-detect"):
                                                            self.bfd_fast_detect = value
                                                            self.bfd_fast_detect.value_namespace = name_space
                                                            self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "description"):
                                                            self.description = value
                                                            self.description.value_namespace = name_space
                                                            self.description.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "detect-multiplier"):
                                                            self.detect_multiplier = value
                                                            self.detect_multiplier.value_namespace = name_space
                                                            self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "index"):
                                                            self.index = value
                                                            self.index.value_namespace = name_space
                                                            self.index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "minimum-interval"):
                                                            self.minimum_interval = value
                                                            self.minimum_interval.value_namespace = name_space
                                                            self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "object-name"):
                                                            self.object_name = value
                                                            self.object_name.value_namespace = name_space
                                                            self.object_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "permanent"):
                                                            self.permanent = value
                                                            self.permanent.value_namespace = name_space
                                                            self.permanent.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tag"):
                                                            self.tag = value
                                                            self.tag.value_namespace = name_space
                                                            self.tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-lable"):
                                                            self.vrf_lable = value
                                                            self.vrf_lable.value_namespace = name_space
                                                            self.vrf_lable.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-recursive-next-hop-table" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                        for c in self.vrf_next_hop_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_explicit_path_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name"):
                                                        for c in self.vrf_next_hop_interface_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                        for c in self.vrf_next_hop_next_hop_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address.append(c)
                                                        return c

                                                    if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.vrf_name.is_set or
                                                    (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.vrf_name.yfilter != YFilter.not_set or
                                                    (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-recursive-next-hop-table"):
                                                    if (self.vrf_recursive_next_hop_table is None):
                                                        self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                        self.vrf_recursive_next_hop_table.parent = self
                                                        self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                    return self.vrf_recursive_next_hop_table

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-recursive-next-hop-table" or name == "vrf-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "vrf-name"):
                                                    self.vrf_name = value
                                                    self.vrf_name.value_namespace = name_space
                                                    self.vrf_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_recurse_route:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_recurse_route:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-recurse-routes" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-recurse-route"):
                                                for c in self.vrf_recurse_route:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_recurse_route.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-recurse-route"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class VrfSegRoute(Entity):
                                        """
                                        A static segment route
                                        
                                        .. attribute:: segment_route_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                            self.yang_name = "vrf-seg-route"
                                            self.yang_parent_name = "vrf-prefix-topology"

                                            self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            self._children_yang_names.add("segment-route-next-hop-table")


                                        class SegmentRouteNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                self.yang_name = "segment-route-next-hop-table"
                                                self.yang_parent_name = "vrf-seg-route"

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "segment-route-next-hop-table" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_explicit_path_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name"):
                                                    for c in self.vrf_next_hop_interface_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_data())

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-seg-route" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "segment-route-next-hop-table"):
                                                if (self.segment_route_next_hop_table is None):
                                                    self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                    self.segment_route_next_hop_table.parent = self
                                                    self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                                return self.segment_route_next_hop_table

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "segment-route-next-hop-table"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.prefix.is_set or
                                            self.prefix_length.is_set or
                                            (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_data()) or
                                            (self.vrf_route is not None and self.vrf_route.has_data()) or
                                            (self.vrf_seg_route is not None and self.vrf_seg_route.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.prefix.yfilter != YFilter.not_set or
                                            self.prefix_length.yfilter != YFilter.not_set or
                                            (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_operation()) or
                                            (self.vrf_route is not None and self.vrf_route.has_operation()) or
                                            (self.vrf_seg_route is not None and self.vrf_seg_route.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix.get_name_leafdata())
                                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-recurse-routes"):
                                            if (self.vrf_recurse_routes is None):
                                                self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                                self.vrf_recurse_routes.parent = self
                                                self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                            return self.vrf_recurse_routes

                                        if (child_yang_name == "vrf-route"):
                                            if (self.vrf_route is None):
                                                self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                                self.vrf_route.parent = self
                                                self._children_name_map["vrf_route"] = "vrf-route"
                                            return self.vrf_route

                                        if (child_yang_name == "vrf-seg-route"):
                                            if (self.vrf_seg_route is None):
                                                self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                                self.vrf_seg_route.parent = self
                                                self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                            return self.vrf_seg_route

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-recurse-routes" or name == "vrf-route" or name == "vrf-seg-route" or name == "prefix" or name == "prefix-length"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "prefix"):
                                            self.prefix = value
                                            self.prefix.value_namespace = name_space
                                            self.prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "prefix-length"):
                                            self.prefix_length = value
                                            self.prefix_length.value_namespace = name_space
                                            self.prefix_length.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vrf_prefix_topology:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.vrf_prefix_topology:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-prefix-topologies" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-prefix-topology"):
                                        for c in self.vrf_prefix_topology:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vrf_prefix_topology.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-prefix-topology"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.topology_name.is_set or
                                    (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.topology_name.yfilter != YFilter.not_set or
                                    (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "topology" + "[topology-name='" + self.topology_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-multicast/topologies/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.topology_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "vrf-prefix-topologies"):
                                    if (self.vrf_prefix_topologies is None):
                                        self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies()
                                        self.vrf_prefix_topologies.parent = self
                                        self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                    return self.vrf_prefix_topologies

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "vrf-prefix-topologies" or name == "topology-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "topology-name"):
                                    self.topology_name = value
                                    self.topology_name.value_namespace = name_space
                                    self.topology_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.topology:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.topology:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "topologies" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-multicast/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "topology"):
                                for c in self.topology:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.topology.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "topology"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class VrfPrefixes(Entity):
                        """
                        The set of all Static Topologies for this AFI.
                        
                        .. attribute:: vrf_prefix
                        
                        	A static route
                        	**type**\: list of    :py:class:`VrfPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2015-09-10'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes, self).__init__()

                            self.yang_name = "vrf-prefixes"
                            self.yang_parent_name = "vrf-multicast"

                            self.vrf_prefix = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes, self).__setattr__(name, value)


                        class VrfPrefix(Entity):
                            """
                            A static route
                            
                            .. attribute:: prefix  <key>
                            
                            	Destination prefix
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: prefix_length  <key>
                            
                            	Destination prefix length
                            	**type**\:  int
                            
                            	**range:** 0..128
                            
                            .. attribute:: vrf_recurse_routes
                            
                            	A recursive next VRF static route
                            	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes>`
                            
                            .. attribute:: vrf_route
                            
                            	A connected or recursive  static route
                            	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute>`
                            
                            .. attribute:: vrf_seg_route
                            
                            	A static segment route
                            	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2015-09-10'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix, self).__init__()

                                self.yang_name = "vrf-prefix"
                                self.yang_parent_name = "vrf-prefixes"

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                self.vrf_recurse_routes.parent = self
                                self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                self._children_yang_names.add("vrf-recurse-routes")

                                self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute()
                                self.vrf_route.parent = self
                                self._children_name_map["vrf_route"] = "vrf-route"
                                self._children_yang_names.add("vrf-route")

                                self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                self.vrf_seg_route.parent = self
                                self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                self._children_yang_names.add("vrf-seg-route")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("prefix",
                                                "prefix_length") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix, self).__setattr__(name, value)


                            class VrfRoute(Entity):
                                """
                                A connected or recursive  static route
                                
                                .. attribute:: vrf_next_hop_table
                                
                                	The set of nexthop information configured for this route
                                	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute, self).__init__()

                                    self.yang_name = "vrf-route"
                                    self.yang_parent_name = "vrf-prefix"

                                    self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                    self.vrf_next_hop_table.parent = self
                                    self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                    self._children_yang_names.add("vrf-next-hop-table")


                                class VrfNextHopTable(Entity):
                                    """
                                    The set of nexthop information configured for
                                    this route
                                    
                                    .. attribute:: vrf_next_hop_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__init__()

                                        self.yang_name = "vrf-next-hop-table"
                                        self.yang_parent_name = "vrf-route"

                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                        self.vrf_next_hop_interface_name = YList(self)
                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)


                                    class VrfNextHopInterfaceName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name"
                                            self.yang_parent_name = "vrf-next-hop-table"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                            self.yang_parent_name = "vrf-next-hop-table"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "next_hop_address",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.next_hop_address.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-address"):
                                                self.next_hop_address = value
                                                self.next_hop_address.value_namespace = name_space
                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                            self.yang_parent_name = "vrf-next-hop-table"

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("next_hop_address",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.next_hop_address.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "next-hop-address"):
                                                self.next_hop_address = value
                                                self.next_hop_address.value_namespace = name_space
                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                            self.yang_parent_name = "vrf-next-hop-table"

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("next_hop_address",
                                                            "explicit_path_name",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.next_hop_address.is_set or
                                                self.explicit_path_name.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                self.explicit_path_name.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                            if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "next-hop-address"):
                                                self.next_hop_address = value
                                                self.next_hop_address.value_namespace = name_space
                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "explicit-path-name"):
                                                self.explicit_path_name = value
                                                self.explicit_path_name.value_namespace = name_space
                                                self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                            self.yang_parent_name = "vrf-next-hop-table"

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("explicit_path_name",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.explicit_path_name.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.explicit_path_name.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "explicit-path-name"):
                                                self.explicit_path_name = value
                                                self.explicit_path_name.value_namespace = name_space
                                                self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vrf_next_hop_explicit_path_name:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.vrf_next_hop_explicit_path_name:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-next-hop-table" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_explicit_path_name.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-interface-name"):
                                            for c in self.vrf_next_hop_interface_name:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_interface_name.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                            for c in self.vrf_next_hop_next_hop_address:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_next_hop_address.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_data())

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-route" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-next-hop-table"):
                                        if (self.vrf_next_hop_table is None):
                                            self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        return self.vrf_next_hop_table

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-next-hop-table"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class VrfRecurseRoutes(Entity):
                                """
                                A recursive next VRF static route
                                
                                .. attribute:: vrf_recurse_route
                                
                                	A recursive next vrf static route
                                	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__init__()

                                    self.yang_name = "vrf-recurse-routes"
                                    self.yang_parent_name = "vrf-prefix"

                                    self.vrf_recurse_route = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__setattr__(name, value)


                                class VrfRecurseRoute(Entity):
                                    """
                                    A recursive next vrf static route
                                    
                                    .. attribute:: vrf_name  <key>
                                    
                                    	Fallback or recusive VRF name
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: vrf_recursive_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                        self.yang_name = "vrf-recurse-route"
                                        self.yang_parent_name = "vrf-recurse-routes"

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                        self.vrf_recursive_next_hop_table.parent = self
                                        self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                        self._children_yang_names.add("vrf-recursive-next-hop-table")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vrf_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)


                                    class VrfRecursiveNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                            self.yang_name = "vrf-recursive-next-hop-table"
                                            self.yang_parent_name = "vrf-recurse-route"

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-recursive-next-hop-table" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_explicit_path_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name"):
                                                for c in self.vrf_next_hop_interface_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.vrf_name.is_set or
                                            (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vrf_name.yfilter != YFilter.not_set or
                                            (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-recursive-next-hop-table"):
                                            if (self.vrf_recursive_next_hop_table is None):
                                                self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            return self.vrf_recursive_next_hop_table

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-recursive-next-hop-table" or name == "vrf-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vrf-name"):
                                            self.vrf_name = value
                                            self.vrf_name.value_namespace = name_space
                                            self.vrf_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vrf_recurse_route:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.vrf_recurse_route:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-recurse-routes" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-recurse-route"):
                                        for c in self.vrf_recurse_route:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vrf_recurse_route.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-recurse-route"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class VrfSegRoute(Entity):
                                """
                                A static segment route
                                
                                .. attribute:: segment_route_next_hop_table
                                
                                	The set of nexthop information configured for this route
                                	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute, self).__init__()

                                    self.yang_name = "vrf-seg-route"
                                    self.yang_parent_name = "vrf-prefix"

                                    self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                    self.segment_route_next_hop_table.parent = self
                                    self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                    self._children_yang_names.add("segment-route-next-hop-table")


                                class SegmentRouteNextHopTable(Entity):
                                    """
                                    The set of nexthop information configured for
                                    this route
                                    
                                    .. attribute:: vrf_next_hop_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                        self.yang_name = "segment-route-next-hop-table"
                                        self.yang_parent_name = "vrf-seg-route"

                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                        self.vrf_next_hop_interface_name = YList(self)
                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)


                                    class VrfNextHopInterfaceName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                            self.yang_parent_name = "segment-route-next-hop-table"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "next_hop_address",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.next_hop_address.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-address"):
                                                self.next_hop_address = value
                                                self.next_hop_address.value_namespace = name_space
                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                            self.yang_parent_name = "segment-route-next-hop-table"

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("next_hop_address",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.next_hop_address.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "next-hop-address"):
                                                self.next_hop_address = value
                                                self.next_hop_address.value_namespace = name_space
                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("next_hop_address",
                                                            "explicit_path_name",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.next_hop_address.is_set or
                                                self.explicit_path_name.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.next_hop_address.yfilter != YFilter.not_set or
                                                self.explicit_path_name.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                            if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "next-hop-address"):
                                                self.next_hop_address = value
                                                self.next_hop_address.value_namespace = name_space
                                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "explicit-path-name"):
                                                self.explicit_path_name = value
                                                self.explicit_path_name.value_namespace = name_space
                                                self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix


                                    class VrfNextHopExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("explicit_path_name",
                                                            "bfd_fast_detect",
                                                            "description",
                                                            "detect_multiplier",
                                                            "index",
                                                            "load_metric",
                                                            "metric",
                                                            "minimum_interval",
                                                            "object_name",
                                                            "permanent",
                                                            "tag",
                                                            "tunnel_id",
                                                            "vrf_lable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.explicit_path_name.is_set or
                                                self.bfd_fast_detect.is_set or
                                                self.description.is_set or
                                                self.detect_multiplier.is_set or
                                                self.index.is_set or
                                                self.load_metric.is_set or
                                                self.metric.is_set or
                                                self.minimum_interval.is_set or
                                                self.object_name.is_set or
                                                self.permanent.is_set or
                                                self.tag.is_set or
                                                self.tunnel_id.is_set or
                                                self.vrf_lable.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.explicit_path_name.yfilter != YFilter.not_set or
                                                self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.detect_multiplier.yfilter != YFilter.not_set or
                                                self.index.yfilter != YFilter.not_set or
                                                self.load_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.minimum_interval.yfilter != YFilter.not_set or
                                                self.object_name.yfilter != YFilter.not_set or
                                                self.permanent.yfilter != YFilter.not_set or
                                                self.tag.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                self.vrf_lable.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                            if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                            if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.index.get_name_leafdata())
                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                            if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.object_name.get_name_leafdata())
                                            if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.permanent.get_name_leafdata())
                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                            if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "explicit-path-name"):
                                                self.explicit_path_name = value
                                                self.explicit_path_name.value_namespace = name_space
                                                self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-fast-detect"):
                                                self.bfd_fast_detect = value
                                                self.bfd_fast_detect.value_namespace = name_space
                                                self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detect-multiplier"):
                                                self.detect_multiplier = value
                                                self.detect_multiplier.value_namespace = name_space
                                                self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "index"):
                                                self.index = value
                                                self.index.value_namespace = name_space
                                                self.index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "load-metric"):
                                                self.load_metric = value
                                                self.load_metric.value_namespace = name_space
                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-interval"):
                                                self.minimum_interval = value
                                                self.minimum_interval.value_namespace = name_space
                                                self.minimum_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "object-name"):
                                                self.object_name = value
                                                self.object_name.value_namespace = name_space
                                                self.object_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "permanent"):
                                                self.permanent = value
                                                self.permanent.value_namespace = name_space
                                                self.permanent.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tag"):
                                                self.tag = value
                                                self.tag.value_namespace = name_space
                                                self.tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vrf-lable"):
                                                self.vrf_lable = value
                                                self.vrf_lable.value_namespace = name_space
                                                self.vrf_lable.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vrf_next_hop_explicit_path_name:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address:
                                            if (c.has_data()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.vrf_next_hop_explicit_path_name:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_interface_name_next_hop_address:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "segment-route-next-hop-table" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_explicit_path_name.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-interface-name"):
                                            for c in self.vrf_next_hop_interface_name:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_interface_name.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                            for c in self.vrf_next_hop_next_hop_address:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_next_hop_address.append(c)
                                            return c

                                        if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_data())

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-seg-route" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "segment-route-next-hop-table"):
                                        if (self.segment_route_next_hop_table is None):
                                            self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        return self.segment_route_next_hop_table

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "segment-route-next-hop-table"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.prefix.is_set or
                                    self.prefix_length.is_set or
                                    (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_data()) or
                                    (self.vrf_route is not None and self.vrf_route.has_data()) or
                                    (self.vrf_seg_route is not None and self.vrf_seg_route.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.prefix.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_operation()) or
                                    (self.vrf_route is not None and self.vrf_route.has_operation()) or
                                    (self.vrf_seg_route is not None and self.vrf_seg_route.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vrf-prefix" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-multicast/vrf-prefixes/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "vrf-recurse-routes"):
                                    if (self.vrf_recurse_routes is None):
                                        self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                    return self.vrf_recurse_routes

                                if (child_yang_name == "vrf-route"):
                                    if (self.vrf_route is None):
                                        self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"
                                    return self.vrf_route

                                if (child_yang_name == "vrf-seg-route"):
                                    if (self.vrf_seg_route is None):
                                        self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    return self.vrf_seg_route

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "vrf-recurse-routes" or name == "vrf-route" or name == "vrf-seg-route" or name == "prefix" or name == "prefix-length"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "prefix"):
                                    self.prefix = value
                                    self.prefix.value_namespace = name_space
                                    self.prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.vrf_prefix:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.vrf_prefix:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "vrf-prefixes" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-multicast/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "vrf-prefix"):
                                for c in self.vrf_prefix:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.vrf_prefix.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "vrf-prefix"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class DefaultTopology(Entity):
                        """
                        Default topology configuration
                        
                        .. attribute:: vrf_prefix_topologies
                        
                        	The set of all Static Topologies for this AFI
                        	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2015-09-10'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology, self).__init__()

                            self.yang_name = "default-topology"
                            self.yang_parent_name = "vrf-multicast"

                            self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies()
                            self.vrf_prefix_topologies.parent = self
                            self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                            self._children_yang_names.add("vrf-prefix-topologies")


                        class VrfPrefixTopologies(Entity):
                            """
                            The set of all Static Topologies for this AFI.
                            
                            .. attribute:: vrf_prefix_topology
                            
                            	A static route
                            	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2015-09-10'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies, self).__init__()

                                self.yang_name = "vrf-prefix-topologies"
                                self.yang_parent_name = "default-topology"

                                self.vrf_prefix_topology = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies, self).__setattr__(name, value)


                            class VrfPrefixTopology(Entity):
                                """
                                A static route
                                
                                .. attribute:: prefix  <key>
                                
                                	Destination prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: prefix_length  <key>
                                
                                	Destination prefix length
                                	**type**\:  int
                                
                                	**range:** 0..128
                                
                                .. attribute:: vrf_recurse_routes
                                
                                	A recursive next VRF static route
                                	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                
                                .. attribute:: vrf_route
                                
                                	A connected or recursive  static route
                                	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                
                                .. attribute:: vrf_seg_route
                                
                                	A static segment route
                                	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2015-09-10'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                    self.yang_name = "vrf-prefix-topology"
                                    self.yang_parent_name = "vrf-prefix-topologies"

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                    self.vrf_recurse_routes.parent = self
                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                    self._children_yang_names.add("vrf-recurse-routes")

                                    self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                    self.vrf_route.parent = self
                                    self._children_name_map["vrf_route"] = "vrf-route"
                                    self._children_yang_names.add("vrf-route")

                                    self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                    self.vrf_seg_route.parent = self
                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    self._children_yang_names.add("vrf-seg-route")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("prefix",
                                                    "prefix_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__setattr__(name, value)


                                class VrfRoute(Entity):
                                    """
                                    A connected or recursive  static route
                                    
                                    .. attribute:: vrf_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                        self.yang_name = "vrf-route"
                                        self.yang_parent_name = "vrf-prefix-topology"

                                        self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                        self.vrf_next_hop_table.parent = self
                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        self._children_yang_names.add("vrf-next-hop-table")


                                    class VrfNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                            self.yang_name = "vrf-next-hop-table"
                                            self.yang_parent_name = "vrf-route"

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__setattr__(name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-next-hop-table" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_explicit_path_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name"):
                                                for c in self.vrf_next_hop_interface_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_data())

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.vrf_next_hop_table is not None and self.vrf_next_hop_table.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-route" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-next-hop-table"):
                                            if (self.vrf_next_hop_table is None):
                                                self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                self.vrf_next_hop_table.parent = self
                                                self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            return self.vrf_next_hop_table

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-next-hop-table"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class VrfRecurseRoutes(Entity):
                                    """
                                    A recursive next VRF static route
                                    
                                    .. attribute:: vrf_recurse_route
                                    
                                    	A recursive next vrf static route
                                    	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                        self.yang_name = "vrf-recurse-routes"
                                        self.yang_parent_name = "vrf-prefix-topology"

                                        self.vrf_recurse_route = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__setattr__(name, value)


                                    class VrfRecurseRoute(Entity):
                                        """
                                        A recursive next vrf static route
                                        
                                        .. attribute:: vrf_name  <key>
                                        
                                        	Fallback or recusive VRF name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: vrf_recursive_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                            self.yang_name = "vrf-recurse-route"
                                            self.yang_parent_name = "vrf-recurse-routes"

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                            self.vrf_recursive_next_hop_table.parent = self
                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            self._children_yang_names.add("vrf-recursive-next-hop-table")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vrf_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__setattr__(name, value)


                                        class VrfRecursiveNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                self.yang_name = "vrf-recursive-next-hop-table"
                                                self.yang_parent_name = "vrf-recurse-route"

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__setattr__(name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("next_hop_address",
                                                                    "explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.next_hop_address.is_set or
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.next_hop_address.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "next-hop-address"):
                                                        self.next_hop_address = value
                                                        self.next_hop_address.value_namespace = name_space
                                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2015-09-10'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("explicit_path_name",
                                                                    "bfd_fast_detect",
                                                                    "description",
                                                                    "detect_multiplier",
                                                                    "index",
                                                                    "load_metric",
                                                                    "metric",
                                                                    "minimum_interval",
                                                                    "object_name",
                                                                    "permanent",
                                                                    "tag",
                                                                    "tunnel_id",
                                                                    "vrf_lable") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.explicit_path_name.is_set or
                                                        self.bfd_fast_detect.is_set or
                                                        self.description.is_set or
                                                        self.detect_multiplier.is_set or
                                                        self.index.is_set or
                                                        self.load_metric.is_set or
                                                        self.metric.is_set or
                                                        self.minimum_interval.is_set or
                                                        self.object_name.is_set or
                                                        self.permanent.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_id.is_set or
                                                        self.vrf_lable.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.explicit_path_name.yfilter != YFilter.not_set or
                                                        self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                        self.description.yfilter != YFilter.not_set or
                                                        self.detect_multiplier.yfilter != YFilter.not_set or
                                                        self.index.yfilter != YFilter.not_set or
                                                        self.load_metric.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.minimum_interval.yfilter != YFilter.not_set or
                                                        self.object_name.yfilter != YFilter.not_set or
                                                        self.permanent.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                        self.vrf_lable.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                    if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.description.get_name_leafdata())
                                                    if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.index.get_name_leafdata())
                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                    if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.object_name.get_name_leafdata())
                                                    if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.permanent.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                    if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "explicit-path-name"):
                                                        self.explicit_path_name = value
                                                        self.explicit_path_name.value_namespace = name_space
                                                        self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "bfd-fast-detect"):
                                                        self.bfd_fast_detect = value
                                                        self.bfd_fast_detect.value_namespace = name_space
                                                        self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "description"):
                                                        self.description = value
                                                        self.description.value_namespace = name_space
                                                        self.description.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "detect-multiplier"):
                                                        self.detect_multiplier = value
                                                        self.detect_multiplier.value_namespace = name_space
                                                        self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "index"):
                                                        self.index = value
                                                        self.index.value_namespace = name_space
                                                        self.index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "load-metric"):
                                                        self.load_metric = value
                                                        self.load_metric.value_namespace = name_space
                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-interval"):
                                                        self.minimum_interval = value
                                                        self.minimum_interval.value_namespace = name_space
                                                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "object-name"):
                                                        self.object_name = value
                                                        self.object_name.value_namespace = name_space
                                                        self.object_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "permanent"):
                                                        self.permanent = value
                                                        self.permanent.value_namespace = name_space
                                                        self.permanent.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-id"):
                                                        self.tunnel_id = value
                                                        self.tunnel_id.value_namespace = name_space
                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vrf-lable"):
                                                        self.vrf_lable = value
                                                        self.vrf_lable.value_namespace = name_space
                                                        self.vrf_lable.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-recursive-next-hop-table" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                    for c in self.vrf_next_hop_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_explicit_path_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name"):
                                                    for c in self.vrf_next_hop_interface_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                    for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                    for c in self.vrf_next_hop_next_hop_address:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address.append(c)
                                                    return c

                                                if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.vrf_name.is_set or
                                                (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vrf_name.yfilter != YFilter.not_set or
                                                (self.vrf_recursive_next_hop_table is not None and self.vrf_recursive_next_hop_table.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-recursive-next-hop-table"):
                                                if (self.vrf_recursive_next_hop_table is None):
                                                    self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                    self.vrf_recursive_next_hop_table.parent = self
                                                    self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                return self.vrf_recursive_next_hop_table

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-recursive-next-hop-table" or name == "vrf-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vrf-name"):
                                                self.vrf_name = value
                                                self.vrf_name.value_namespace = name_space
                                                self.vrf_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vrf_recurse_route:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.vrf_recurse_route:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-recurse-routes" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vrf-recurse-route"):
                                            for c in self.vrf_recurse_route:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vrf_recurse_route.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vrf-recurse-route"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class VrfSegRoute(Entity):
                                    """
                                    A static segment route
                                    
                                    .. attribute:: segment_route_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2015-09-10'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                        self.yang_name = "vrf-seg-route"
                                        self.yang_parent_name = "vrf-prefix-topology"

                                        self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                        self.segment_route_next_hop_table.parent = self
                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        self._children_yang_names.add("segment-route-next-hop-table")


                                    class SegmentRouteNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2015-09-10'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                            self.yang_name = "segment-route-next-hop-table"
                                            self.yang_parent_name = "vrf-seg-route"

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__setattr__(name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("next_hop_address",
                                                                "explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.next_hop_address.is_set or
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "next-hop-address" or name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2015-09-10'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("explicit_path_name",
                                                                "bfd_fast_detect",
                                                                "description",
                                                                "detect_multiplier",
                                                                "index",
                                                                "load_metric",
                                                                "metric",
                                                                "minimum_interval",
                                                                "object_name",
                                                                "permanent",
                                                                "tag",
                                                                "tunnel_id",
                                                                "vrf_lable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.explicit_path_name.is_set or
                                                    self.bfd_fast_detect.is_set or
                                                    self.description.is_set or
                                                    self.detect_multiplier.is_set or
                                                    self.index.is_set or
                                                    self.load_metric.is_set or
                                                    self.metric.is_set or
                                                    self.minimum_interval.is_set or
                                                    self.object_name.is_set or
                                                    self.permanent.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_id.is_set or
                                                    self.vrf_lable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.explicit_path_name.yfilter != YFilter.not_set or
                                                    self.bfd_fast_detect.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.detect_multiplier.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.load_metric.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.minimum_interval.yfilter != YFilter.not_set or
                                                    self.object_name.yfilter != YFilter.not_set or
                                                    self.permanent.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_id.yfilter != YFilter.not_set or
                                                    self.vrf_lable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.explicit_path_name.is_set or self.explicit_path_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.explicit_path_name.get_name_leafdata())
                                                if (self.bfd_fast_detect.is_set or self.bfd_fast_detect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_fast_detect.get_name_leafdata())
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.detect_multiplier.is_set or self.detect_multiplier.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.detect_multiplier.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                                                if (self.object_name.is_set or self.object_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.object_name.get_name_leafdata())
                                                if (self.permanent.is_set or self.permanent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.permanent.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                if (self.vrf_lable.is_set or self.vrf_lable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vrf_lable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "explicit-path-name" or name == "bfd-fast-detect" or name == "description" or name == "detect-multiplier" or name == "index" or name == "load-metric" or name == "metric" or name == "minimum-interval" or name == "object-name" or name == "permanent" or name == "tag" or name == "tunnel-id" or name == "vrf-lable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "explicit-path-name"):
                                                    self.explicit_path_name = value
                                                    self.explicit_path_name.value_namespace = name_space
                                                    self.explicit_path_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-fast-detect"):
                                                    self.bfd_fast_detect = value
                                                    self.bfd_fast_detect.value_namespace = name_space
                                                    self.bfd_fast_detect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "detect-multiplier"):
                                                    self.detect_multiplier = value
                                                    self.detect_multiplier.value_namespace = name_space
                                                    self.detect_multiplier.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "load-metric"):
                                                    self.load_metric = value
                                                    self.load_metric.value_namespace = name_space
                                                    self.load_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-interval"):
                                                    self.minimum_interval = value
                                                    self.minimum_interval.value_namespace = name_space
                                                    self.minimum_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "object-name"):
                                                    self.object_name = value
                                                    self.object_name.value_namespace = name_space
                                                    self.object_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "permanent"):
                                                    self.permanent = value
                                                    self.permanent.value_namespace = name_space
                                                    self.permanent.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-id"):
                                                    self.tunnel_id = value
                                                    self.tunnel_id.value_namespace = name_space
                                                    self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vrf-lable"):
                                                    self.vrf_lable = value
                                                    self.vrf_lable.value_namespace = name_space
                                                    self.vrf_lable.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.vrf_next_hop_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "segment-route-next-hop-table" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vrf-next-hop-explicit-path-name"):
                                                for c in self.vrf_next_hop_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_explicit_path_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name"):
                                                for c in self.vrf_next_hop_interface_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-interface-name-next-hop-address"):
                                                for c in self.vrf_next_hop_interface_name_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_interface_name_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address"):
                                                for c in self.vrf_next_hop_next_hop_address:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address.append(c)
                                                return c

                                            if (child_yang_name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                for c in self.vrf_next_hop_next_hop_address_explicit_path_name:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vrf_next_hop_next_hop_address_explicit_path_name.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vrf-next-hop-explicit-path-name" or name == "vrf-next-hop-interface-name" or name == "vrf-next-hop-interface-name-next-hop-address" or name == "vrf-next-hop-next-hop-address" or name == "vrf-next-hop-next-hop-address-explicit-path-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_data())

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.segment_route_next_hop_table is not None and self.segment_route_next_hop_table.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vrf-seg-route" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "segment-route-next-hop-table"):
                                            if (self.segment_route_next_hop_table is None):
                                                self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                self.segment_route_next_hop_table.parent = self
                                                self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            return self.segment_route_next_hop_table

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "segment-route-next-hop-table"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.prefix.is_set or
                                        self.prefix_length.is_set or
                                        (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_data()) or
                                        (self.vrf_route is not None and self.vrf_route.has_data()) or
                                        (self.vrf_seg_route is not None and self.vrf_seg_route.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.prefix.yfilter != YFilter.not_set or
                                        self.prefix_length.yfilter != YFilter.not_set or
                                        (self.vrf_recurse_routes is not None and self.vrf_recurse_routes.has_operation()) or
                                        (self.vrf_route is not None and self.vrf_route.has_operation()) or
                                        (self.vrf_seg_route is not None and self.vrf_seg_route.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-multicast/default-topology/vrf-prefix-topologies/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vrf-recurse-routes"):
                                        if (self.vrf_recurse_routes is None):
                                            self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                            self.vrf_recurse_routes.parent = self
                                            self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                        return self.vrf_recurse_routes

                                    if (child_yang_name == "vrf-route"):
                                        if (self.vrf_route is None):
                                            self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                            self.vrf_route.parent = self
                                            self._children_name_map["vrf_route"] = "vrf-route"
                                        return self.vrf_route

                                    if (child_yang_name == "vrf-seg-route"):
                                        if (self.vrf_seg_route is None):
                                            self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                            self.vrf_seg_route.parent = self
                                            self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        return self.vrf_seg_route

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vrf-recurse-routes" or name == "vrf-route" or name == "vrf-seg-route" or name == "prefix" or name == "prefix-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "prefix"):
                                        self.prefix = value
                                        self.prefix.value_namespace = name_space
                                        self.prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-length"):
                                        self.prefix_length = value
                                        self.prefix_length.value_namespace = name_space
                                        self.prefix_length.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.vrf_prefix_topology:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.vrf_prefix_topology:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vrf-prefix-topologies" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-multicast/default-topology/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "vrf-prefix-topology"):
                                    for c in self.vrf_prefix_topology:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.vrf_prefix_topology.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "vrf-prefix-topology"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.vrf_prefix_topologies is not None and self.vrf_prefix_topologies.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "default-topology" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-multicast/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "vrf-prefix-topologies"):
                                if (self.vrf_prefix_topologies is None):
                                    self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies()
                                    self.vrf_prefix_topologies.parent = self
                                    self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                return self.vrf_prefix_topologies

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "vrf-prefix-topologies"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.default_topology is not None and self.default_topology.has_data()) or
                            (self.topologies is not None and self.topologies.has_data()) or
                            (self.vrf_prefixes is not None and self.vrf_prefixes.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.default_topology is not None and self.default_topology.has_operation()) or
                            (self.topologies is not None and self.topologies.has_operation()) or
                            (self.vrf_prefixes is not None and self.vrf_prefixes.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "vrf-multicast" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "default-topology"):
                            if (self.default_topology is None):
                                self.default_topology = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology()
                                self.default_topology.parent = self
                                self._children_name_map["default_topology"] = "default-topology"
                            return self.default_topology

                        if (child_yang_name == "topologies"):
                            if (self.topologies is None):
                                self.topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies()
                                self.topologies.parent = self
                                self._children_name_map["topologies"] = "topologies"
                            return self.topologies

                        if (child_yang_name == "vrf-prefixes"):
                            if (self.vrf_prefixes is None):
                                self.vrf_prefixes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes()
                                self.vrf_prefixes.parent = self
                                self._children_name_map["vrf_prefixes"] = "vrf-prefixes"
                            return self.vrf_prefixes

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "default-topology" or name == "topologies" or name == "vrf-prefixes"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.vrf_multicast is not None and self.vrf_multicast.has_data()) or
                        (self.vrf_unicast is not None and self.vrf_unicast.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.vrf_multicast is not None and self.vrf_multicast.has_operation()) or
                        (self.vrf_unicast is not None and self.vrf_unicast.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "vrfipv6" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "vrf-multicast"):
                        if (self.vrf_multicast is None):
                            self.vrf_multicast = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast()
                            self.vrf_multicast.parent = self
                            self._children_name_map["vrf_multicast"] = "vrf-multicast"
                        return self.vrf_multicast

                    if (child_yang_name == "vrf-unicast"):
                        if (self.vrf_unicast is None):
                            self.vrf_unicast = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast()
                            self.vrf_unicast.parent = self
                            self._children_name_map["vrf_unicast"] = "vrf-unicast"
                        return self.vrf_unicast

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "vrf-multicast" or name == "vrf-unicast"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    (self.vrfipv4 is not None and self.vrfipv4.has_data()) or
                    (self.vrfipv6 is not None and self.vrfipv6.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.vrfipv4 is not None and self.vrfipv4.has_operation()) or
                    (self.vrfipv6 is not None and self.vrfipv6.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "address-family" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "vrfipv4"):
                    if (self.vrfipv4 is None):
                        self.vrfipv4 = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4()
                        self.vrfipv4.parent = self
                        self._children_name_map["vrfipv4"] = "vrfipv4"
                    return self.vrfipv4

                if (child_yang_name == "vrfipv6"):
                    if (self.vrfipv6 is None):
                        self.vrfipv6 = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6()
                        self.vrfipv6.parent = self
                        self._children_name_map["vrfipv6"] = "vrfipv6"
                    return self.vrfipv6

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "vrfipv4" or name == "vrfipv6"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (self.address_family is not None and self.address_family.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.address_family is not None and self.address_family.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "default-vrf" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "address-family"):
                if (self.address_family is None):
                    self.address_family = RouterStatic.DefaultVrf.AddressFamily()
                    self.address_family.parent = self
                    self._children_name_map["address_family"] = "address-family"
                return self.address_family

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "address-family"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class MaximumRoutes(Entity):
        """
        The maximum number of static routes that can be
        configured.
        
        .. attribute:: ipv4_routes
        
        	The maximum number of static routes that can be configured for IPv4 AFI
        	**type**\:  int
        
        	**range:** 1..140000
        
        	**default value**\: 4000
        
        .. attribute:: ipv6_routes
        
        	The maximum number of static routes that can be configured for IPv6 AFI
        	**type**\:  int
        
        	**range:** 1..140000
        
        	**default value**\: 4000
        
        

        """

        _prefix = 'ip-static-cfg'
        _revision = '2015-09-10'

        def __init__(self):
            super(RouterStatic.MaximumRoutes, self).__init__()

            self.yang_name = "maximum-routes"
            self.yang_parent_name = "router-static"

            self.ipv4_routes = YLeaf(YType.uint32, "ipv4-routes")

            self.ipv6_routes = YLeaf(YType.uint32, "ipv6-routes")

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in ("ipv4_routes",
                            "ipv6_routes") and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RouterStatic.MaximumRoutes, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RouterStatic.MaximumRoutes, self).__setattr__(name, value)

        def has_data(self):
            return (
                self.ipv4_routes.is_set or
                self.ipv6_routes.is_set)

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                self.ipv4_routes.yfilter != YFilter.not_set or
                self.ipv6_routes.yfilter != YFilter.not_set)

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "maximum-routes" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()
            if (self.ipv4_routes.is_set or self.ipv4_routes.yfilter != YFilter.not_set):
                leaf_name_data.append(self.ipv4_routes.get_name_leafdata())
            if (self.ipv6_routes.is_set or self.ipv6_routes.yfilter != YFilter.not_set):
                leaf_name_data.append(self.ipv6_routes.get_name_leafdata())

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "ipv4-routes" or name == "ipv6-routes"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            if(value_path == "ipv4-routes"):
                self.ipv4_routes = value
                self.ipv4_routes.value_namespace = name_space
                self.ipv4_routes.value_namespace_prefix = name_space_prefix
            if(value_path == "ipv6-routes"):
                self.ipv6_routes = value
                self.ipv6_routes.value_namespace = name_space
                self.ipv6_routes.value_namespace_prefix = name_space_prefix

    def has_data(self):
        return (
            (self.default_vrf is not None and self.default_vrf.has_data()) or
            (self.maximum_routes is not None and self.maximum_routes.has_data()) or
            (self.vrfs is not None and self.vrfs.has_data()))

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.default_vrf is not None and self.default_vrf.has_operation()) or
            (self.maximum_routes is not None and self.maximum_routes.has_operation()) or
            (self.vrfs is not None and self.vrfs.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-ip-static-cfg:router-static" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "default-vrf"):
            if (self.default_vrf is None):
                self.default_vrf = RouterStatic.DefaultVrf()
                self.default_vrf.parent = self
                self._children_name_map["default_vrf"] = "default-vrf"
            return self.default_vrf

        if (child_yang_name == "maximum-routes"):
            if (self.maximum_routes is None):
                self.maximum_routes = RouterStatic.MaximumRoutes()
                self.maximum_routes.parent = self
                self._children_name_map["maximum_routes"] = "maximum-routes"
            return self.maximum_routes

        if (child_yang_name == "vrfs"):
            if (self.vrfs is None):
                self.vrfs = RouterStatic.Vrfs()
                self.vrfs.parent = self
                self._children_name_map["vrfs"] = "vrfs"
            return self.vrfs

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "default-vrf" or name == "maximum-routes" or name == "vrfs"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = RouterStatic()
        return self._top_entity

